"use strict";

var _react = _interopRequireDefault(require("react"));
var _theme = _interopRequireDefault(require("../../theme"));
var _testUtils = require("../../test-utils");
var _Alert = _interopRequireDefault(require("./Alert"));
var _Button = _interopRequireDefault(require("../Button/Button"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
describe('Alert', () => {
  test('should render alert correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Alert.default, {
      caption: "caption",
      description: "description",
      closable: true
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render null when closed true', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Alert.default, {
      caption: "caption",
      description: "description",
      closable: true,
      closed: true
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render alert with given variant', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Alert.default, {
      testID: "alert",
      variant: "success"
    }));
    const alertComponent = getByTestId('alert');

    // then
    expect(alertComponent.props.style[1][0].backgroundColor).toBe(_theme.default.colors.successContrast);
  });
  test('should render alert with given children ', () => {
    // given
    const mockOnPress = jest.fn();

    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Alert.default, {
      testID: "alert",
      description: "description",
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Button.default, {
        label: "Button",
        testID: "alert-child-button",
        onPress: mockOnPress
      })
    }));
    const alertChildButton = getByTestId('alert-child-button');
    _testUtils.fireEvent.press(alertChildButton);

    // then
    expect(mockOnPress).toBeCalled();
  });
});
//# sourceMappingURL=Alert.test.js.map