"use strict";

var _react = _interopRequireDefault(require("react"));
var _testUtils = require("../../test-utils");
var _BottomSheet = _interopRequireDefault(require("./BottomSheet"));
var _Text = _interopRequireDefault(require("../Text/Text"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
describe('BottomSheet', () => {
  test('should render BottomSheet when visible false', () => {
    // when
    const {
      toJSON,
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_BottomSheet.default, {
      testID: "modal",
      visible: false,
      title: "Base Title",
      closeButtonLabel: "Close",
      selectButtonLabel: "Select"
    }));

    // then
    const modalWrapper = queryByTestId('modal-wrapper');
    expect(modalWrapper).toBeNull();
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render BottomSheet when visible true', () => {
    // when
    const {
      toJSON,
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_BottomSheet.default, {
      testID: "modal",
      visible: true,
      title: "Base Title",
      closeButtonLabel: "Close",
      selectButtonLabel: "Select",
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
        children: "Base Content"
      })
    }));

    // then
    const modalWrapper = queryByTestId('modal-wrapper');
    expect(modalWrapper).not.toBeNull();
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render BottomSheet when closeButtonAction is called', () => {
    // when
    const closeButtonAction = jest.fn();
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_BottomSheet.default, {
      testID: "modal",
      visible: true,
      title: "Base Title",
      closeButtonAction: closeButtonAction,
      closeButtonLabel: "Close",
      selectButtonLabel: "Select",
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
        children: "Base Content"
      })
    }));
    _testUtils.fireEvent.press(queryByTestId('modal-header-close'));

    // then
    expect(closeButtonAction).toHaveBeenCalled();
  });
  test('should render BottomSheet when selectButtonAction is called', () => {
    // when
    const selectButtonAction = jest.fn();
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_BottomSheet.default, {
      testID: "modal",
      visible: true,
      title: "Base Title",
      selectButtonAction: selectButtonAction,
      closeButtonLabel: "Close",
      selectButtonLabel: "Select",
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
        children: "Base Content"
      })
    }));
    _testUtils.fireEvent.press(queryByTestId('modal-header-select'));

    // then
    expect(selectButtonAction).toHaveBeenCalled();
  });
  test('should render BottomSheet when title is given', () => {
    // when
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_BottomSheet.default, {
      testID: "modal",
      visible: true,
      title: "Base Title",
      closeButtonLabel: "Close",
      selectButtonLabel: "Select",
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
        children: "Base Content"
      })
    }));

    // then
    expect(queryByTestId('modal-header-label').children[0]).toEqual('Base Title');
  });
});
//# sourceMappingURL=BottomSheet.test.js.map