"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _restyle = require("@ergenekonyigit/restyle");
var _Text = _interopRequireDefault(require("../Text/Text"));
var _hooks = require("./hooks");
var _Icon = _interopRequireDefault(require("../Icon/Icon"));
var _Box = _interopRequireDefault(require("../Box/Box"));
var _utils = require("./utils");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const sizeVariant = (0, _restyle.createVariant)({
  property: 'size',
  themeKey: 'buttonSizeVariants'
});
const kindVariant = (0, _restyle.createVariant)({
  property: 'kind',
  themeKey: 'buttonKindVariants'
});
const variantVariant = (0, _restyle.createVariant)({
  property: 'variant',
  themeKey: 'buttonVariants'
});
const ButtonContainer = (0, _restyle.createRestyleComponent)([_restyle.layout, _restyle.spacing, _restyle.border, _restyle.backgroundColor, sizeVariant, kindVariant, variantVariant], _Box.default);
const PressableContainer = (0, _restyle.createRestyleComponent)([_restyle.layout, _restyle.spacing, _restyle.spacingShorthand], _reactNative.Pressable);
const Button = ({
  size = 'm',
  kind = 'default',
  variant = 'primary',
  icon,
  label,
  tintColor,
  disabled = false,
  filled = false,
  ...rest
}) => {
  const {
    pressableProps,
    isPressed
  } = (0, _hooks.useIsPressed)(rest.isPressed);

  /* istanbul ignore next */
  const onPressIn = () => pressableProps.onPressIn();
  /* istanbul ignore next */
  const onPressOut = () => pressableProps.onPressOut();
  const buttonHorizontalPadding = label ? {
    s: 'm',
    m: 'xl',
    l: '2xl'
  }[size] : {
    s: '2xs',
    m: 'xs',
    l: 's'
  }[size];
  const textVariant = {
    s: 'subtitle03Medium',
    m: 'subtitle03Medium',
    l: 'subtitle02Medium'
  }[size];
  const variantColors = (0, _utils.variantColorSelector)({
    variant,
    kind,
    isPressed,
    disabled
  });
  const typeColor = disabled ? 'neutralLighter' : isPressed && variant !== 'tertiary' ? 'neutralFull' : variantColors.color;
  const iconView = _react.default.useMemo(() => {
    if (!icon) {
      return null;
    }
    if (variant === 'transparent') {
      return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Icon.default, {
        name: icon,
        size: "s",
        color: tintColor,
        testID: "button-icon"
      });
    }
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Icon.default, {
      name: icon,
      size: "s",
      color: typeColor,
      testID: "button-icon"
    });
  }, [icon, typeColor, tintColor, variant]);
  const labelView = _react.default.useMemo(() => {
    if (!label) {
      return null;
    }
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      variant: textVariant,
      color: typeColor,
      marginLeft: icon ? '2xs' : 'none',
      testID: "button-text",
      children: label
    });
  }, [icon, label, textVariant, typeColor]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(PressableContainer, {
    onPressIn: onPressIn,
    onPressOut: onPressOut,
    disabled: disabled,
    ...rest,
    children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(ButtonContainer, {
      size: size,
      kind: kind
      // @ts-ignore
      ,
      variant: variant,
      paddingHorizontal: buttonHorizontalPadding,
      flexDirection: "row",
      alignItems: "center",
      justifyContent: "center",
      alignSelf: filled ? 'stretch' : 'flex-start',
      ...variantColors,
      children: [iconView, labelView]
    })
  });
};
var _default = exports.default = Button;
//# sourceMappingURL=Button.js.map