"use strict";

var _react = _interopRequireDefault(require("react"));
var _theme = _interopRequireDefault(require("../../theme"));
var _testUtils = require("../../test-utils");
var _Checkbox = _interopRequireDefault(require("./Checkbox"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
describe('Checkbox', () => {
  beforeEach(() => {});
  test('should render Checkbox correctly when checked is false', () => {
    // when
    const {
      toJSON,
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Checkbox.default, {
      checked: false
    }));
    const checkboxComponent = getByTestId('tickbox');

    // then
    expect(toJSON()).toMatchSnapshot();
    expect(checkboxComponent.props.style[1][0].borderColor).toBe(_theme.default.colors.neutralLighter);
    expect(checkboxComponent.props.style[1][0].backgroundColor).toBe(_theme.default.colors.neutralFull);
  });
  test('should render Checkbox correctly when checked is true', () => {
    // when
    const {
      toJSON,
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Checkbox.default, {
      checked: true
    }));
    const checkboxComponent = getByTestId('tickbox');

    // then
    expect(toJSON()).toMatchSnapshot();
    expect(checkboxComponent.props.style[1][0].borderColor).toBe(_theme.default.colors.primaryKey);
    expect(checkboxComponent.props.style[1][0].backgroundColor).toBe(_theme.default.colors.primaryKey);
  });
  test('should render Checkbox correctly when checked is true, indeterminate is false', () => {
    // when
    const {
      toJSON,
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Checkbox.default, {
      checked: true,
      indeterminate: false
    }));
    const checkboxComponent = getByTestId('tickbox');

    // then
    expect(toJSON()).toMatchSnapshot();
    expect(checkboxComponent.props.style[1][0].borderColor).toBe(_theme.default.colors.primaryKey);
    expect(checkboxComponent.props.style[1][0].backgroundColor).toBe(_theme.default.colors.primaryKey);
  });
  test('should render Checkbox correctly when checked is true, indeterminate is true', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Checkbox.default, {
      checked: true,
      indeterminate: true
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render Checkbox correctly when disable, checked is false', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Checkbox.default, {
      disabled: true,
      checked: false
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render Checkbox correctly when disable, checked is true', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Checkbox.default, {
      disabled: true,
      checked: true
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render Checkbox correctly when disable, checked and indeterminate is true', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Checkbox.default, {
      disabled: true,
      checked: true,
      indeterminate: true
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should press checkbox', () => {
    // given
    const onPress = jest.fn();

    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Checkbox.default, {
      checked: true,
      testID: "checkbox",
      onPress: onPress
    }));
    const checkboxComponent = getByTestId('checkbox');
    _testUtils.fireEvent.press(checkboxComponent);

    // then
    expect(onPress).toBeCalledTimes(1);
  });
  test('should not press checkbox when disabled', () => {
    // given
    const onPress = jest.fn();

    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Checkbox.default, {
      checked: true,
      disabled: true,
      testID: "checkbox",
      label: "lorem ipsum",
      onPress: onPress
    }));
    const checkboxComponent = getByTestId('checkbox');
    const checkboxLabelComponent = getByTestId('label');
    _testUtils.fireEvent.press(checkboxComponent);

    // then
    expect(onPress).not.toBeCalled();
    expect(checkboxLabelComponent.props.style[0].color).toBe(_theme.default.colors.neutralLighter);
  });
  test('should render without icon correctly', () => {
    // when
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Checkbox.default, {
      checked: false
    }));
    const checkboxCheckedIcon = queryByTestId('check-icon');
    const checkboxMinusIcon = queryByTestId('minus-icon');

    // then
    expect(checkboxCheckedIcon).toBeFalsy();
    expect(checkboxMinusIcon).toBeFalsy();
  });
  test('should render checked icon correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Checkbox.default, {
      checked: true
    }));
    const checkboxIcon = getByTestId('check-icon');

    // then
    expect(checkboxIcon).toBeTruthy();
  });
  test('should render unchecked icon correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Checkbox.default, {
      checked: true,
      indeterminate: true
    }));
    const checkboxIcon = getByTestId('minus-icon');

    // then
    expect(checkboxIcon).toBeTruthy();
  });
  test('should render with label correctly when checked', () => {
    // when
    const {
      getByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Checkbox.default, {
      checked: true,
      label: "lorem ipsum"
    }));
    const checkboxLabel = getByText('lorem ipsum');

    // then
    expect(checkboxLabel).toBeTruthy();
    expect(checkboxLabel.props.style[0].color).toBe(_theme.default.colors.primaryKey);
  });
  test('should render with label correctly when unchecked', () => {
    // when
    const {
      getByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Checkbox.default, {
      checked: false,
      label: "lorem ipsum"
    }));
    const checkboxLabel = getByText('lorem ipsum');

    // then
    expect(checkboxLabel).toBeTruthy();
    expect(checkboxLabel.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render without label correctly', () => {
    // when
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Checkbox.default, {
      checked: true
    }));
    const checkboxLabel = queryByTestId('');

    // then
    expect(checkboxLabel).toBeFalsy();
  });
  test('should render with icon correctly when checked', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Checkbox.default, {
      checked: true,
      flagIcon: "TR"
    }));
    const icon = getByTestId('flag-icon');

    // then
    expect(icon).toBeTruthy();
  });
  test('should render with icon correctly when unchecked', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Checkbox.default, {
      checked: false,
      flagIcon: "TR"
    }));
    const icon = getByTestId('flag-icon');

    // then
    expect(icon).toBeTruthy();
  });
  test('should render with icon correctly when disabled', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Checkbox.default, {
      checked: false,
      disabled: true,
      flagIcon: "TR"
    }));
    const icon = getByTestId('flag-icon');

    // then
    expect(icon).toBeTruthy();
  });
  test('should render without icon correctly when icon prop is not provided', () => {
    // when
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Checkbox.default, {
      checked: false
    }));
    const icon = queryByTestId('flag-icon');

    // then
    expect(icon).toBeFalsy();
  });
});
//# sourceMappingURL=Checkbox.test.js.map