"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _Box = _interopRequireDefault(require("../Box/Box"));
var _Text = _interopRequireDefault(require("../Text/Text"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const DayItem = /*#__PURE__*/_react.default.memo(({
  date,
  weekIndex,
  dateIndex,
  isSelected,
  inRange,
  onSelectDate,
  testID,
  children,
  disableDates,
  disableMonths,
  disableYears
}) => {
  const isActiveCurrentDate = date.isCurrentDate && date.isActive;
  const backgroundColor = isSelected ? 'primaryKey' : undefined;
  const textColor = isSelected ? 'white' : !date.isActive ? 'neutralDark' : isActiveCurrentDate ? 'primaryColor' : 'neutralDark';
  const inRangeBackgroundColor = inRange ? 'primaryContrast' : 'transparent';
  const isDisabled = disableDates.includes(date.timestamp) || disableMonths.includes(date.yearWithMonth) || disableYears.includes(date.year);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
    flex: 1,
    justifyContent: "center",
    alignItems: "center",
    backgroundColor: inRangeBackgroundColor,
    children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.TouchableOpacity, {
      onPress: () => {
        if (isDisabled) {
          return;
        }
        onSelectDate(date);
      },
      testID: `${testID}-datepicker-day-${date.timestamp}`,
      accessibilityLabel: `${testID}-datepicker-day-${date.timestamp}`,
      style: styles.dayItemTouchableOpacity,
      children: [children, /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
        width: 40,
        height: 40,
        justifyContent: "center",
        alignItems: "center",
        style: [styles.positionRelative, styles.zIndex1],
        borderRadius: isSelected ? 'full' : 'none',
        backgroundColor: backgroundColor,
        opacity: !date.isActive || isDisabled ? 0.5 : 1,
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
          variant: "subtitle03Regular",
          color: textColor,
          testID: `${testID}-datepicker-day-${date.timestamp}-text`,
          accessibilityLabel: `${testID}-datepicker-day-${date.timestamp}-text`,
          children: date.day
        })
      })]
    }, `day-${weekIndex}-${dateIndex}`)
  });
});
const WeekHeader = /*#__PURE__*/_react.default.memo(({
  nameOfWeekdays,
  testID
}) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
  flexDirection: "row",
  justifyContent: "space-around",
  mb: "2xs",
  children: nameOfWeekdays.map((dayName, dateIndex) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
    width: 40,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      textAlign: "center",
      variant: "subtitle03Regular",
      color: "neutralDark",
      testID: `${testID}-datepicker-header-${dateIndex}-text`,
      accessibilityLabel: `${testID}-datepicker-header-${dateIndex}-text`,
      children: dayName
    })
  }, `${testID}-datepicker-header-${dateIndex}`))
}));
const CalendarPicker = /*#__PURE__*/_react.default.memo(({
  context
}) => {
  const {
    onSelectDate,
    date: selectedDate,
    testID,
    dateRange,
    calendarData,
    nameOfWeekdays,
    multiple,
    disableDates = [],
    disableMonths = [],
    disableYears = []
  } = context;
  const getIsSelected = _react.default.useCallback(date => {
    if (multiple) {
      return dateRange?.startDate?.timestamp === date.timestamp || dateRange?.endDate?.timestamp === date.timestamp;
    }
    return selectedDate?.timestamp === date.timestamp;
  }, [multiple, selectedDate, dateRange]);
  const isRange = date => {
    if (!multiple) {
      return false;
    }
    if (dateRange?.startDate?.timestamp && dateRange?.endDate?.timestamp) {
      return dateRange?.startDate?.timestamp < date.timestamp && dateRange?.endDate?.timestamp > date.timestamp;
    }
  };
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_jsxRuntime.Fragment, {
    children: calendarData.calendar.map((week, weekIndex) => {
      if (weekIndex === 0) {
        return /*#__PURE__*/(0, _jsxRuntime.jsx)(WeekHeader, {
          nameOfWeekdays: nameOfWeekdays || [],
          testID: testID || ''
        }, `week-header-${weekIndex}`);
      }
      return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
        flexDirection: "row",
        justifyContent: "space-around",
        mb: "2xs",
        style: styles.positionRelative,
        height: 40,
        children: week.map((date, dateIndex) => {
          const isSelected = getIsSelected(date);
          const inRange = isRange(date);
          const isStartDate = dateRange?.startDate?.timestamp === date.timestamp;
          const isEndDate = dateRange?.endDate?.timestamp === date.timestamp;
          const rangeIsActive = dateRange?.startDate?.timestamp && dateRange?.endDate?.timestamp && dateRange?.startDate?.timestamp !== dateRange?.endDate?.timestamp;
          return /*#__PURE__*/(0, _jsxRuntime.jsx)(DayItem, {
            date: date,
            weekIndex: weekIndex,
            dateIndex: dateIndex,
            isSelected: isSelected,
            inRange: multiple && inRange,
            onSelectDate: onSelectDate,
            testID: testID || '',
            disableDates: disableDates,
            disableMonths: disableMonths,
            disableYears: disableYears,
            children: multiple && rangeIsActive ? /*#__PURE__*/(0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
              children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
                width: 20,
                height: 40,
                style: styles.dayItemLeftBackground,
                backgroundColor: isEndDate ? 'primaryContrast' : 'transparent'
              }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
                width: 20,
                height: 40,
                style: styles.dayItemRightBackground,
                backgroundColor: isStartDate ? 'primaryContrast' : 'transparent'
              })]
            }) : null
          }, `day-${weekIndex}-${dateIndex}`);
        })
      }, `week-${weekIndex}`);
    })
  });
});
CalendarPicker.displayName = 'CalendarPicker';
DayItem.displayName = 'DayItem';
WeekHeader.displayName = 'WeekHeader';
var _default = exports.default = CalendarPicker;
const styles = _reactNative.StyleSheet.create({
  dayItemTouchableOpacity: {
    position: 'relative',
    display: 'flex',
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'center',
    width: '100%',
    height: '100%'
  },
  dayItemLeftBackground: {
    position: 'absolute',
    top: 0,
    left: 0,
    bottom: 0
  },
  dayItemRightBackground: {
    position: 'absolute',
    top: 0,
    right: 0,
    bottom: 0
  },
  positionRelative: {
    position: 'relative'
  },
  zIndex1: {
    zIndex: 1
  }
});
//# sourceMappingURL=CalendarPicker.js.map