"use strict";

var _react = _interopRequireDefault(require("react"));
var _testUtils = require("../../test-utils");
var _DatePicker = _interopRequireDefault(require("./DatePicker"));
var _constants = require("./constants");
var _DatePickerContext = require("./DatePickerContext");
var _Text = _interopRequireDefault(require("../Text/Text"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const defaultProps = {
  nameOfWeekdays: _constants.DEFAULT_NAME_OF_WEEKDAYS,
  nameOfMonths: _constants.DEFAULT_NAME_OF_MONTHS,
  closeButtonLabel: 'Close',
  selectButtonLabel: 'Select',
  title: 'Select Date',
  testID: 'datepicker',
  value: null,
  placeholder: 'Select date',
  firstDayOfWeek: 1,
  disableDates: [],
  onChange: jest.fn()
};
const getTimestamp = (year, month, day) => {
  return new Date(year, month, day, 0, 0, 0, 0).getTime();
};
describe('DatePicker', () => {
  beforeEach(() => {
    jest.clearAllMocks();
  });
  test('should render with empty input and calendar closed initially', () => {
    const {
      getByTestId,
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
      ...defaultProps
    }));
    expect(getByTestId('datepicker-input').props.value).toBe('');
    expect(queryByTestId('datepicker-wrapper')).toBeNull();
  });
  test('should open calendar when input is pressed', () => {
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
      ...defaultProps
    }));
    const touchable = getByTestId('datepicker-touchable');
    _testUtils.fireEvent.press(touchable);
    expect(getByTestId('datepicker-wrapper')).toBeTruthy();
  });
  test('should close calendar when close button is pressed', () => {
    const {
      getByTestId,
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
      ...defaultProps
    }));
    _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
    expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    _testUtils.fireEvent.press(getByTestId('datepicker-header-close'));
    expect(queryByTestId('datepicker-wrapper')).toBeNull();
  });
  test('should handle value prop changes', () => {
    const {
      rerender,
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
      ...defaultProps,
      value: "2025-01-15"
    }));
    expect(getByTestId('datepicker-input').props.value).toBe('2025-01-15');
    rerender(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
      ...defaultProps,
      value: "2025-02-20"
    }));
    expect(getByTestId('datepicker-input').props.value).toBe('2025-02-20');
  });
  test('should handle firstDayOfWeek prop correctly', () => {
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
      ...defaultProps,
      firstDayOfWeek: 0
    }));
    _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
    expect(getByTestId('datepicker-datepicker-header-0-text')).toBeTruthy();
  });
  test('should handle custom nameOfWeekdays', () => {
    const customWeekdays = ['Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun'];
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
      ...defaultProps,
      nameOfWeekdays: customWeekdays
    }));
    _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
    const headerText = getByTestId('datepicker-datepicker-header-0-text');
    expect(headerText.props.children).toBe('Mon');
  });
  test('should handle custom nameOfMonths', () => {
    const customMonths = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
      ...defaultProps,
      nameOfMonths: customMonths
    }));
    _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
    const monthButton = getByTestId('datepicker-header-month-select');
    expect(monthButton).toBeTruthy();
  });
  describe('Size prop', () => {
    test('should render with small size', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        size: "small"
      }));
      const input = getByTestId('datepicker-input');
      expect(input).toBeTruthy();
    });
    test('should render with medium size', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        size: "medium"
      }));
      const input = getByTestId('datepicker-input');
      expect(input).toBeTruthy();
    });
    test('should render with large size by default', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      const input = getByTestId('datepicker-input');
      expect(input).toBeTruthy();
    });
    test('should render with large size when explicitly set', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        size: "large"
      }));
      const input = getByTestId('datepicker-input');
      expect(input).toBeTruthy();
    });
  });
  describe('Label prop', () => {
    test('should render with label', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        label: "Birth Date"
      }));
      const input = getByTestId('datepicker-input');
      expect(input).toBeTruthy();
    });
    test('should render without label when not provided', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      const input = getByTestId('datepicker-input');
      expect(input).toBeTruthy();
    });
    test('should render with calendar icon', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        label: "Test Label"
      }));
      const input = getByTestId('datepicker-input');
      expect(input).toBeTruthy();
    });
  });
  describe('onChange callback', () => {
    test('should call onChange when date is selected and select button is pressed', () => {
      const onChange = jest.fn();
      const {
        getByTestId,
        getAllByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        onChange: onChange
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      const dateButtons = getAllByTestId(/datepicker-datepicker-day-/);
      if (dateButtons.length > 0) {
        _testUtils.fireEvent.press(dateButtons[0]);
        _testUtils.fireEvent.press(getByTestId('datepicker-header-select'));
        expect(onChange).toHaveBeenCalled();
      }
    });
    test('should call onChange with date range when multiple is true', () => {
      const onChange = jest.fn();
      const {
        getByTestId,
        getAllByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        multiple: true,
        onChange: onChange
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      const dateButtons = getAllByTestId(/datepicker-datepicker-day-/);
      if (dateButtons.length >= 2) {
        _testUtils.fireEvent.press(dateButtons[0]);
        _testUtils.fireEvent.press(dateButtons[1]);
        _testUtils.fireEvent.press(getByTestId('datepicker-header-select'));
        expect(onChange).toHaveBeenCalled();
      }
    });
  });
  describe('DisableDates', () => {
    test('should disable specified dates', () => {
      const disableDates = ['2025-01-15', '2025-01-16'];
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        disableDates: disableDates
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
    test('should not allow selection of disabled dates', () => {
      const onChange = jest.fn();
      const disableDates = ['2025-01-15'];
      const {
        getByTestId,
        getAllByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        disableDates: disableDates,
        onChange: onChange
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      const dateButtons = getAllByTestId(/datepicker-datepicker-day-/);
      if (dateButtons.length > 0) {
        _testUtils.fireEvent.press(dateButtons[0]);
        _testUtils.fireEvent.press(getByTestId('datepicker-header-select'));
        expect(onChange).toHaveBeenCalled();
      }
    });
  });
  describe('Accessibility', () => {
    test('should have proper accessibility labels', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      expect(getByTestId('datepicker-input').props.accessibilityLabel).toBe('datepicker-input');
      expect(getByTestId('datepicker-touchable').props.accessibilityLabel).toBe('datepicker-touchable');
    });
    test('should have proper testIDs for all interactive elements', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      expect(getByTestId('datepicker-header-prev')).toBeTruthy();
      expect(getByTestId('datepicker-header-next')).toBeTruthy();
      expect(getByTestId('datepicker-header-month-select')).toBeTruthy();
      expect(getByTestId('datepicker-header-year-select')).toBeTruthy();
    });
    test('should have proper accessibility labels for calendar elements', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      expect(getByTestId('datepicker-header-prev').props.accessibilityLabel).toBe('datepicker-header-prev');
      expect(getByTestId('datepicker-header-next').props.accessibilityLabel).toBe('datepicker-header-next');
      expect(getByTestId('datepicker-header-month-select').props.accessibilityLabel).toBe('datepicker-header-month-select');
      expect(getByTestId('datepicker-header-year-select').props.accessibilityLabel).toBe('datepicker-header-year-select');
    });
  });
  describe('Edge cases', () => {
    test('should handle null value gracefully', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        value: null
      }));
      expect(getByTestId('datepicker-input').props.value).toBe('');
    });
    test('should handle empty string value', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        value: ""
      }));
      expect(getByTestId('datepicker-input').props.value).toBe('');
    });
    test('should handle minYear and maxYear constraints', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        minYear: 2020,
        maxYear: 2030
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      expect(getByTestId('datepicker-year-2020')).toBeTruthy();
      expect(getByTestId('datepicker-year-2030')).toBeTruthy();
    });
    test('should handle month boundary navigation', () => {
      const {
        getByTestId,
        getByText
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-month-select'));
      _testUtils.fireEvent.press(getByTestId('datepicker-month-12'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-next'));
      expect(getByText('January')).toBeTruthy();
    });
    test('should handle year boundary navigation', () => {
      const {
        getByTestId,
        getByText
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      const currentYear = new Date().getFullYear();
      _testUtils.fireEvent.press(getByTestId('datepicker-header-month-select'));
      _testUtils.fireEvent.press(getByTestId('datepicker-month-12'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-next'));
      expect(getByText(String(currentYear + 1))).toBeTruthy();
    });
    test('should handle invalid date values', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        value: "invalid-date"
      }));
      expect(getByTestId('datepicker-input').props.value).toBe('invalid-date');
    });
  });
  describe('Performance', () => {
    test('should not re-render unnecessarily when props are stable', () => {
      const {
        rerender,
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      const initialRender = getByTestId('datepicker-input');
      rerender(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      const secondRender = getByTestId('datepicker-input');
      expect(initialRender).toBe(secondRender);
    });
    test('should handle large disableDates array efficiently', () => {
      const largeDisableDates = Array.from({
        length: 20
      }, (_, i) => `2025-01-${i + 1}`);
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        disableDates: largeDisableDates
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
  });
  describe('Multiple date selection', () => {
    test('should handle date range value prop', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        multiple: true,
        value: "2025-01-15 - 2025-01-20"
      }));
      expect(getByTestId('datepicker-input').props.value).toBe('2025-01-15 - 2025-01-20');
    });
    test('should handle empty date range value', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        multiple: true,
        value: ""
      }));
      expect(getByTestId('datepicker-input').props.value).toBe('');
    });
    test('should handle null date range value', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        multiple: true,
        value: null
      }));
      expect(getByTestId('datepicker-input').props.value).toBe('');
    });
    test('should handle single date selection in multiple mode', () => {
      const onChange = jest.fn();
      const {
        getByTestId,
        getAllByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        multiple: true,
        onChange: onChange
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      const dateButtons = getAllByTestId(/datepicker-datepicker-day-/);
      if (dateButtons.length > 0) {
        _testUtils.fireEvent.press(dateButtons[0]);
        _testUtils.fireEvent.press(getByTestId('datepicker-header-select'));
        expect(onChange).toHaveBeenCalled();
      }
    });
    test('should handle reverse date selection (end date before start date)', () => {
      const onChange = jest.fn();
      const {
        getByTestId,
        getAllByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        multiple: true,
        onChange: onChange
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      const dateButtons = getAllByTestId(/datepicker-datepicker-day-/);
      if (dateButtons.length >= 2) {
        _testUtils.fireEvent.press(dateButtons[1]);
        _testUtils.fireEvent.press(dateButtons[0]);
        _testUtils.fireEvent.press(getByTestId('datepicker-header-select'));
        expect(onChange).toHaveBeenCalled();
      }
    });
  });
  describe('Calendar navigation', () => {
    test('should change month when prev/next arrows are pressed', () => {
      const {
        getByTestId,
        getByText
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      const touchable = getByTestId('datepicker-touchable');
      _testUtils.fireEvent.press(touchable);
      const currentMonth = getByText(/January|February|March|April|May|June|July|August|September|October|November|December/).props.children;
      _testUtils.fireEvent.press(getByTestId('datepicker-header-next'));
      const nextMonth = getByText(/January|February|March|April|May|June|July|August|September|October|November|December/).props.children;
      expect(nextMonth).not.toBe(currentMonth);
      _testUtils.fireEvent.press(getByTestId('datepicker-header-prev'));
      const prevMonth = getByText(/January|February|March|April|May|June|July|August|September|October|November|December/).props.children;
      expect(prevMonth).toBe(currentMonth);
    });
    test('should open month picker when month button is pressed', () => {
      const {
        getByTestId,
        toJSON
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-month-select'));
      expect(toJSON()).toMatchSnapshot();
    });
    test('should open year picker when year button is pressed', () => {
      const {
        getByTestId,
        toJSON
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      expect(toJSON()).toMatchSnapshot();
    });
    test('should select month from month picker', () => {
      const {
        getByTestId,
        getByText
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-month-select'));
      _testUtils.fireEvent.press(getByTestId('datepicker-month-3'));
      expect(getByText('March')).toBeTruthy();
    });
    test('should select year from year picker', () => {
      const {
        getByTestId,
        getByText
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      _testUtils.fireEvent.press(getByTestId('datepicker-year-2026'));
      expect(getByText('2026')).toBeTruthy();
    });
    test('should navigate between years in MonthPicker', () => {
      const {
        getByTestId,
        getByText
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-month-select'));
      const yearBefore = getByText(/\d{4}/).props.children;
      _testUtils.fireEvent.press(getByTestId('datepicker-header-next'));
      const yearAfter = getByText(/\d{4}/).props.children;
      expect(Number(yearAfter)).toBe(Number(yearBefore) + 1);
      _testUtils.fireEvent.press(getByTestId('datepicker-header-prev'));
      const yearBack = getByText(/\d{4}/).props.children;
      expect(Number(yearBack)).toBe(Number(yearBefore));
    });
    test('should navigate between year ranges in YearPicker', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        minYear: 2020,
        maxYear: 2030
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      expect(getByTestId('datepicker-year-2020')).toBeTruthy();
      expect(getByTestId('datepicker-year-2030')).toBeTruthy();
      _testUtils.fireEvent.press(getByTestId('datepicker-header-next'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-prev'));
      expect(getByTestId('datepicker-year-2020')).toBeTruthy();
      expect(getByTestId('datepicker-year-2030')).toBeTruthy();
    });
    test('should handle complete calendar navigation flow', () => {
      const {
        getByTestId,
        getByText
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-next'));
      expect(getByText(/January|February|March|April|May|June|July|August|September|October|November|December/)).toBeTruthy();
      _testUtils.fireEvent.press(getByTestId('datepicker-header-prev'));
      expect(getByText(/January|February|March|April|May|June|July|August|September|October|November|December/)).toBeTruthy();
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      expect(getByTestId('datepicker-year-2026')).toBeTruthy();
      _testUtils.fireEvent.press(getByTestId('datepicker-year-2026'));
      expect(getByText('2026')).toBeTruthy();
    });
    test('should handle month navigation with year constraints', () => {
      const {
        getByTestId,
        toJSON
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        minYear: 2020,
        maxYear: 2030
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-month-select'));
      _testUtils.fireEvent.press(getByTestId('datepicker-month-12'));
      expect(toJSON()).toMatchSnapshot();
      _testUtils.fireEvent.press(getByTestId('datepicker-header-next'));
      expect(toJSON()).toMatchSnapshot();
    });
    test('should handle previous/next month navigation', () => {
      const {
        getByTestId,
        getByText
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      const initialMonth = getByText(/January|February|March|April|May|June|July|August|September|October|November|December/).props.children;
      _testUtils.fireEvent.press(getByTestId('datepicker-header-next'));
      const nextMonth = getByText(/January|February|March|April|May|June|July|August|September|October|November|December/).props.children;
      expect(nextMonth).not.toBe(initialMonth);
      _testUtils.fireEvent.press(getByTestId('datepicker-header-prev'));
      const prevMonth = getByText(/January|February|March|April|May|June|July|August|September|October|November|December/).props.children;
      expect(prevMonth).toBe(initialMonth);
    });
  });
  describe('Integration tests', () => {
    test('should handle month and year selection flow', () => {
      const {
        getByTestId,
        getByText
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-month-select'));
      _testUtils.fireEvent.press(getByTestId('datepicker-month-3'));
      expect(getByText('March')).toBeTruthy();
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      _testUtils.fireEvent.press(getByTestId('datepicker-year-2026'));
      expect(getByText('2026')).toBeTruthy();
    });
    test('should handle complete date selection flow', () => {
      const onChange = jest.fn();
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        onChange: onChange
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-month-select'));
      _testUtils.fireEvent.press(getByTestId('datepicker-month-3'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      _testUtils.fireEvent.press(getByTestId('datepicker-year-2026'));
      const timestamp = getTimestamp(2026, 2, 15);
      const dateButton = getByTestId(`datepicker-datepicker-day-${timestamp}`);
      _testUtils.fireEvent.press(dateButton);
      _testUtils.fireEvent.press(getByTestId('datepicker-header-select'));
      expect(onChange).toHaveBeenCalledWith('2026-03-15');
    });
    test('should handle multiple date selection with navigation', () => {
      const onChange = jest.fn();
      const {
        getByTestId,
        getAllByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        multiple: true,
        format: "yyyy-MM-dd",
        onChange: onChange
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-month-select'));
      _testUtils.fireEvent.press(getByTestId('datepicker-month-3'));
      const startTimestamp = getTimestamp(2025, 2, 15);
      const endTimestamp = getTimestamp(2025, 2, 20);
      try {
        const startDateButton = getByTestId(`datepicker-datepicker-day-${startTimestamp}`);
        const endDateButton = getByTestId(`datepicker-datepicker-day-${endTimestamp}`);
        _testUtils.fireEvent.press(startDateButton);
        _testUtils.fireEvent.press(endDateButton);
        _testUtils.fireEvent.press(getByTestId('datepicker-header-select'));
        expect(onChange).toHaveBeenCalledWith('2025-03-15 - 2025-03-20');
      } catch (error) {
        const dateButtons = getAllByTestId(/datepicker-datepicker-day-/);
        if (dateButtons.length >= 2) {
          _testUtils.fireEvent.press(dateButtons[0]);
          _testUtils.fireEvent.press(dateButtons[1]);
          _testUtils.fireEvent.press(getByTestId('datepicker-header-select'));
          expect(onChange).toHaveBeenCalled();
        }
      }
    });
  });
  describe('Edge cases and error handling', () => {
    test('should handle context error when used outside provider', () => {
      const TestComponent = () => {
        const context = (0, _DatePickerContext.useDatePickerContext)();
        return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
          children: context.value
        });
      };
      expect(() => (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(TestComponent, {}))).toThrow('useDatePickerContext must be used within a DatePickerProvider');
    });
    test('should handle invalid date format gracefully', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        value: "invalid-format"
      }));
      expect(getByTestId('datepicker-input').props.value).toBe('invalid-format');
    });
    test('should handle empty disableDates array', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        disableDates: []
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
    test('should handle null disableDates', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        disableDates: undefined
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
    test('should handle extreme minYear and maxYear values', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        minYear: 1900,
        maxYear: 2100
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
    test('should handle same minYear and maxYear', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        minYear: 2025,
        maxYear: 2025
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      expect(getByTestId('datepicker-year-2025')).toBeTruthy();
    });
  });
  describe('Context edge cases', () => {
    test('should handle date range with same start and end date', () => {
      const onChange = jest.fn();
      const {
        getByTestId,
        getAllByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        multiple: true,
        onChange: onChange
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      const dateButtons = getAllByTestId(/datepicker-datepicker-day-/);
      if (dateButtons.length > 0) {
        _testUtils.fireEvent.press(dateButtons[0]);
        _testUtils.fireEvent.press(dateButtons[0]);
        _testUtils.fireEvent.press(getByTestId('datepicker-header-select'));
        expect(onChange).toHaveBeenCalled();
      }
    });
    test('should handle selection mode switching', () => {
      const onChange = jest.fn();
      const {
        getByTestId,
        getAllByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        multiple: true,
        onChange: onChange
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      const dateButtons = getAllByTestId(/datepicker-datepicker-day-/);
      if (dateButtons.length >= 3) {
        _testUtils.fireEvent.press(dateButtons[0]);
        _testUtils.fireEvent.press(dateButtons[1]);
        _testUtils.fireEvent.press(dateButtons[2]);
        _testUtils.fireEvent.press(getByTestId('datepicker-header-select'));
        expect(onChange).toHaveBeenCalled();
      }
    });
    test('should handle year range navigation with minYear constraint', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        minYear: 2020
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-prev'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-prev'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
    test('should handle year range navigation with maxYear constraint', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        maxYear: 2030
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-next'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-next'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
    test('should handle month selection with year constraints', () => {
      const {
        getByTestId,
        toJSON
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        minYear: 2020,
        maxYear: 2030
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-month-select'));
      expect(toJSON()).toMatchSnapshot();
      _testUtils.fireEvent.press(getByTestId('datepicker-month-1'));
      expect(toJSON()).toMatchSnapshot();
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
  });
  describe('Format handling', () => {
    test('should handle custom date format', () => {
      const onChange = jest.fn();
      const {
        getByTestId,
        getAllByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        format: "dd/MM/yyyy",
        onChange: onChange
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      const dateButtons = getAllByTestId(/datepicker-datepicker-day-/);
      if (dateButtons.length > 0) {
        _testUtils.fireEvent.press(dateButtons[0]);
        _testUtils.fireEvent.press(getByTestId('datepicker-header-select'));
        expect(onChange).toHaveBeenCalled();
      }
    });
    test('should handle multiple selection with custom format', () => {
      const onChange = jest.fn();
      const {
        getByTestId,
        getAllByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        multiple: true,
        format: "dd/MM/yyyy",
        onChange: onChange
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      const dateButtons = getAllByTestId(/datepicker-datepicker-day-/);
      if (dateButtons.length >= 2) {
        _testUtils.fireEvent.press(dateButtons[0]);
        _testUtils.fireEvent.press(dateButtons[1]);
        _testUtils.fireEvent.press(getByTestId('datepicker-header-select'));
        expect(onChange).toHaveBeenCalled();
      }
    });
  });
  describe('YearPicker specific tests', () => {
    test('should handle year selection with minYear constraint', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        minYear: 2020
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      expect(getByTestId('datepicker-year-2020')).toBeTruthy();
    });
    test('should handle year selection with maxYear constraint', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        maxYear: 2030
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      expect(getByTestId('datepicker-year-2030')).toBeTruthy();
    });
    test('should handle year range navigation with constraints', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        minYear: 2020,
        maxYear: 2030
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-next'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-prev'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
    test('should handle year selection and return to calendar', () => {
      const {
        getByTestId,
        getByText
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      _testUtils.fireEvent.press(getByTestId('datepicker-year-2026'));
      expect(getByText('2026')).toBeTruthy();
    });
  });
  describe('MonthPicker specific tests', () => {
    test('should handle month selection with year constraints', () => {
      const {
        getByTestId,
        toJSON
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        minYear: 2020,
        maxYear: 2030
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-month-select'));
      expect(toJSON()).toMatchSnapshot();
      _testUtils.fireEvent.press(getByTestId('datepicker-month-1'));
      expect(toJSON()).toMatchSnapshot();
    });
    test('should handle month navigation with year boundaries', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-month-select'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-next'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-prev'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
    test('should handle month selection and return to calendar', () => {
      const {
        getByTestId,
        getByText
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-month-select'));
      _testUtils.fireEvent.press(getByTestId('datepicker-month-3'));
      expect(getByText('March')).toBeTruthy();
    });
  });
  describe('CalendarWrapper specific tests', () => {
    test('should handle calendar data updates', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-next'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
    test('should handle firstDayOfWeek changes', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        firstDayOfWeek: 0
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      expect(getByTestId('datepicker-datepicker-header-0-text')).toBeTruthy();
    });
    test('should handle custom weekday names', () => {
      const customWeekdays = ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'];
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        nameOfWeekdays: customWeekdays
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      expect(getByTestId('datepicker-datepicker-header-0-text')).toBeTruthy();
    });
    test('should handle disabled dates in calendar', () => {
      const disableDates = ['2025-01-15', '2025-01-16'];
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        disableDates: disableDates
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
    test('should handle previous/next month navigation', () => {
      const {
        getByTestId,
        getByText
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      const initialMonth = getByText(/January|February|March|April|May|June|July|August|September|October|November|December/).props.children;
      _testUtils.fireEvent.press(getByTestId('datepicker-header-next'));
      const nextMonth = getByText(/January|February|March|April|May|June|July|August|September|October|November|December/).props.children;
      expect(nextMonth).not.toBe(initialMonth);
      _testUtils.fireEvent.press(getByTestId('datepicker-header-prev'));
      const prevMonth = getByText(/January|February|March|April|May|June|July|August|September|October|November|December/).props.children;
      expect(prevMonth).toBe(initialMonth);
    });
  });
  describe('DisableMonths', () => {
    test('should disable specified months in month picker', () => {
      const disableMonths = [0, 1, 2];
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        disableMonths: disableMonths
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-month-select'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
    test('should not allow selection of disabled months', () => {
      const onChange = jest.fn();
      const disableMonths = [0];
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        disableMonths: disableMonths,
        onChange: onChange
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-month-select'));
      _testUtils.fireEvent.press(getByTestId('datepicker-month-1'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
    test('should allow selection of enabled months', () => {
      const onChange = jest.fn();
      const disableMonths = [0, 1];
      const {
        getByTestId,
        getByText
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        disableMonths: disableMonths,
        onChange: onChange
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-month-select'));
      _testUtils.fireEvent.press(getByTestId('datepicker-month-3'));
      expect(getByText('March')).toBeTruthy();
    });
    test('should handle empty disableMonths array', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        disableMonths: []
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-month-select'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
    test('should handle null disableMonths', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        disableMonths: undefined
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-month-select'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
    test('should handle large disableMonths array efficiently', () => {
      const largeDisableMonths = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11];
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        disableMonths: largeDisableMonths
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-month-select'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
  });
  describe('DisableYears', () => {
    test('should disable specified years in year picker', () => {
      const disableYears = [2020, 2021, 2022];
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        disableYears: disableYears
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
    test('should not allow selection of disabled years', () => {
      const onChange = jest.fn();
      const disableYears = [2020];
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        disableYears: disableYears,
        onChange: onChange
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      _testUtils.fireEvent.press(getByTestId('datepicker-year-2020'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
    test('should allow selection of enabled years', () => {
      const onChange = jest.fn();
      const disableYears = [2020, 2021];
      const {
        getByTestId,
        getByText
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        disableYears: disableYears,
        onChange: onChange
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      _testUtils.fireEvent.press(getByTestId('datepicker-year-2022'));
      expect(getByText('2022')).toBeTruthy();
    });
    test('should handle empty disableYears array', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        disableYears: []
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
    test('should handle null disableYears', () => {
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        disableYears: undefined
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
    test('should handle large disableYears array efficiently', () => {
      const largeDisableYears = Array.from({
        length: 20
      }, (_, i) => 2020 + i);
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        disableYears: largeDisableYears
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
    test('should work with minYear and maxYear constraints', () => {
      const disableYears = [2022, 2023];
      const {
        getByTestId
      } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_DatePicker.default, {
        ...defaultProps,
        disableYears: disableYears,
        minYear: 2020,
        maxYear: 2030
      }));
      _testUtils.fireEvent.press(getByTestId('datepicker-touchable'));
      _testUtils.fireEvent.press(getByTestId('datepicker-header-year-select'));
      expect(getByTestId('datepicker-wrapper')).toBeTruthy();
    });
  });
});
//# sourceMappingURL=DatePicker.test.js.map