"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useDatePickerContext = exports.DatePickerProvider = void 0;
var _react = _interopRequireWildcard(require("react"));
var _utils = require("./utils");
var _constants = require("./constants");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const DatePickerContext = /*#__PURE__*/(0, _react.createContext)(undefined);
const DatePickerProvider = ({
  children,
  value = null,
  nameOfWeekdays = _constants.DEFAULT_NAME_OF_WEEKDAYS,
  nameOfMonths = _constants.DEFAULT_NAME_OF_MONTHS,
  minYear = _constants.DEFAULT_MIN_YEAR,
  maxYear = _constants.DEFAULT_MAX_YEAR,
  firstDayOfWeek,
  testID,
  onChange: onChangeProp,
  disableDates = [],
  multiple = false,
  format,
  disableMonths,
  disableYears
}) => {
  const [date, setDate] = (0, _react.useState)((0, _utils.getDayFromDate)((0, _utils.getDateFromString)(value || '', format)));
  const [dateRange, setDateRange] = (0, _react.useState)((0, _utils.getDayFromDateRange)(value, format));
  const [selectionMode, setSelectionMode] = (0, _react.useState)('startDate');
  const [visible, setVisible] = (0, _react.useState)(false);
  const [showPickerType, setShowPickerType] = (0, _react.useState)(_constants.ShowPickerType.NONE);
  const [calendarData, setCalendarData] = (0, _react.useState)((0, _utils.getCurrentMonthCalendar)({
    nameOfMonths,
    nameOfWeekdays,
    firstDayOfWeek
  }));
  const [yearRange, setYearRange] = (0, _react.useState)({
    min: minYear && minYear > calendarData.year - _constants.DEFAULT_YEAR_OFFSET ? minYear : calendarData.year - _constants.DEFAULT_YEAR_OFFSET,
    max: maxYear && maxYear < calendarData.year + _constants.DEFAULT_YEAR_OFFSET ? maxYear : calendarData.year + _constants.DEFAULT_YEAR_OFFSET
  });
  const handleOpen = (0, _react.useCallback)(() => setVisible(true), []);
  const handleClose = (0, _react.useCallback)(() => setVisible(false), []);
  const updateDateRange = (0, _react.useCallback)(newDate => {
    if (!dateRange) {
      setDateRange({
        startDate: newDate,
        endDate: newDate
      });
      setSelectionMode('endDate');
      return;
    }
    const {
      startDate,
      endDate
    } = dateRange;
    const newTimestamp = newDate.timestamp || 0;
    const startTimestamp = startDate.timestamp || 0;
    const endTimestamp = endDate.timestamp || 0;
    if (selectionMode === 'startDate') {
      if (newTimestamp > endTimestamp) {
        setDateRange({
          startDate: endDate,
          endDate: newDate
        });
      } else {
        setDateRange({
          startDate: newDate,
          endDate
        });
      }
      setSelectionMode('endDate');
    } else {
      if (newTimestamp < startTimestamp) {
        setDateRange({
          startDate: newDate,
          endDate: startDate
        });
      } else {
        setDateRange({
          startDate,
          endDate: newDate
        });
      }
      setSelectionMode('startDate');
    }
  }, [dateRange, selectionMode]);
  const onSelectDate = (0, _react.useCallback)(selectedDate => {
    const isOutOfRange = selectedDate.year < minYear || selectedDate.year > maxYear;
    if (isOutOfRange) {
      return;
    }
    if (selectedDate.isPrevMonth || selectedDate.isNextMonth) {
      const currentCalendar = (0, _utils.getMonthCalendar)({
        year: selectedDate.year,
        month: selectedDate.month,
        nameOfMonths,
        nameOfWeekdays,
        firstDayOfWeek
      });
      setCalendarData(currentCalendar);
    }
    if (multiple) {
      updateDateRange(selectedDate);
    } else {
      setDate(selectedDate);
    }
  }, [multiple, updateDateRange, nameOfMonths, nameOfWeekdays, firstDayOfWeek, minYear, maxYear]);
  const onChange = (0, _react.useCallback)(() => {
    if (multiple && dateRange) {
      const startDate = (0, _utils.formatDate)((0, _utils.createDate)(dateRange.startDate.year, dateRange.startDate.month, dateRange.startDate.day), format);
      const endDate = (0, _utils.formatDate)((0, _utils.createDate)(dateRange.endDate.year, dateRange.endDate.month, dateRange.endDate.day), format);
      const rangeString = `${startDate} - ${endDate}`;
      onChangeProp?.(rangeString);
    } else if (!multiple && date) {
      const formattedDate = (0, _utils.formatDate)((0, _utils.createDate)(date.year, date.month, date.day), format);
      onChangeProp?.(formattedDate || '');
    }
    setVisible(false);
  }, [multiple, dateRange, date, onChangeProp, format]);
  const onPressPrev = (0, _react.useCallback)(() => {
    if (showPickerType === _constants.ShowPickerType.YEAR) {
      const offset = minYear && yearRange.min - minYear < _constants.DEFAULT_YEAR_RANGE ? yearRange.min - minYear : _constants.DEFAULT_YEAR_RANGE;
      setYearRange(prev => ({
        min: prev.min - offset,
        max: prev.max - offset
      }));
    } else if (showPickerType === _constants.ShowPickerType.MONTH) {
      setCalendarData(prev => ({
        ...prev,
        year: minYear && prev.year - 1 < minYear ? minYear : prev.year - 1
      }));
    } else {
      if (calendarData.month === 0 && calendarData.year - 1 < minYear) {
        return;
      }
      setCalendarData((0, _utils.changeMonthCalendar)({
        year: calendarData.year,
        month: calendarData.month - 1,
        nameOfMonths,
        nameOfWeekdays,
        firstDayOfWeek
      }));
    }
  }, [showPickerType, minYear, yearRange, calendarData, nameOfMonths, nameOfWeekdays, firstDayOfWeek]);
  const onPressNext = (0, _react.useCallback)(() => {
    if (showPickerType === _constants.ShowPickerType.YEAR) {
      const offset = maxYear && maxYear - yearRange.max < _constants.DEFAULT_YEAR_RANGE ? maxYear - yearRange.max : _constants.DEFAULT_YEAR_RANGE;
      setYearRange(prev => ({
        min: prev.min + offset,
        max: prev.max + offset
      }));
    } else if (showPickerType === _constants.ShowPickerType.MONTH) {
      setCalendarData(prev => ({
        ...prev,
        year: maxYear && prev.year + 1 > maxYear ? maxYear : prev.year + 1
      }));
    } else {
      if (calendarData.month === 11 && calendarData.year + 1 > maxYear) {
        return;
      }
      setCalendarData((0, _utils.changeMonthCalendar)({
        year: calendarData.year,
        month: calendarData.month + 1,
        nameOfMonths,
        nameOfWeekdays,
        firstDayOfWeek
      }));
    }
  }, [showPickerType, maxYear, yearRange, calendarData, nameOfMonths, nameOfWeekdays, firstDayOfWeek]);
  const contextValue = _react.default.useMemo(() => ({
    value,
    visible,
    date,
    nameOfWeekdays,
    nameOfMonths,
    minYear,
    maxYear,
    firstDayOfWeek,
    testID,
    handleOpen,
    handleClose,
    onSelectDate,
    onChange,
    showPickerType,
    setShowPickerType,
    calendarData,
    setCalendarData,
    yearRange,
    setYearRange,
    onPressPrev,
    onPressNext,
    multiple,
    dateRange,
    selectionMode,
    disableDates,
    disableMonths,
    disableYears
  }), [value, visible, date, nameOfWeekdays, nameOfMonths, minYear, maxYear, firstDayOfWeek, testID, handleOpen, handleClose, onSelectDate, onChange, showPickerType, setShowPickerType, calendarData, setCalendarData, yearRange, setYearRange, onPressPrev, onPressNext, multiple, dateRange, selectionMode, disableDates, disableMonths, disableYears]);
  _react.default.useEffect(() => {
    if (visible) {
      if (multiple) {
        setDateRange((0, _utils.getDayFromDateRange)(value, format));
      } else {
        setDate((0, _utils.getDayFromDate)((0, _utils.getDateFromString)(value || '', format)));
      }
    }
  }, [visible, value, multiple, format]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(DatePickerContext.Provider, {
    value: contextValue,
    children: children
  });
};
exports.DatePickerProvider = DatePickerProvider;
const useDatePickerContext = () => {
  const context = (0, _react.useContext)(DatePickerContext);
  if (!context) {
    throw new Error('useDatePickerContext must be used within a DatePickerProvider');
  }
  return context;
};
exports.useDatePickerContext = useDatePickerContext;
//# sourceMappingURL=DatePickerContext.js.map