"use strict";

var _react = _interopRequireDefault(require("react"));
var _theme = _interopRequireDefault(require("../../theme"));
var _testUtils = require("../../test-utils");
var _Icon = _interopRequireDefault(require("./Icon"));
var _list = require("./list");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
describe('Icon', () => {
  beforeEach(() => {
    jest.spyOn(console, 'warn').mockImplementation(() => ({}));
  });
  test('should render icon correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Icon.default, {
      name: "academy"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render default size correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Icon.default, {
      testID: "icon",
      name: "confetti"
    }));
    const iconComponent = getByTestId('icon');

    // then
    expect(iconComponent.props.width).toBe(_theme.default.iconSizeVariants.l);
    expect(iconComponent.props.height).toBe(_theme.default.iconSizeVariants.l);
  });
  test('should render given size correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Icon.default, {
      testID: "icon",
      name: "confetti",
      size: "2xs"
    }));
    const iconComponent = getByTestId('icon');

    // then
    expect(iconComponent.props.width).toBe(_theme.default.iconSizeVariants['2xs']);
    expect(iconComponent.props.height).toBe(_theme.default.iconSizeVariants['2xs']);
  });
  test('should render default color correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Icon.default, {
      testID: "icon",
      name: "confetti"
    }));
    const iconComponent = getByTestId('icon');

    // then
    expect(iconComponent.props.fill).toBe('#273142');
  });
  test('should render given color correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Icon.default, {
      testID: "icon",
      name: "confetti",
      color: "successKey"
    }));
    const iconComponent = getByTestId('icon');

    // then
    expect(iconComponent.props.fill).toBe(_theme.default.colors.successKey);
  });
  test('should render invalid color correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Icon.default, {
      testID: "icon",
      name: "confetti",
      color: "testtest"
    }));
    const iconComponent = getByTestId('icon');

    // then
    expect(iconComponent.props.fill).not.toBe(_theme.default.colors.neutralDarker);
    expect(iconComponent.props.fill).not.toBe('#273142');
  });
  test('should render iconList correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Icon.default, {
      testID: "icon",
      name: _list.iconList[6]
    }));
    const iconComponent = getByTestId('icon');

    // then
    expect(iconComponent).toBeTruthy();
  });
  test('should not render icon component without name', () => {
    // when
    //@ts-ignore
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Icon.default, {
      testID: "icon"
    }));
    const iconComponent = queryByTestId('icon');

    // then
    expect(iconComponent).toBeNull();
  });
});
//# sourceMappingURL=Icon.test.js.map