"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _theme = _interopRequireDefault(require("../../theme"));
var _Box = _interopRequireDefault(require("../Box/Box"));
var _InputIcon = require("./InputIcon");
var _InputLabel = require("./InputLabel");
var _InputHelpText = require("./InputHelpText");
var _hooks = require("./hooks");
var _utils = require("./utils");
var _restyle = require("@ergenekonyigit/restyle");
var _Text = _interopRequireDefault(require("../Text/Text"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const sizeVariant = (0, _restyle.createVariant)({
  property: 'size',
  themeKey: 'inputSizeVariants'
});
const BaseInput = (0, _restyle.createRestyleComponent)([_restyle.layout, _restyle.spacing, _restyle.border, _restyle.backgroundColor, _restyle.position, sizeVariant], _reactNative.TextInput);
const isRTL = _reactNative.I18nManager.isRTL;
const Input = /*#__PURE__*/(0, _react.forwardRef)(({
  size = 'large',
  label,
  subLabel = '',
  labelFixed,
  placeholder,
  helpText,
  errorText,
  successText,
  icon,
  success = false,
  error = false,
  secureTextEntry = false,
  required = false,
  disabled = false,
  editable = true,
  easing = _reactNative.Easing.inOut(_reactNative.Easing.ease),
  testID = 'input',
  leadingText,
  trailingText,
  ...rest
}, ref) => {
  const [focused, setFocused] = _react.default.useState(false);
  const [errorState, setErrorState] = _react.default.useState(false);
  const [successState, setSuccessState] = _react.default.useState(false);
  const [variantIconName, setVariantIconName] = _react.default.useState(null);
  const innerRef = (0, _hooks.useInputRef)();
  const {
    value,
    isControlled,
    setUncontrolledValue
  } = (0, _hooks.useInputValue)({
    value: rest.value,
    defaultValue: rest.defaultValue
  });
  const placeholderText = (0, _utils.getPlaceholderText)({
    label,
    subLabel,
    labelFixed,
    placeholder,
    value,
    focused
  });
  const borderColor = (0, _utils.getBorderColor)({
    focused,
    successState,
    errorState
  });
  const inputHeight = {
    small: _theme.default.inputSizeVariants.small.height,
    medium: _theme.default.inputSizeVariants.medium.height,
    large: _theme.default.inputSizeVariants.large.height
  }[size];
  const {
    passwordVisibility,
    setPasswordVisibility,
    passwordVisibilityIcon,
    handlePasswordVisibility
  } = (0, _hooks.useTogglePasswordVisibility)(secureTextEntry);
  (0, _react.useEffect)(() => {
    setPasswordVisibility(secureTextEntry);
  }, [secureTextEntry, setPasswordVisibility]);
  const {
    startAnimation,
    stopAnimation,
    animatedViewProps,
    animatedTextProps
  } = (0, _hooks.useOutlineLabelVisibility)({
    theme: _theme.default,
    easing,
    inputHeight,
    focused,
    value,
    disabled,
    helpText,
    errorText,
    successText,
    errorState,
    successState
  });
  (0, _react.useEffect)(() => {
    setErrorState(error);
    setSuccessState(success);
    if (icon) {
      setVariantIconName(null);
    } else if (error) {
      setVariantIconName('close-fill');
    } else if (success) {
      setVariantIconName('check-fill');
    }
  }, [error, success, icon]);
  const handleFocus = async e => {
    if (disabled || !editable) {
      return;
    }
    await startAnimation();
    setFocused(true);
    setVariantIconName(null);
    setErrorState(false);
    setSuccessState(false);
    rest.onFocus?.(e);
  };
  const handleBlur = async e => {
    if (disabled || !editable) {
      return;
    }
    if (!value) {
      await stopAnimation();
    }
    setFocused(false);
    rest.onBlur?.(e);
  };
  const handleChangeText = nextValue => {
    if (disabled || !editable) {
      return;
    }
    if (!isControlled) {
      setUncontrolledValue(nextValue);
    }
    rest.onChangeText?.(nextValue);
  };
  _react.default.useImperativeHandle(ref, () => ({
    focus: () => innerRef.current?.focus(),
    clear: () => innerRef.current?.clear(),
    setNativeProps: args => innerRef.current?.setNativeProps(args),
    isFocused: () => innerRef.current?.isFocused() || false,
    blur: () => innerRef.current?.blur()
  }));
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Box.default, {
    py: '2xs',
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_InputLabel.InputLabel, {
      label: label,
      subLabel: ` ${subLabel} `,
      labelFixed: labelFixed,
      errorState: errorState,
      successState: successState,
      animatedViewProps: animatedViewProps,
      animatedTextProps: animatedTextProps,
      inputHeight: inputHeight,
      required: required
    }), /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Box.default, {
      flexDirection: "row",
      alignItems: "center",
      borderWidth: 1,
      borderRadius: 'm',
      borderColor: borderColor,
      backgroundColor: disabled ? 'neutralLightest' : 'neutralFull',
      px: "m",
      zIndex: "layer_0",
      accessibilityLabel: `${testID}-box`,
      testID: `${testID}-box`,
      children: [leadingText && !disabled ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
        mr: "2xs",
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
          color: "neutralDark",
          variant: "subtitle2Medium",
          accessibilityLabel: "input-leading-text",
          children: leadingText
        })
      }) : null, /*#__PURE__*/(0, _jsxRuntime.jsx)(BaseInput, {
        ...rest,
        flex: 1,
        ref: innerRef,
        multiline: false,
        height: inputHeight,
        bg: "transparent",
        onFocus: handleFocus,
        onBlur: handleBlur,
        placeholder: placeholderText,
        placeholderTextColor: _theme.default.colors.neutralLight,
        secureTextEntry: passwordVisibility,
        onChangeText: handleChangeText,
        value: value,
        disabled: disabled,
        editable: !disabled,
        accessibilityLabel: testID,
        testID: testID,
        textAlign: isRTL ? 'right' : 'left'
      }), trailingText ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
        ml: "m",
        mr: icon ? 'm' : 'none',
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
          color: "neutralDark",
          variant: "subtitle2Medium",
          accessibilityLabel: "input-trailing-text",
          children: trailingText
        })
      }) : null, /*#__PURE__*/(0, _jsxRuntime.jsx)(_InputIcon.InputIcon, {
        secureTextEntry: secureTextEntry,
        icon: icon,
        variantIconName: variantIconName,
        focused: focused,
        successState: successState,
        errorState: errorState,
        passwordVisibilityIcon: passwordVisibilityIcon,
        handlePasswordVisibility: handlePasswordVisibility
      })]
    }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_InputHelpText.InputHelpText, {
      helpText: helpText,
      errorState: errorState,
      errorText: errorText,
      successState: successState,
      successText: successText
    })]
  });
});
var _default = exports.default = Input;
//# sourceMappingURL=Input.js.map