"use strict";

var _react = _interopRequireDefault(require("react"));
var _reactTestRenderer = require("react-test-renderer");
var _testUtils = require("../../test-utils");
var _theme = _interopRequireDefault(require("../../theme"));
var _Input = _interopRequireDefault(require("./Input"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
describe('Input', () => {
  test('should render input correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      label: "label"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render label fixed input correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      label: "label",
      labelFixed: true,
      placeholder: "placeholder"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render disabled input correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      disabled: true,
      label: "label"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render input with help text correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      label: "label",
      helpText: "helpText"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render input with icon correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      label: "label",
      icon: "confetti"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render input with leadingText correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      label: "label",
      leadingText: "%"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render input with trailingText correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      label: "label",
      trailingText: "\u20BA"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render input with error state correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      label: "label",
      error: true
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render input with error state and error text correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      label: "label",
      error: true,
      errorText: "errorText"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render input with success state correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      label: "label",
      success: true
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render input with success state and success text correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      label: "label",
      success: true,
      successText: "successText"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render input with small size correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      label: "label",
      size: "small"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render input with medium size correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      label: "label",
      size: "medium"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should focus input correctly', async () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      label: "label"
    }));

    // then
    expect(getByTestId('input-box').props.style[0].borderColor).toBe(_theme.default.colors.neutralLighter);

    // when
    (0, _testUtils.fireEvent)(getByTestId('input'), 'onFocus');

    // then
    await (0, _testUtils.waitFor)(() => {
      expect(getByTestId('input-box').props.style[0].borderColor).toBe(_theme.default.colors.primaryKey);
    });
  });
  test('should not focus and blur input when input is disabled', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      label: "label",
      disabled: true
    }));

    // then
    expect(getByTestId('input-box').props.style[0].borderColor).toBe(_theme.default.colors.neutralLighter);

    // when
    (0, _reactTestRenderer.act)(() => {
      const input = getByTestId('input');
      (0, _testUtils.fireEvent)(input, 'onFocus');
      (0, _testUtils.fireEvent)(input, 'onBlur');
    });

    // then
    expect(getByTestId('input-box').props.style[0].borderColor).toBe(_theme.default.colors.neutralLighter);
  });
  test('should blur input without value correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      label: "label"
    }));

    // then
    expect(getByTestId('input-box').props.style[0].borderColor).toBe(_theme.default.colors.neutralLighter);

    // when
    (0, _reactTestRenderer.act)(() => {
      const input = getByTestId('input');
      (0, _testUtils.fireEvent)(input, 'onFocus');
      (0, _testUtils.fireEvent)(input, 'onBlur');
    });

    // then
    expect(getByTestId('input-box').props.style[0].borderColor).toBe(_theme.default.colors.neutralLighter);
  });
  test('should blur input with value correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      label: "label",
      value: "value"
    }));

    // then
    expect(getByTestId('input-box').props.style[0].borderColor).toBe(_theme.default.colors.neutralLighter);

    // when
    (0, _reactTestRenderer.act)(() => {
      const input = getByTestId('input');
      (0, _testUtils.fireEvent)(input, 'onFocus');
      (0, _testUtils.fireEvent)(input, 'onBlur');
    });

    // then
    expect(getByTestId('input-box').props.style[0].borderColor).toBe(_theme.default.colors.neutralLighter);
  });
  test('should change text of input without value', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      label: "label"
    }));
    const input = getByTestId('input');
    _testUtils.fireEvent.changeText(input, 'e-mail@mail.com');

    // then
    expect(input.props.value).toBe('e-mail@mail.com');
  });
  test('should change text of input with value', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      label: "label",
      value: "value"
    }));
    const input = getByTestId('input');
    _testUtils.fireEvent.changeText(input, 'e-mail@mail.com');

    // then
    expect(input.props.value).toBe('value');
  });
  test('should not change text of input when input is disabled', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      label: "label",
      disabled: true
    }));
    const input = getByTestId('input');
    _testUtils.fireEvent.changeText(input, 'e-mail@mail.com');

    // then
    expect(input.props.value).not.toBe('e-mail@mail.com');
  });
  test('should change text of input when input has defaultValue', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      label: "label",
      defaultValue: "defaultValue"
    }));
    const input = getByTestId('input');
    _testUtils.fireEvent.changeText(input, 'e-mail@mail.com');

    // then
    expect(input.props.value).toBe('e-mail@mail.com');
  });
  test('should access inputs handle functions correctly', () => {
    // given
    const ref = /*#__PURE__*/_react.default.createRef();

    // when
    (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Input.default, {
      label: "label",
      ref: ref
    }));
    (0, _reactTestRenderer.act)(() => {
      ref.current?.focus();
      ref.current?.blur();
      ref.current?.clear();
      ref.current?.isFocused();
      ref.current?.setNativeProps({
        text: ''
      });
    });

    // then
    expect(ref.current?.focus).toBeTruthy();
  });
});
//# sourceMappingURL=Input.test.js.map