"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _Box = _interopRequireDefault(require("../Box/Box"));
var _reactNative = require("react-native");
var _portal = require("@gorhom/portal");
var _react = _interopRequireDefault(require("react"));
var _theme = _interopRequireDefault(require("../../theme"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const BaseModal = ({
  modalKey,
  justifyContent,
  p = 'l',
  accessible,
  accessibilityLabel,
  testID,
  children,
  header,
  actions,
  visible,
  duration = 200,
  closable = true,
  wrongPressThresholdMs = 1000,
  // 1 second
  closeButtonAction,
  borderBottomStartRadius,
  borderBottomEndRadius
}) => {
  const anim = _react.default.useRef(new _reactNative.Animated.Value(0)).current;
  const preventWrongPressToClose = _react.default.useRef(Date.now());
  _react.default.useEffect(() => {
    if (visible) {
      preventWrongPressToClose.current = Date.now();
      _reactNative.Animated.timing(anim, {
        toValue: 0.7,
        duration,
        useNativeDriver: true
      }).start();
    } else {
      anim.setValue(0);
    }
  }, [anim, duration, visible]);
  const close = _react.default.useCallback(() => {
    const threshold = preventWrongPressToClose.current + wrongPressThresholdMs;
    if (closable && threshold < Date.now()) {
      closeButtonAction?.();
    }
  }, [closable, closeButtonAction, wrongPressThresholdMs]);
  const testProps = _react.default.useMemo(() => {
    return {
      accessible: accessible,
      accessibilityLabel: accessibilityLabel ?? testID,
      testID: testID ?? accessibilityLabel
    };
  }, [testID, accessibilityLabel, accessible]);
  if (!visible || !children) {
    return null;
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_portal.Portal, {
    name: modalKey ?? 'base-modal',
    children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Box.default, {
      position: "absolute",
      justifyContent: justifyContent,
      p: p,
      top: 0,
      bottom: 0,
      left: 0,
      right: 0,
      testID: `${testProps.testID}-wrapper`,
      accessibilityLabel: `${testProps.accessibilityLabel}-wrapper`,
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Animated.View, {
        testID: `${testProps.testID}-overlay`,
        accessibilityLabel: `${testProps.testID}-overlay`,
        style: [styles.overlay, {
          opacity: anim
        }],
        onStartShouldSetResponder: () => true,
        onResponderRelease: close
      }), /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Box.default, {
        ...testProps,
        bg: "white",
        p: "m",
        borderRadius: 'l',
        borderBottomStartRadius: borderBottomStartRadius,
        borderBottomEndRadius: borderBottomEndRadius,
        style: styles.card,
        children: [header, /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
          testID: `${testProps.testID}-body`,
          accessibilityLabel: `${testProps.accessibilityLabel}-body`,
          bounces: false,
          showsVerticalScrollIndicator: true,
          children: children
        }), actions]
      })]
    })
  });
};
const styles = _reactNative.StyleSheet.create({
  card: {
    maxHeight: '90%'
  },
  overlay: {
    position: 'absolute',
    backgroundColor: _theme.default.colors.neutralDarker,
    opacity: 0.7,
    top: 0,
    bottom: 0,
    left: 0,
    right: 0
  }
});
var _default = exports.default = BaseModal;
//# sourceMappingURL=BaseModal.js.map