"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _Box = _interopRequireDefault(require("../Box/Box"));
var _Button = _interopRequireDefault(require("../Button/Button"));
var _Icon = _interopRequireDefault(require("../Icon/Icon"));
var _Text = _interopRequireDefault(require("../Text/Text"));
var _BaseModal = _interopRequireDefault(require("./BaseModal"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const Modal = ({
  visible,
  title,
  closable = true,
  modalKey,
  closeButtonAction,
  actionButtonProps,
  secondActionButtonProps,
  justifyContent = 'center',
  testID,
  accessibilityLabel,
  accessible = true,
  children,
  ...etc
}) => {
  const testProps = _react.default.useMemo(() => {
    return {
      accessible: accessible,
      accessibilityLabel: accessibilityLabel ?? testID,
      testID: testID ?? accessibilityLabel
    };
  }, [testID, accessibilityLabel, accessible]);
  const header = _react.default.useMemo(() => {
    if (!title && !closable) {
      return null;
    }
    return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Box.default, {
      flexDirection: "row",
      justifyContent: "space-between",
      alignItems: "flex-start",
      mb: "m",
      testID: `${testProps.testID}-header`,
      accessibilityLabel: `${testProps.accessibilityLabel}-header`,
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
        flex: 1,
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
          variant: "subtitle2Medium",
          testID: `${testProps.testID}-title`,
          numberOfLines: 2,
          textAlign: "left",
          children: title
        })
      }), closable && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.TouchableOpacity, {
        testID: `${testProps.testID}-close`,
        accessibilityLabel: `${testProps.accessibilityLabel}-close`,
        hitSlop: {
          left: 0,
          bottom: 0,
          top: 12,
          right: 12
        },
        onPress: closeButtonAction,
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
          p: "4xs",
          pl: "2xs",
          pb: "2xs",
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Icon.default, {
            name: "close",
            color: "neutralDarker",
            size: "xs"
          })
        })
      })]
    });
  }, [closeButtonAction, closable, testProps.accessibilityLabel, testProps.testID, title]);
  const actions = _react.default.useMemo(() => {
    if (!actionButtonProps && !secondActionButtonProps) {
      return null;
    }
    return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Box.default, {
      testID: `${testProps.testID}-actions-area`,
      accessibilityLabel: `${testProps.accessibilityLabel}-actions-area`,
      children: [actionButtonProps && /*#__PURE__*/(0, _jsxRuntime.jsx)(_Button.default, {
        mt: "m",
        filled: true,
        size: "l",
        variant: "primary",
        testID: `${testProps.testID}-action`,
        accessibilityLabel: `${testProps.accessibilityLabel}-action`,
        ...actionButtonProps
      }), secondActionButtonProps && /*#__PURE__*/(0, _jsxRuntime.jsx)(_Button.default, {
        mt: "m",
        filled: true,
        size: "l",
        variant: "secondary",
        testID: `${testProps.testID}-second-action`,
        accessibilityLabel: `${testProps.accessibilityLabel}-second-action`,
        ...secondActionButtonProps
      })]
    });
  }, [actionButtonProps, secondActionButtonProps, testProps.accessibilityLabel, testProps.testID]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_BaseModal.default, {
    ...etc,
    closeButtonAction: closeButtonAction,
    header: header,
    accessible: accessible,
    accessibilityLabel: accessibilityLabel,
    testID: testID,
    actions: actions,
    modalKey: modalKey,
    justifyContent: justifyContent,
    closable: closable,
    visible: visible,
    children: children
  });
};
var _default = exports.default = Modal;
//# sourceMappingURL=Modal.js.map