"use strict";

var _react = _interopRequireDefault(require("react"));
var _theme = _interopRequireDefault(require("../../theme"));
var _testUtils = require("../../test-utils");
var _RadioButton = _interopRequireDefault(require("./RadioButton"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
describe('RadioButton', () => {
  beforeEach(() => {});
  test('should render RadioButton correctly when selected is false', () => {
    // when
    const {
      toJSON,
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_RadioButton.default, {
      selected: false
    }));
    const radiobuttonComponent = getByTestId('selectbox');

    // then
    expect(toJSON()).toMatchSnapshot();
    expect(radiobuttonComponent.props.style[1][0].borderColor).toBe(_theme.default.colors.neutralLighter);
    expect(radiobuttonComponent.props.style[1][0].backgroundColor).toBe(_theme.default.colors.neutralFull);
  });
  test('should render RadioButton correctly when selected is true', () => {
    // when
    const {
      toJSON,
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_RadioButton.default, {
      selected: true
    }));
    const radiobuttonComponent = getByTestId('selectbox');

    // then
    expect(toJSON()).toMatchSnapshot();
    expect(radiobuttonComponent.props.style[1][0].borderColor).toBe(_theme.default.colors.primaryKey);
    expect(radiobuttonComponent.props.style[1][0].backgroundColor).toBe(_theme.default.colors.primaryKey);
  });
  test('should render RadioButton correctly when disable, selected is false', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_RadioButton.default, {
      disabled: true,
      selected: false
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render RadioButton correctly when disable, selected is true', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_RadioButton.default, {
      disabled: true,
      selected: true
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should press RadioButton', () => {
    // given
    const onPress = jest.fn();

    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_RadioButton.default, {
      selected: true,
      testID: "radioButton",
      onPress: onPress
    }));
    const radiobuttonComponent = getByTestId('radioButton');
    _testUtils.fireEvent.press(radiobuttonComponent);

    // then
    expect(onPress).toBeCalledTimes(1);
  });
  test('should not press radiobutton when disabled', () => {
    // given
    const onPress = jest.fn();

    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_RadioButton.default, {
      selected: true,
      disabled: true,
      testID: "radiobuttonbox",
      label: "lorem ipsum",
      onPress: onPress
    }));
    const radiobuttonComponent = getByTestId('radiobuttonbox');
    const radiobuttonLabelComponent = getByTestId('label');
    _testUtils.fireEvent.press(radiobuttonComponent);

    // then
    expect(onPress).not.toBeCalled();
    expect(radiobuttonLabelComponent.props.style[0].color).toBe(_theme.default.colors.neutralLighter);
  });
  test('should render without selectbox correctly', () => {
    // when
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_RadioButton.default, {
      selected: false
    }));
    const radiobuttonSelectbox = queryByTestId('selectbox');

    // then
    expect(radiobuttonSelectbox.props.style[1][0].backgroundColor).toBe(_theme.default.colors.neutralFull);
  });
  test('should render with label correctly when selected', () => {
    // when
    const {
      getByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_RadioButton.default, {
      selected: true,
      label: "lorem ipsum"
    }));
    const radiobuttonLabel = getByText('lorem ipsum');

    // then
    expect(radiobuttonLabel).toBeTruthy();
    expect(radiobuttonLabel.props.style[0].color).toBe(_theme.default.colors.primaryKey);
  });
  test('should render with label correctly when unselected', () => {
    // when
    const {
      getByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_RadioButton.default, {
      selected: false,
      label: "lorem ipsum"
    }));
    const radiobuttonLabel = getByText('lorem ipsum');

    // then
    expect(radiobuttonLabel).toBeTruthy();
    expect(radiobuttonLabel.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render without label correctly', () => {
    // when
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_RadioButton.default, {
      selected: true
    }));
    const radioButtonLabel = queryByTestId('');

    // then
    expect(radioButtonLabel).toBeFalsy();
  });
  test('should render with icon correctly when selected', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_RadioButton.default, {
      selected: true,
      flagIcon: "TR"
    }));
    const iconComponent = getByTestId('flag-icon');

    // then
    expect(iconComponent).toBeTruthy();
  });
  test('should render with icon correctly when unselected', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_RadioButton.default, {
      selected: false,
      flagIcon: "TR"
    }));
    const iconComponent = getByTestId('flag-icon');

    // then
    expect(iconComponent).toBeTruthy();
  });
  test('should render with icon correctly when disabled', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_RadioButton.default, {
      selected: false,
      disabled: true,
      flagIcon: "TR"
    }));
    const iconComponent = getByTestId('flag-icon');

    // then
    expect(iconComponent).toBeTruthy();
  });
  test('should render without icon correctly', () => {
    // when
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_RadioButton.default, {
      selected: true
    }));
    const iconComponent = queryByTestId('flag-icon');

    // then
    expect(iconComponent).toBeFalsy();
  });
});
//# sourceMappingURL=RadioButton.test.js.map