"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _theme = _interopRequireDefault(require("../../theme"));
var _Box = _interopRequireDefault(require("../Box/Box"));
var _Icon = _interopRequireDefault(require("../Icon/Icon"));
var _Text = _interopRequireDefault(require("../Text/Text"));
var _SelectBottomSheet = _interopRequireDefault(require("../SelectBottomSheet/SelectBottomSheet"));
var _InputLabel = require("../Input/InputLabel");
var _InputHelpText = require("../Input/InputHelpText");
var _hooks = require("../Input/hooks");
var _utils = require("../Input/utils");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const useSelectState = selectedOptions => {
  const [selectedValues, setSelectedValues] = (0, _react.useState)(Array.isArray(selectedOptions) ? selectedOptions : [selectedOptions]);
  const bottomSheetSelectionRef = (0, _react.useRef)([]);
  const resetSelections = (0, _react.useCallback)(() => {
    setSelectedValues([]);
  }, []);
  const updateSelections = (0, _react.useCallback)(newSelections => {
    setSelectedValues(newSelections);
  }, []);
  return {
    selectedValues,
    updateSelections,
    resetSelections,
    bottomSheetSelectionRef
  };
};
const useDisplayValue = props => {
  const {
    multiple,
    selectedOptionObjects,
    selectedValues,
    maxDisplayItems = 2
  } = props;
  const getDisplayValues = (0, _react.useCallback)(() => {
    if (selectedValues.length === 0) {
      return {
        visibleText: '',
        remainingCount: 0
      };
    }
    if (multiple) {
      const selectedLabels = selectedOptionObjects.map(option => option.label);
      if (selectedLabels.length <= maxDisplayItems) {
        return {
          visibleText: selectedLabels.join(', '),
          remainingCount: 0
        };
      } else {
        const visibleLabels = selectedLabels.slice(0, maxDisplayItems);
        const remainingCount = selectedLabels.length - maxDisplayItems;
        return {
          visibleText: visibleLabels.join(', '),
          remainingCount
        };
      }
    }
    return {
      visibleText: selectedOptionObjects.length > 0 ? selectedOptionObjects[0].label : '',
      remainingCount: 0
    };
  }, [selectedOptionObjects, multiple, selectedValues, maxDisplayItems]);
  return {
    getDisplayValues
  };
};
const useSortedOptions = props => {
  const {
    options,
    selectedValues,
    isBottomSheetVisible,
    wasCleared
  } = props;
  const originalOptionsRef = (0, _react.useRef)([]);
  (0, _react.useEffect)(() => {
    if (originalOptionsRef.current.length === 0) {
      originalOptionsRef.current = [...options];
    }
  }, [options]);
  return (0, _react.useMemo)(() => {
    if (wasCleared || !isBottomSheetVisible) {
      return options;
    }
    if (selectedValues.length === 0) {
      return options;
    }
    const selectedOptions = options.filter(option => selectedValues.includes(option.id));
    const unselectedOptions = options.filter(option => !selectedValues.includes(option.id));
    return [...selectedOptions, ...unselectedOptions];
  }, [options, selectedValues, isBottomSheetVisible, wasCleared]);
};
const Select = /*#__PURE__*/(0, _react.forwardRef)(({
  label,
  subLabel,
  labelFixed = false,
  placeholder = '',
  helpText,
  error = false,
  errorText,
  success = false,
  successText,
  required = false,
  disabled = false,
  size = 'medium',
  options = [],
  selectedOptions = [],
  testID = 'select',
  onSelect,
  bottomSheetTitle,
  closeButtonLabel = '',
  selectButtonLabel,
  multiple = true,
  maxVisibleItems = 6,
  ...rest
}, ref) => {
  const [focused, setFocused] = (0, _react.useState)(false);
  const [errorState, setErrorState] = (0, _react.useState)(error);
  const [successState, setSuccessState] = (0, _react.useState)(success);
  const [isBottomSheetVisible, setIsBottomSheetVisible] = (0, _react.useState)(false);
  const [wasCleared, setWasCleared] = (0, _react.useState)(false);
  const {
    selectedValues,
    updateSelections,
    resetSelections,
    bottomSheetSelectionRef
  } = useSelectState(selectedOptions);
  const selectedOptionObjects = (0, _react.useMemo)(() => options.filter(option => selectedValues.includes(option.id)), [options, selectedValues]);
  const sortedOptions = useSortedOptions({
    options,
    selectedValues,
    multiple,
    isBottomSheetVisible,
    wasCleared
  });
  const inputHeight = _theme.default.inputSizeVariants[size].height;
  const borderColor = (0, _react.useMemo)(() => (0, _utils.getBorderColor)({
    focused,
    successState,
    errorState
  }), [focused, successState, errorState]);
  const {
    getDisplayValues
  } = useDisplayValue({
    multiple,
    selectedOptionObjects,
    selectedValues,
    maxDisplayItems: 2
  });
  const {
    startAnimation,
    animatedViewProps,
    animatedTextProps
  } = (0, _hooks.useOutlineLabelVisibility)({
    theme: _theme.default,
    easing: _reactNative.Easing.inOut(_reactNative.Easing.ease),
    inputHeight,
    focused,
    value: getDisplayValues().visibleText || '',
    disabled,
    helpText,
    errorText,
    successText,
    errorState,
    successState
  });
  (0, _react.useEffect)(() => {
    setErrorState(error);
    setSuccessState(success);
  }, [error, success]);
  const openBottomSheet = (0, _react.useCallback)(async () => {
    if (disabled) {
      return;
    }
    await startAnimation();
    setFocused(true);
    bottomSheetSelectionRef.current = [...selectedValues];
    setWasCleared(false);
    setIsBottomSheetVisible(true);
  }, [disabled, startAnimation, selectedValues, bottomSheetSelectionRef]);
  const closeBottomSheet = (0, _react.useCallback)(() => {
    setIsBottomSheetVisible(false);
    setFocused(false);
  }, []);
  const confirmSelection = (0, _react.useCallback)(() => {
    const newSelections = [...bottomSheetSelectionRef.current];
    updateSelections(newSelections);
    if (onSelect) {
      onSelect(newSelections);
    }
    closeBottomSheet();
  }, [onSelect, closeBottomSheet, bottomSheetSelectionRef, updateSelections]);
  const handleClear = (0, _react.useCallback)(event => {
    event?.stopPropagation();
    resetSelections();
    if (onSelect) {
      onSelect([]);
    }
    setWasCleared(true);
  }, [onSelect, resetSelections]);
  const handleBottomSheetSelection = (0, _react.useCallback)(selectedIds => {
    bottomSheetSelectionRef.current = selectedIds;
  }, [bottomSheetSelectionRef]);
  const {
    visibleText,
    remainingCount
  } = (0, _react.useMemo)(() => getDisplayValues(), [getDisplayValues]);
  const hasSelectedValue = (0, _react.useMemo)(() => selectedValues.length > 0, [selectedValues]);
  const iconColor = (0, _react.useMemo)(() => {
    if (disabled) {
      return 'neutralLight';
    } else if (focused || hasSelectedValue) {
      return 'neutralDarker';
    } else {
      return 'neutralLight';
    }
  }, [focused, hasSelectedValue, disabled]);
  _react.default.useImperativeHandle(ref, () => ({
    focus: openBottomSheet,
    blur: closeBottomSheet,
    clear: () => {
      handleClear();
    }
  }));
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Box.default, {
    py: "2xs",
    ...rest,
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_InputLabel.InputLabel, {
      label: label,
      subLabel: subLabel,
      labelFixed: labelFixed,
      errorState: errorState,
      successState: successState,
      animatedViewProps: animatedViewProps,
      animatedTextProps: animatedTextProps,
      inputHeight: inputHeight,
      required: required
    }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Pressable, {
      onPress: openBottomSheet,
      disabled: disabled,
      testID: `${testID}-pressable`,
      children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Box.default, {
        flexDirection: "row",
        alignItems: "center",
        borderWidth: 1,
        borderRadius: 'm',
        borderColor: borderColor,
        backgroundColor: disabled ? 'neutralLightest' : 'neutralFull',
        px: "m",
        height: inputHeight,
        zIndex: "layer_0",
        accessibilityLabel: `${testID}-box`,
        testID: `${testID}-box`,
        children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)(_Box.default, {
          flex: 1,
          flexDirection: "row",
          alignItems: "center",
          justifyContent: "space-between",
          testID: `${testID}-text-container`,
          children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
            variant: "body2",
            color: visibleText ? 'neutralDarker' : 'neutralLight',
            testID: `${testID}-value`,
            numberOfLines: 1,
            ellipsizeMode: "tail",
            style: {
              flex: 1
            },
            children: visibleText || placeholder
          }), remainingCount > 0 && /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Text.default, {
            variant: "body2",
            color: "neutralDarker",
            testID: `${testID}-remaining-count`,
            marginRight: "m",
            children: ["+", remainingCount]
          })]
        }), /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Box.default, {
          flexDirection: "row",
          alignItems: "center",
          children: [hasSelectedValue && !disabled && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.TouchableOpacity, {
            onPress: handleClear,
            hitSlop: {
              top: 10,
              right: 10,
              bottom: 10,
              left: 10
            },
            testID: `${testID}-clear`,
            style: styles.clearButton,
            children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Icon.default, {
              name: "close",
              size: "s",
              color: "neutralDarker"
            })
          }), hasSelectedValue && !disabled && /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
            height: 16,
            width: 1,
            backgroundColor: "neutralLighter",
            marginHorizontal: "xs",
            testID: `${testID}-divider`
          }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Icon.default, {
            name: isBottomSheetVisible ? 'arrow-up' : 'arrow-down',
            size: "xs",
            color: iconColor,
            testID: `${testID}-icon`,
            accessibilityLabel: `${testID}-icon`
          })]
        })]
      })
    }), (helpText || errorText || successText) && /*#__PURE__*/(0, _jsxRuntime.jsx)(_InputHelpText.InputHelpText, {
      helpText: helpText,
      errorState: errorState,
      errorText: errorText,
      successState: successState,
      successText: successText
    }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_SelectBottomSheet.default, {
      visible: isBottomSheetVisible,
      title: bottomSheetTitle,
      closeButtonLabel: closeButtonLabel,
      closeButtonAction: closeBottomSheet,
      selectButtonLabel: selectButtonLabel,
      selectButtonAction: confirmSelection,
      options: sortedOptions,
      type: multiple ? 'checkbox' : 'radio',
      onSelect: handleBottomSheetSelection,
      selectedOption: isBottomSheetVisible ? bottomSheetSelectionRef.current : selectedValues,
      testID: `${testID}-bottomSheet`,
      maxVisibleItems: maxVisibleItems
    })]
  });
});
const styles = _reactNative.StyleSheet.create({
  clearButton: {
    padding: 2
  }
});
var _default = exports.default = Select;
//# sourceMappingURL=Select.js.map