"use strict";

var _react = _interopRequireDefault(require("react"));
var _testUtils = require("../../test-utils");
var _theme = _interopRequireDefault(require("../../theme"));
var _Select = _interopRequireDefault(require("./Select"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
describe('Select', () => {
  const defaultOptions = [{
    id: '1',
    label: 'Option 1'
  }, {
    id: '2',
    label: 'Option 2'
  }, {
    id: '3',
    label: 'Option 3'
  }];
  const defaultProps = {
    options: defaultOptions,
    testID: 'select',
    label: 'Select Label',
    placeholder: 'Select item',
    bottomSheetTitle: 'Options',
    closeButtonLabel: 'Cancel',
    selectButtonLabel: 'Select'
  };
  afterEach(() => {
    jest.clearAllMocks();
  });
  test('should render select correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render select with label correctly', () => {
    // when
    const {
      getByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps
    }));

    // then
    expect(getByText('Select Label')).toBeTruthy();
  });
  test('should render select with placeholder correctly', () => {
    // when
    const {
      getByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps
    }));

    // then
    expect(getByText('Select item')).toBeTruthy();
  });
  test('should render select with disabled state correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      disabled: true
    }));
    const selectBox = getByTestId('select-box');

    // then
    expect(selectBox.props.style[0].backgroundColor).toBe(_theme.default.colors.neutralLightest);
  });
  test('should render select with error state correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      error: true
    }));
    const selectBox = getByTestId('select-box');

    // then
    expect(selectBox.props.style[0].borderColor).toBe(_theme.default.colors.dangerKey);
  });
  test('should render select with error state and error text correctly', () => {
    // when
    const {
      getByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      error: true,
      errorText: "Error message"
    }));

    // then
    expect(getByText('Error message')).toBeTruthy();
  });
  test('should render select with success state correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      success: true
    }));
    const selectBox = getByTestId('select-box');

    // then
    expect(selectBox.props.style[0].borderColor).toBe(_theme.default.colors.successKey);
  });
  test('should render select with success state and success text correctly', () => {
    // when
    const {
      getByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      success: true,
      successText: "Success message"
    }));

    // then
    expect(getByText('Success message')).toBeTruthy();
  });
  test('should render select with help text correctly', () => {
    // when
    const {
      getByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      helpText: "Help message"
    }));

    // then
    expect(getByText('Help message')).toBeTruthy();
  });
  test('should render select with fixed label correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      labelFixed: true
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render select with medium size correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      size: "medium"
    }));
    const selectBox = getByTestId('select-box');

    // then
    expect(selectBox.props.style[0].height).toBe(_theme.default.inputSizeVariants.medium.height);
  });
  test('should render select with small size correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      size: "small"
    }));
    const selectBox = getByTestId('select-box');

    // then
    expect(selectBox.props.style[0].height).toBe(_theme.default.inputSizeVariants.small.height);
  });
  test('should render selected option correctly for single select', () => {
    // given
    const mockOptions = [{
      id: '1',
      label: 'Option 1'
    }, {
      id: '2',
      label: 'Option 2'
    }, {
      id: '3',
      label: 'Option 3'
    }];

    // when
    const {
      getByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      testID: "select",
      multiple: false,
      selectedOptions: "2",
      options: mockOptions,
      placeholder: "Select"
    }));

    // then
    expect(getByText('Option 2')).toBeTruthy();
  });
  test('should render selected options correctly for multiple select', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      multiple: true,
      selectedOptions: ['1', '3']
    }));
    const selectValue = getByTestId('select-value');

    // then
    expect(selectValue.props.children).toBe('Option 1, Option 3');
  });
  test('should render +n indicator when selected options exceed maxVisibleItems', () => {
    // when
    const {
      getByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      multiple: true,
      selectedOptions: ['1', '2', '3'],
      maxVisibleItems: 2
    }));

    // then
    expect(getByText('+1')).toBeTruthy();
  });
  test('should open bottom sheet when pressed', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps
    }));
    const selectPressable = getByTestId('select-pressable');

    // then
    expect(selectPressable).toBeTruthy();
    _testUtils.fireEvent.press(selectPressable);
    expect(true).toBe(true);
  });
  test('should not open bottom sheet when pressed and disabled', async () => {
    // when
    const {
      getByTestId,
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      disabled: true
    }));
    const selectPressable = getByTestId('select-pressable');

    // then
    expect(queryByTestId('select-bottomSheet')).toBeFalsy();

    // when
    _testUtils.fireEvent.press(selectPressable);

    // then
    expect(queryByTestId('select-bottomSheet')).toBeFalsy();
  });
  test('should call onSelect with selected value when item selected in bottom sheet', async () => {
    // given
    jest.useFakeTimers();
    const onSelect = jest.fn();

    // when
    const {
      getByTestId,
      getByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      multiple: false,
      onSelect: onSelect
    }));
    _testUtils.fireEvent.press(getByTestId('select-pressable'));
    await (0, _testUtils.act)(async () => {
      jest.runAllTimers();
    });

    // then
    const option = await (0, _testUtils.waitFor)(() => getByText('Option 2'));
    _testUtils.fireEvent.press(option);
    _testUtils.fireEvent.press(getByText('Select'));
    expect(onSelect).toHaveBeenCalledWith(['2']);
  });
  test('should call onSelect with selected values when multiple items selected in bottom sheet', async () => {
    // given
    jest.useFakeTimers();
    const onSelect = jest.fn();

    // when
    const {
      getByTestId,
      getByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      multiple: true,
      onSelect: onSelect
    }));

    // Open the bottom sheet
    _testUtils.fireEvent.press(getByTestId('select-pressable'));
    await (0, _testUtils.act)(async () => {
      jest.runAllTimers();
    });

    // Selecting individual options
    const option1 = getByText('Option 1');
    _testUtils.fireEvent.press(option1);
    const option3 = getByText('Option 3');
    _testUtils.fireEvent.press(option3);

    // Press the select button
    const selectButton = getByText('Select');
    _testUtils.fireEvent.press(selectButton);
    jest.runAllTimers();

    // then
    expect(onSelect).toHaveBeenCalledWith(['1', '3']);
    jest.useRealTimers();
  });
  test('should clear selected values when clear button pressed', async () => {
    // given
    const onSelect = jest.fn();

    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      multiple: true,
      selectedOptions: ['1', '2'],
      onSelect: onSelect
    }));
    const clearButton = getByTestId('select-clear');
    _testUtils.fireEvent.press(clearButton);

    // then
    expect(onSelect).toHaveBeenCalledWith([]);
  });
  test('should close bottom sheet when close button pressed', async () => {
    // given
    jest.useFakeTimers();

    // when
    const {
      getByTestId,
      queryByTestId,
      getByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps
    }));

    // Open the bottom sheet
    _testUtils.fireEvent.press(getByTestId('select-pressable'));
    await (0, _testUtils.act)(async () => {
      jest.runAllTimers();
    });

    // Press the close button
    const closeButton = getByText('Cancel');
    _testUtils.fireEvent.press(closeButton);
    jest.runAllTimers();

    // then
    expect(queryByTestId('select-bottomSheet')).toBeFalsy();
    jest.useRealTimers();
  });
  test('should show down arrow when bottom sheet is closed', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps
    }));
    const icon = getByTestId('select-icon');

    // then
    expect(icon.props.title).toBe('arrow-down');
  });
  test('should show up arrow when bottom sheet is open', async () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps
    }));
    const selectPressable = getByTestId('select-pressable');
    _testUtils.fireEvent.press(selectPressable);

    // then
    await (0, _testUtils.waitFor)(() => {
      const icon = getByTestId('select-icon');
      expect(icon.props.title).toBe('arrow-up');
    });
  });
  test('should render divider when there are selected options', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      selectedOptions: ['1']
    }));

    // then
    expect(getByTestId('select-divider')).toBeTruthy();
  });
  test('should not render clear button and divider when disabled', () => {
    // when
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      selectedOptions: ['1'],
      disabled: true
    }));

    // then
    expect(queryByTestId('select-clear')).toBeFalsy();
    expect(queryByTestId('select-divider')).toBeFalsy();
  });
  test('should render options with flag icons', async () => {
    // given
    const optionsWithFlags = [{
      id: '1',
      label: 'Turkey',
      flagIcon: 'TR'
    }, {
      id: '2',
      label: 'USA',
      flagIcon: 'US'
    }];

    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      options: optionsWithFlags,
      selectedOptions: ['1']
    }));
    const selectPressable = getByTestId('select-pressable');
    _testUtils.fireEvent.press(selectPressable);
  });
  test('should access select handle functions correctly', () => {
    // given
    const ref = /*#__PURE__*/_react.default.createRef();
    const onSelect = jest.fn();

    // when
    (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      ref: ref,
      onSelect: onSelect
    }));

    // then
    expect(ref.current?.focus).toBeTruthy();
    expect(ref.current?.blur).toBeTruthy();
    expect(ref.current?.clear).toBeTruthy();
    ref.current?.clear();

    // then
    expect(onSelect).toHaveBeenCalledWith([]);
  });
  test('should not focus or show bottom sheet when openBottomSheet is called through ref on disabled select', () => {
    // given
    jest.useFakeTimers();
    const ref = /*#__PURE__*/_react.default.createRef();
    const onSelect = jest.fn();

    // when
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      ref: ref,
      onSelect: onSelect,
      disabled: true
    }));

    // then
    expect(queryByTestId('select-bottomSheet')).toBeFalsy();

    // when
    ref.current?.focus();
    jest.runAllTimers();

    // then
    expect(queryByTestId('select-bottomSheet')).toBeFalsy();
    jest.useRealTimers();
  });
  test('should reset selections when clear method is called', () => {
    // given
    const ref = /*#__PURE__*/_react.default.createRef();
    const onSelect = jest.fn();

    // when
    (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      ref: ref,
      onSelect: onSelect
    }));
    ref.current?.clear();

    // then
    expect(onSelect).toHaveBeenCalledWith([]);
  });
  test('selected items should appear at the top of the list when bottom sheet is reopened after selection', async () => {
    // given
    jest.useFakeTimers();
    const onSelect = jest.fn();
    const options = [{
      id: '1',
      label: 'Option 1'
    }, {
      id: '2',
      label: 'Option 2'
    }, {
      id: '3',
      label: 'Option 3'
    }, {
      id: '4',
      label: 'Option 4'
    }];

    // when
    const {
      getByTestId,
      getByText,
      queryByTestId,
      queryAllByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Select.default, {
      ...defaultProps,
      options: options,
      multiple: true,
      onSelect: onSelect
    }));
    _testUtils.fireEvent.press(getByTestId('select-pressable'));
    await (0, _testUtils.act)(async () => {
      jest.runAllTimers();
    });
    _testUtils.fireEvent.press(getByText('Option 2'));
    _testUtils.fireEvent.press(getByText('Option 4'));
    _testUtils.fireEvent.press(getByText('Select'));
    jest.runAllTimers();
    expect(queryByTestId('select-bottomSheet')).toBeFalsy();
    _testUtils.fireEvent.press(getByTestId('select-pressable'));
    await (0, _testUtils.act)(async () => {
      jest.runAllTimers();
    });

    // then
    const labels = queryAllByTestId('label');
    expect(labels[0].props.children).toContain('Option 2');
    expect(labels[1].props.children).toContain('Option 4');
    expect(labels[2].props.children).toContain('Option 1');
    expect(labels[3].props.children).toContain('Option 3');
    jest.useRealTimers();
  });
});
//# sourceMappingURL=Select.test.js.map