"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _Box = _interopRequireDefault(require("../Box/Box"));
var _BottomSheet = _interopRequireDefault(require("../BottomSheet/BottomSheet"));
var _Checkbox = _interopRequireDefault(require("../Checkbox/Checkbox"));
var _RadioButton = _interopRequireDefault(require("../RadioButton/RadioButton"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const SelectBottomSheet = ({
  options,
  type,
  onSelect,
  selectedOption,
  maxVisibleItems = 6,
  pb,
  accessibilityLabel,
  testID,
  ...bottomSheetProps
}) => {
  const [selectedValues, setSelectedValues] = _react.default.useState(selectedOption ?? []);
  const testProps = _react.default.useMemo(() => {
    return {
      accessibilityLabel: accessibilityLabel ?? testID,
      testID: testID ?? accessibilityLabel
    };
  }, [testID, accessibilityLabel]);
  _react.default.useEffect(() => {
    if (Array.isArray(selectedOption)) {
      setSelectedValues(selectedOption);
    }
  }, [selectedOption]);
  const handleSelect = value => {
    if (type === 'checkbox') {
      setSelectedValues(prev => prev.includes(value) ? prev.filter(v => v !== value) : [...prev, value]);
    } else {
      setSelectedValues([value]);
    }
  };
  _react.default.useEffect(() => {
    if (onSelect) {
      onSelect(selectedValues);
    }
  }, [selectedValues, onSelect]);
  const renderItem = ({
    item,
    index
  }) => {
    return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Box.default, {
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.TouchableOpacity, {
        onPress: () => handleSelect(item.id),
        disabled: item.disabled,
        ...testProps,
        testID: `touchable-selectBottomSheet-${item.id}`,
        children: type === 'checkbox' ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_Checkbox.default, {
          testID: `checkbox-selectBottomSheet-${item.id}`,
          label: item.label,
          flagIcon: item.flagIcon,
          checked: selectedValues.includes(item.id),
          onPress: () => handleSelect(item.id),
          disabled: item.disabled
        }) : /*#__PURE__*/(0, _jsxRuntime.jsx)(_RadioButton.default, {
          testID: `radiobutton-selectBottomSheet-${item.id}`,
          label: item.label,
          flagIcon: item.flagIcon,
          selected: selectedValues.includes(item.id),
          onPress: () => handleSelect(item.id),
          disabled: item.disabled
        })
      }), index < options.length - 1 && /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
        height: 1,
        backgroundColor: "borderColor",
        marginVertical: "m"
      })]
    }, item.id);
  };
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_BottomSheet.default, {
    ...bottomSheetProps,
    ...testProps,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
      pb: pb,
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
        testID: 'selectBottomSheet',
        contentContainerStyle: styles.flatListContainer,
        horizontal: true,
        bounces: false,
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.FlatList, {
          data: options,
          renderItem: renderItem,
          keyExtractor: item => item.id,
          nestedScrollEnabled: true,
          initialNumToRender: maxVisibleItems,
          maxToRenderPerBatch: maxVisibleItems,
          style: {
            maxHeight: maxVisibleItems * 50 - 15
          }
        })
      })
    })
  });
};
var _default = exports.default = SelectBottomSheet;
const styles = _reactNative.StyleSheet.create({
  flatListContainer: {
    flex: 1,
    width: 'auto'
  }
});
//# sourceMappingURL=SelectBottomSheet.js.map