"use strict";

var _react = _interopRequireDefault(require("react"));
var _testUtils = require("../../test-utils");
var _SelectBottomSheet = _interopRequireDefault(require("./SelectBottomSheet"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
describe('SelectBottomSheet', () => {
  const options = [{
    id: '1',
    label: 'Option 1'
  }, {
    id: '2',
    label: 'Option 2'
  }, {
    id: '3',
    label: 'Option 3'
  }];
  const mockOnSelect = jest.fn();
  const defaultProps = {
    options,
    type: 'checkbox',
    onSelect: mockOnSelect,
    visible: true,
    closeButtonLabel: 'Close',
    selectButtonLabel: 'Select',
    flagIcon: 'TR'
  };
  afterEach(() => {
    jest.clearAllMocks();
  });
  test('should render correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_SelectBottomSheet.default, {
      ...defaultProps
    }));

    //then
    expect(getByTestId('selectBottomSheet')).toBeTruthy();
  });
  test('renders correctly with radio type', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_SelectBottomSheet.default, {
      ...defaultProps,
      type: "radio"
    }));

    //then
    expect(getByTestId('selectBottomSheet')).toBeTruthy();
  });
  test('should render SelectBottomSheet when visible true', () => {
    // when
    const {
      toJSON,
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_SelectBottomSheet.default, {
      ...defaultProps
    }));

    // then
    expect(queryByTestId('selectBottomSheet')).not.toBeNull();
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render SelectBottomSheet when visible false', () => {
    // when
    const {
      toJSON,
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_SelectBottomSheet.default, {
      ...defaultProps,
      visible: false
    }));

    // then
    const modalWrapper = queryByTestId('selectBottomSheet');
    expect(modalWrapper).toBeNull();
    expect(toJSON()).toMatchSnapshot();
  });
  test('should not render SelectBottomSheet when visible is false', () => {
    // when
    const {
      toJSON,
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_SelectBottomSheet.default, {
      ...defaultProps
    }));

    // then
    expect(queryByTestId('modal-wrapper')).toBeNull();
    expect(toJSON()).toMatchSnapshot();
  });
  test('should initialize with correct selected values', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_SelectBottomSheet.default, {
      ...defaultProps,
      selectedOption: ['1', '2']
    }));

    // then
    expect(getByTestId('checkbox-selectBottomSheet-1').props.children[0][0].props.variant).toBe('checked');
    expect(getByTestId('checkbox-selectBottomSheet-2').props.children[0][0].props.variant).toBe('checked');
    expect(getByTestId('checkbox-selectBottomSheet-3').props.children[0][0].props.variant).toBe('unchecked');
  });
  test('should update selected values on checkbox select', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_SelectBottomSheet.default, {
      ...defaultProps
    }));
    const checkbox = getByTestId('checkbox-selectBottomSheet-1');
    _testUtils.fireEvent.press(checkbox);

    // then
    expect(getByTestId('checkbox-selectBottomSheet-1').props.children[0][0].props.variant).toBe('checked');
  });
  test('should update selected values on checkbox unselect', () => {
    // given
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_SelectBottomSheet.default, {
      ...defaultProps,
      selectedOption: ['1', '2']
    }));
    const checkbox = getByTestId('checkbox-selectBottomSheet-1');

    // when
    _testUtils.fireEvent.press(checkbox);

    // then
    expect(getByTestId('checkbox-selectBottomSheet-1').props.children[0][0].props.variant).toBe('unchecked');
    expect(mockOnSelect).toHaveBeenCalledWith(['2']);
  });
  test('should update selected values on radio button select', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_SelectBottomSheet.default, {
      ...defaultProps,
      type: "radio"
    }));
    const radioButton = getByTestId('radiobutton-selectBottomSheet-2');
    _testUtils.fireEvent.press(radioButton);

    // then
    expect(mockOnSelect).toHaveBeenCalledWith(['2']);
  });
  test('should call onSelect with selected radio button value', () => {
    // when
    const {
      getByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_SelectBottomSheet.default, {
      ...defaultProps,
      type: "radio"
    }));
    _testUtils.fireEvent.press(getByText('Option 3'));

    // then
    expect(mockOnSelect).toHaveBeenCalledWith(['3']);
  });
  test('should render flag icon if provided', () => {
    // given
    const optionsWithFlag = [{
      id: '1',
      label: 'Option 1',
      flagIcon: 'TR'
    }];

    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_SelectBottomSheet.default, {
      ...defaultProps,
      options: optionsWithFlag
    }));

    // then
    expect(getByTestId('flag-icon').props.title).toBe('TR');
  });
  test('should call onSelect if provided', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_SelectBottomSheet.default, {
      ...defaultProps
    }));
    const checkbox = getByTestId('checkbox-selectBottomSheet-1');
    _testUtils.fireEvent.press(checkbox);

    // then
    expect(mockOnSelect).toHaveBeenCalledWith(['1']);
  });
  test('should not call onSelect if not provided', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_SelectBottomSheet.default, {
      ...defaultProps,
      onSelect: undefined
    }));
    const checkbox = getByTestId('checkbox-selectBottomSheet-1');
    _testUtils.fireEvent.press(checkbox);

    // then
    expect(mockOnSelect).not.toHaveBeenCalled();
  });
  test('should render disabled options checkbox', () => {
    // given
    const optionsWithDisabled = [{
      id: '1',
      label: 'Option 1',
      disabled: true
    }, {
      id: '2',
      label: 'Option 2'
    }];

    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_SelectBottomSheet.default, {
      ...defaultProps,
      options: optionsWithDisabled
    }));

    // then
    expect(getByTestId('checkbox-selectBottomSheet-1').props.accessibilityState.disabled).toBe(true);
    expect(getByTestId('checkbox-selectBottomSheet-2').props.accessibilityState.disabled).toBe(false);
  });
  test('should render disabled options radio', () => {
    // given
    const optionsWithDisabled = [{
      id: '1',
      label: 'Option 1',
      disabled: true
    }, {
      id: '2',
      label: 'Option 2'
    }];

    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_SelectBottomSheet.default, {
      ...defaultProps,
      type: "radio",
      options: optionsWithDisabled
    }));

    // then
    expect(getByTestId('radiobutton-selectBottomSheet-1').props.accessibilityState.disabled).toBe(true);
    expect(getByTestId('radiobutton-selectBottomSheet-2').props.accessibilityState.disabled).toBe(false);
  });
});
//# sourceMappingURL=SelectBottomSheet.test.js.map