"use strict";

var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _testUtils = require("../../test-utils");
var _theme = _interopRequireDefault(require("../../theme"));
var _Spinner = _interopRequireDefault(require("./Spinner"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
describe('Spinner', () => {
  test('should render Spinner correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Spinner.default, {}));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render given spinner', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Spinner.default, {
      testID: "spinner",
      color: "successKey"
    }));
    const spinnerComponent = getByTestId('spinner').children[0];

    // then
    expect(spinnerComponent.props.children[0].props.fill).toBe(_theme.default.colors.successKey);
    expect(spinnerComponent.props.children[0].props.opacity).toBe(0.3);
    expect(spinnerComponent.props.children[1].props.fill).toBe(_theme.default.colors.successKey);
  });
  test('should render custom named color', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Spinner.default, {
      testID: "spinner",
      color: "pink"
    }));
    const spinnerComponent = getByTestId('spinner').children[0];

    // then
    expect(spinnerComponent.props.children[0].props.fill).toBe('pink');
    expect(spinnerComponent.props.children[0].props.opacity).toBe(0.3);
    expect(spinnerComponent.props.children[1].props.fill).toBe('pink');
  });
  test('should render hex color', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Spinner.default, {
      testID: "spinner",
      color: "#5C8984"
    }));
    const spinnerComponent = getByTestId('spinner').children[0];

    // then
    expect(spinnerComponent.props.children[0].props.fill).toBe('#5C8984');
    expect(spinnerComponent.props.children[0].props.opacity).toBe(0.3);
    expect(spinnerComponent.props.children[1].props.fill).toBe('#5C8984');
  });
  test('should start spin animation', () => {
    const mockStart = jest.fn();
    const mockStop = jest.fn();
    const mockLoop = jest.fn().mockReturnValue({
      start: mockStart,
      stop: mockStop
    });
    jest.spyOn(_reactNative.Animated, 'loop').mockImplementation(mockLoop);
    // when
    (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Spinner.default, {
      testID: "spinner",
      color: "successKey"
    }));

    // then
    expect(mockLoop).toBeCalled();
    expect(mockStart).toBeCalled();
  });
  test('should stop spin animation', () => {
    const mockStart = jest.fn();
    const mockStop = jest.fn();
    const mockLoop = jest.fn().mockReturnValue({
      start: mockStart,
      stop: mockStop
    });
    jest.spyOn(_reactNative.Animated, 'loop').mockImplementation(mockLoop);
    // when
    const {
      unmount
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Spinner.default, {
      testID: "spinner",
      color: "successKey"
    }));
    unmount();

    // then
    expect(mockStop).toBeCalled();
  });
});
//# sourceMappingURL=Spinner.test.js.map