"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _restyle = require("@ergenekonyigit/restyle");
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _theme = _interopRequireDefault(require("../../theme"));
var _Text = _interopRequireDefault(require("../Text/Text"));
var _Box = _interopRequireDefault(require("../Box/Box"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const SwitchContainer = (0, _restyle.createRestyleComponent)([_restyle.layout], _Box.default);
const AnimatedView = (0, _restyle.createRestyleComponent)([_restyle.layout, _restyle.border, _restyle.spacing], _reactNative.Animated.View);
const RestyledPressable = (0, _restyle.createRestyleComponent)([_restyle.opacity], _reactNative.Pressable);
const Switch = ({
  label,
  value,
  onValueChange,
  disabled,
  onColor,
  offColor,
  testID,
  accessibilityLabel,
  accessible,
  containerStyle
}) => {
  const [isEnabled, setIsEnabled] = (0, _react.useState)(value ? value : false);
  const animatedCirclePosition = (0, _react.useRef)(new _reactNative.Animated.Value(isEnabled ? 1 : 0)).current;
  const animatedSwitchWidth = (0, _react.useRef)(new _reactNative.Animated.Value(_theme.default.spacing.l)).current;
  const animatedSwitchMarginRight = (0, _react.useRef)(new _reactNative.Animated.Value(0)).current;
  const onSwitchPressIn = () => {
    _reactNative.Animated.timing(animatedSwitchMarginRight, {
      toValue: isEnabled ? 1 : -1,
      duration: 200,
      easing: _reactNative.Easing.sin,
      useNativeDriver: false
    }).start();
    _reactNative.Animated.timing(animatedSwitchWidth, {
      toValue: _theme.default.spacing.xl,
      duration: 200,
      easing: _reactNative.Easing.sin,
      useNativeDriver: false
    }).start();
  };
  const onSwitchPressOut = () => {
    _reactNative.Animated.timing(animatedSwitchWidth, {
      toValue: _theme.default.spacing.l,
      duration: 130,
      easing: _reactNative.Easing.out(_reactNative.Easing.exp),
      useNativeDriver: false
    }).start();
  };
  const handleValueChange = _react.default.useCallback(nextState => {
    setIsEnabled(nextState);
    if (onValueChange) {
      onValueChange(nextState);
    }
    _reactNative.Animated.timing(animatedCirclePosition, {
      toValue: nextState ? 1 : 0,
      duration: 130,
      easing: _reactNative.Easing.out(_reactNative.Easing.exp),
      useNativeDriver: false
    }).start();
    _reactNative.Animated.timing(animatedSwitchMarginRight, {
      toValue: 0,
      duration: 90,
      easing: _reactNative.Easing.out(_reactNative.Easing.exp),
      useNativeDriver: false
    }).start();
  }, [animatedCirclePosition, animatedSwitchMarginRight, onValueChange]);
  const testProps = _react.default.useMemo(() => {
    const result = {
      accessible: false,
      accessibilityLabel: undefined,
      testID: undefined
    };
    if (!(testID || accessibilityLabel)) {
      return result;
    }
    result.accessible = accessible ?? true;
    result.accessibilityLabel = accessibilityLabel ?? testID;
    result.testID = testID ?? accessibilityLabel;
    return result;
  }, [testID, accessibilityLabel, accessible]);
  const isRTL = _reactNative.I18nManager.isRTL;
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(SwitchContainer, {
    flexDirection: "row",
    alignItems: "center",
    style: containerStyle,
    children: [label && /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      variant: "subtitle2Medium",
      p: "2xs",
      testID: "switch-label",
      accessibilityLabel: "switch-label",
      children: label
    }), /*#__PURE__*/(0, _jsxRuntime.jsx)(RestyledPressable, {
      opacity: disabled ? 0.5 : 1,
      disabled: disabled,
      onPressOut: onSwitchPressOut,
      onPressIn: onSwitchPressIn,
      onPress: () => handleValueChange(!isEnabled),
      ...testProps,
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(AnimatedView, {
        flexDirection: isRTL ? 'row-reverse' : 'row',
        width: _theme.default.spacing['4xl'],
        height: _theme.default.spacing.xl,
        paddingHorizontal: "4xs",
        alignItems: "center",
        borderRadius: "full",
        testID: "switch-outer-view",
        accessibilityLabel: "switch-outer-view"
        // @ts-ignore
        ,
        backgroundColor: animatedCirclePosition.interpolate({
          inputRange: [0, 1],
          outputRange: [offColor ?? _theme.default.colors.neutralLighter, onColor ?? _theme.default.colors.primaryKey]
        }),
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(AnimatedView, {
          backgroundColor: "white",
          height: _theme.default.spacing.l,
          borderRadius: "full",
          testID: "switch-inner-view",
          accessibilityLabel: "switch-inner-view"
          //@ts-ignore
          ,
          width: animatedSwitchWidth
          //@ts-ignore
          ,
          style: {
            transform: [{
              translateX: animatedCirclePosition.interpolate({
                inputRange: [0, 1],
                outputRange: _reactNative.I18nManager.isRTL ? [_theme.default.spacing.xl, 0] : [0, _theme.default.spacing.xl]
              })
            }, {
              translateX: animatedSwitchMarginRight.interpolate({
                inputRange: [-1, 0, 1],
                outputRange: [2, 0, -6]
              })
            }]
          }
        })
      })
    })]
  });
};
var _default = exports.default = Switch;
//# sourceMappingURL=Switch.js.map