"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _Box = _interopRequireDefault(require("../Box/Box"));
var _Text = _interopRequireDefault(require("../Text/Text"));
var _Icon = _interopRequireDefault(require("../Icon/Icon"));
var _utils = _interopRequireDefault(require("./utils"));
var _Badge = _interopRequireDefault(require("../Badge/Badge"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const TabsContext = /*#__PURE__*/(0, _react.createContext)(null);
const Tabs = ({
  value: controlledValue,
  defaultValue,
  onValueChange,
  ...rest
}) => {
  const [value, setValue] = (0, _react.useState)(defaultValue ?? '');
  (0, _react.useEffect)(() => {
    if (controlledValue !== undefined) {
      setValue(controlledValue);
    }
  }, [controlledValue]);
  const handleChange = newValue => {
    if (controlledValue === undefined) {
      setValue(newValue);
    }
    onValueChange(newValue);
  };
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(TabsContext.Provider, {
    value: {
      value,
      onValueChange: handleChange
    },
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
      testID: "tabsBox",
      accessibilityLabel: "tabsBox",
      flex: 1,
      ...rest
    })
  });
};
const List = ({
  children
}) => {
  const data = _react.default.useMemo(() => {
    const childrenArray = _react.default.Children.toArray(children);
    return (0, _utils.default)(childrenArray, /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
      flex: 1,
      mx: "m",
      width: 1,
      height: 30,
      alignSelf: "center",
      backgroundColor: "neutralLighter"
    }));
  }, [children]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
    testID: "tabsListBox",
    accessibilityLabel: "tabsListBox",
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.FlatList, {
      data: data,
      testID: "tabsFlatList",
      accessibilityLabel: "tabsFlatList",
      keyExtractor: (item, index) => index.toString(),
      horizontal: true,
      showsHorizontalScrollIndicator: false,
      renderItem: ({
        item
      }) => item,
      contentContainerStyle: {
        flexGrow: 1,
        justifyContent: 'space-around'
      }
    })
  });
};
const Option = ({
  value,
  title,
  caption = '',
  disabled = false,
  iconName = undefined,
  badgeText = undefined
}) => {
  const context = (0, _react.useContext)(TabsContext);
  if (!context) {
    throw new Error('Tabs.Option must be used within Tabs');
  }
  const isSelected = context.value === value;
  const conditionalColor = disabled ? 'neutralLight' : isSelected ? 'primaryKey' : 'neutralDarker';
  const underline = _react.default.useMemo(() => {
    if (!isSelected) {
      return null;
    }
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
      position: "absolute",
      bottom: 0,
      alignSelf: "center",
      width: "100%",
      borderBottomWidth: 2,
      borderColor: "primaryKey"
    });
  }, [isSelected]);
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.TouchableOpacity, {
    disabled: disabled,
    style: {
      justifyContent: 'center'
    },
    onPress: () => !disabled && context.onValueChange(value),
    children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)(_Box.default, {
      testID: "tabOptionBox",
      alignItems: "center",
      justifyContent: "center",
      paddingVertical: "xs",
      children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)(_Box.default, {
        flexDirection: "row",
        alignItems: "center",
        children: [iconName ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
          pr: "3xs",
          testID: "tabIconBox",
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Icon.default, {
            name: iconName,
            size: "s",
            color: conditionalColor,
            testID: "tabIcon"
          })
        }) : null, /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
          testID: "tabTitleBox",
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
            testID: "tabTitle",
            fontWeight: "500",
            color: conditionalColor,
            numberOfLines: 1,
            ellipsizeMode: "tail",
            children: title
          })
        }), badgeText ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
          pl: "3xs",
          testID: "tabBadgeBox",
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Badge.default, {
            testID: "tabBadge",
            text: badgeText,
            size: "small",
            transparent: true,
            color: "neutralFull",
            backgroundColor: "dangerKey"
          })
        }) : null]
      }), caption ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
        testID: "tabCaption",
        fontSize: 12,
        color: disabled ? 'neutralLight' : 'neutralDarker',
        children: caption
      }) : null]
    }), underline]
  });
};
const Content = ({
  value,
  ...rest
}) => {
  const context = (0, _react.useContext)(TabsContext);
  if (!context) {
    throw new Error('Tabs.Content must be used within Tabs');
  }
  return context.value === value ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
    testID: "tabsContentBox",
    accessibilityLabel: "tabsContentBox",
    ...rest
  }) : null;
};
Tabs.List = List;
Tabs.Option = Option;
Tabs.Content = Content;
var _default = exports.default = Tabs;
//# sourceMappingURL=Tabs.js.map