"use strict";

var _react = _interopRequireDefault(require("react"));
var _theme = _interopRequireDefault(require("../../theme"));
var _testUtils = require("../../test-utils");
var _Tabs = _interopRequireDefault(require("./Tabs"));
var _Box = _interopRequireDefault(require("../Box/Box"));
var _Text = _interopRequireDefault(require("../Text/Text"));
var _utils = _interopRequireDefault(require("./utils"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
describe('Tabs', () => {
  beforeEach(() => {});
  test('should render Tabs correctly', () => {
    // given
    const {
      toJSON,
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsxs)(_Tabs.default, {
      value: "tab1",
      onValueChange: () => {},
      defaultValue: "tab1",
      children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)(_Tabs.default.List, {
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Option, {
          value: "tab1",
          title: "Tab 1"
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Option, {
          value: "tab2",
          title: "Tab 2"
        })]
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Content, {
        value: "tab1",
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
          children: "Tab 1 Content"
        })
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Content, {
        value: "tab2",
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
          children: "Tab 2 Content"
        })
      })]
    }));

    // when
    const tabsComponent = getByTestId('tabsBox');
    const listComponent = getByTestId('tabsListBox');

    // then
    expect(toJSON()).toMatchSnapshot();
    expect(tabsComponent).toBeTruthy();
    expect(listComponent).toBeTruthy();
  });
  test('should change selected tab on press', () => {
    // given
    const onValueChange = jest.fn();
    const {
      getByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsxs)(_Tabs.default, {
      value: "tab1",
      onValueChange: onValueChange,
      defaultValue: "tab1",
      children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)(_Tabs.default.List, {
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Option, {
          value: "tab1",
          title: "Tab 1"
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Option, {
          value: "tab2",
          title: "Tab 2"
        })]
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Content, {
        value: "tab1",
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
          children: "Tab 1 Content"
        })
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Content, {
        value: "tab2",
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
          children: "Tab 2 Content"
        })
      })]
    }));

    // when
    _testUtils.fireEvent.press(getByText('Tab 2'));

    // then
    expect(onValueChange).toHaveBeenCalledWith('tab2');
  });
  test('should change selected tab on press when value undefined', () => {
    // given
    const onValueChange = jest.fn();
    const {
      getByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsxs)(_Tabs.default
    // @ts-ignore
    , {
      value: undefined,
      onValueChange: onValueChange,
      defaultValue: "tab1",
      children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)(_Tabs.default.List, {
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Option, {
          value: "tab1",
          title: "Tab 1"
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Option, {
          value: "tab2",
          title: "Tab 2"
        })]
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Content, {
        value: "tab1",
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
          children: "Tab 1 Content"
        })
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Content, {
        value: "tab2",
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
          children: "Tab 2 Content"
        })
      })]
    }));

    // when
    _testUtils.fireEvent.press(getByText('Tab 2'));

    // then
    expect(onValueChange).toHaveBeenCalledWith('tab2');
  });
  test('should not trigger onValueChange when disabled tab is pressed', () => {
    // given
    const onValueChange = jest.fn();
    const {
      getByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsxs)(_Tabs.default, {
      value: "tab1",
      onValueChange: onValueChange,
      children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)(_Tabs.default.List, {
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Option, {
          value: "tab1",
          title: "Tab 1"
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Option, {
          value: "tab2",
          title: "Tab 2",
          disabled: true
        })]
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Content, {
        value: "tab1",
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
          children: "Tab 1 Content"
        })
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Content, {
        value: "tab2",
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
          children: "Tab 2 Content"
        })
      })]
    }));

    // when
    _testUtils.fireEvent.press(getByText('Tab 2'));

    // then
    expect(onValueChange).not.toHaveBeenCalled();
  });
  test('should update value state when uncontrolled (defaultValue is used)', () => {
    // given
    const onValueChangeMock = jest.fn();
    const {
      getByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default, {
      value: "tab1",
      defaultValue: "tab1",
      onValueChange: onValueChangeMock,
      children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Tabs.default.List, {
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Option, {
          value: "tab1",
          title: "Tab 1"
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Option, {
          value: "tab2",
          title: "Tab 2"
        })]
      })
    }));
    const tab2 = getByText('Tab 2');

    // when
    _testUtils.fireEvent.press(tab2);

    // then
    expect(onValueChangeMock).toHaveBeenCalledWith('tab2');
  });
  test('should render correct content based on selected tab', () => {
    // given
    const {
      getByTestId,
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsxs)(_Tabs.default, {
      value: "tab1",
      onValueChange: () => {},
      children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)(_Tabs.default.List, {
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Option, {
          value: "tab1",
          title: "Tab 1"
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Option, {
          value: "tab2",
          title: "Tab 2"
        })]
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Content, {
        value: "tab1",
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
          testID: "content-tab1",
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
            children: "Tab 1 Content"
          })
        })
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Content, {
        value: "tab2",
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
          testID: "content-tab2",
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
            children: "Tab 2 Content"
          })
        })
      })]
    }));

    // then
    expect(getByTestId('content-tab1')).toBeTruthy();
    expect(queryByTestId('content-tab2')).toBeNull();
  });
  test('should have neutralLight color when disabled', () => {
    // given
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default, {
      value: "tab1",
      onValueChange: jest.fn(),
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.List, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Option, {
          value: "tab1",
          title: "Tab 1",
          disabled: true,
          iconName: "heart",
          badgeText: "test"
        })
      })
    }));

    // when
    const title = getByTestId('tabTitle');
    const icon = getByTestId('tabIcon');
    const badge = getByTestId('tabBadge');
    const badgeText = getByTestId('badgeText');

    // then
    expect(title.props.style[0].color).toEqual(_theme.default.colors.neutralLight);
    expect(icon.props.fill).toEqual(_theme.default.colors.neutralLight);
    expect(badgeText.props.style[0].color).toEqual(_theme.default.colors.neutralFull);
    expect(badge.props.style[1].backgroundColor).toEqual(_theme.default.colors.dangerKey);
  });
  test('should have primaryKey color when selected and enabled', () => {
    // given
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default, {
      value: "tab1",
      onValueChange: jest.fn(),
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.List, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Option, {
          value: "tab1",
          title: "Tab 1",
          iconName: "heart",
          badgeText: "test"
        })
      })
    }));

    // when
    const title = getByTestId('tabTitle');
    const icon = getByTestId('tabIcon');
    const badge = getByTestId('tabBadge');
    const badgeText = getByTestId('badgeText');

    // then
    expect(title.props.style[0].color).toEqual(_theme.default.colors.primaryKey);
    expect(icon.props.fill).toEqual(_theme.default.colors.primaryKey);
    expect(badgeText.props.style[0].color).toEqual(_theme.default.colors.neutralFull);
    expect(badge.props.style[1].backgroundColor).toEqual(_theme.default.colors.dangerKey);
  });
  test('should render caption when provided', () => {
    // given
    const {
      getByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default, {
      value: "tab1",
      onValueChange: jest.fn(),
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.List, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Option, {
          value: "tab1",
          title: "Tab 1",
          caption: "Test Caption",
          disabled: true
        })
      })
    }));

    // when
    const tab1 = getByText('Tab 1');

    // then
    expect(getByText('Test Caption')).toBeTruthy();
    expect(tab1.props.style[0].color).toEqual(_theme.default.colors.neutralLight);
  });
  test('should not render caption when not provided', () => {
    // given
    const {
      queryByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default, {
      value: "tab1",
      onValueChange: jest.fn(),
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.List, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Option, {
          value: "tab1",
          title: "Tab 1"
        })
      })
    }));

    // then
    expect(queryByText('Test Caption')).toBeNull();
  });
  test('should render title with neutralDarker color when not disabled and not selected', () => {
    // Given
    const onValueChange = jest.fn();
    const {
      getByText
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default, {
      value: "tab1",
      onValueChange: onValueChange,
      children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Tabs.default.List, {
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Option, {
          value: "tab1",
          title: "Option 1",
          caption: "Caption 1"
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Option, {
          value: "tab2",
          title: "Option 2",
          caption: "Caption 2"
        })]
      })
    }));

    // When
    const option2Text = getByText('Option 2');

    // Then
    expect(option2Text.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should throw error if Tabs.Option is used outside of Tabs', () => {
    // given
    const consoleErrorSpy = jest.spyOn(console, 'error').mockImplementation(() => {});

    // then
    expect(() => (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Option, {
      value: "tab1",
      title: "Tab 1"
    }))).toThrow('Tabs.Option must be used within Tabs');
    consoleErrorSpy.mockRestore();
  });
  test('should throw error if Tabs.Content is used outside of Tabs', () => {
    // given
    const consoleErrorSpy = jest.spyOn(console, 'error').mockImplementation(() => {});

    // then
    expect(() => (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Tabs.default.Content, {
      value: "tab1"
    }))).toThrow('Tabs.Content must be used within Tabs');
    consoleErrorSpy.mockRestore();
  });
  test('provider', () => {});
});
describe('insertObjectBetweenElements', () => {
  test('should return the same array if it has 0 elements', () => {
    // given
    const input = [];
    const separator = '|';
    const result = (0, _utils.default)(input, separator);

    // then
    expect(result).toEqual([]);
  });
  test('should return the same array if it has 1 element', () => {
    // given
    const input = ['A'];
    const separator = '|';
    const result = (0, _utils.default)(input, separator);

    // then
    expect(result).toEqual(['A']);
  });
  test('should insert the object between elements', () => {
    // given
    const input = ['A', 'B', 'C'];
    const separator = '|';
    const result = (0, _utils.default)(input, separator);

    // then
    expect(result).toEqual(['A', '|', 'B', '|', 'C']);
  });
});
//# sourceMappingURL=Tabs.test.js.map