"use strict";

var _react = _interopRequireDefault(require("react"));
var _theme = _interopRequireDefault(require("../../theme"));
var _testUtils = require("../../test-utils");
var _Text = _interopRequireDefault(require("./Text"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
describe('Text', () => {
  test('should render text correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      accessibilityLabel: "text",
      children: "testtesttest"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render given text correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.children).toBe('Test Text');
  });

  // Heading
  test('should render heading1 variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "heading1",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(30);
    expect(textComponent.props.style[0].lineHeight).toBe(36);
    expect(textComponent.props.style[0].fontWeight).toBe('400');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render heading2 variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "heading2",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(28);
    expect(textComponent.props.style[0].lineHeight).toBe(32);
    expect(textComponent.props.style[0].fontWeight).toBe('400');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render heading3 variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "heading3",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then

    expect(textComponent.props.style[0].fontSize).toBe(24);
    expect(textComponent.props.style[0].lineHeight).toBe(28);
    expect(textComponent.props.style[0].fontWeight).toBe('400');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });

  // Subtitle01
  test('should render subtitle01Regular variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle01Regular",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(20);
    expect(textComponent.props.style[0].fontWeight).toBe('400');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle01Medium variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle01Medium",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(20);
    expect(textComponent.props.style[0].fontWeight).toBe('500');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle01Semibold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle01Semibold",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(20);
    expect(textComponent.props.style[0].fontWeight).toBe('600');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle01Bold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle01Bold",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(20);
    expect(textComponent.props.style[0].fontWeight).toBe('700');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });

  // Subtitle1
  test('should render subtitle1Regular variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle1Regular",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(20);
    expect(textComponent.props.style[0].fontWeight).toBe('400');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle1Medium variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle1Medium",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(20);
    expect(textComponent.props.style[0].fontWeight).toBe('500');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle1Semibold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle1Semibold",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(20);
    expect(textComponent.props.style[0].fontWeight).toBe('600');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle1Bold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle1Bold",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(20);
    expect(textComponent.props.style[0].fontWeight).toBe('700');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });

  // Subtitle02
  test('should render subtitle02Regular variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle02Regular",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(16);
    expect(textComponent.props.style[0].fontWeight).toBe('400');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle02Medium variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle02Medium",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(16);
    expect(textComponent.props.style[0].fontWeight).toBe('500');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle02Semibold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle02Semibold",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(16);
    expect(textComponent.props.style[0].fontWeight).toBe('600');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle02Bold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle02Bold",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(16);
    expect(textComponent.props.style[0].fontWeight).toBe('700');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });

  // Subtitle2
  test('should render subtitle2Regular variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle2Regular",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(16);
    expect(textComponent.props.style[0].fontWeight).toBe('400');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle2Medium variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle2Medium",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(16);
    expect(textComponent.props.style[0].fontWeight).toBe('500');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle2Semibold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle2Semibold",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(16);
    expect(textComponent.props.style[0].fontWeight).toBe('600');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle2Bold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle2Bold",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(16);
    expect(textComponent.props.style[0].fontWeight).toBe('700');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });

  // Subtitle03
  test('should render subtitle03Regular variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle03Regular",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(14);
    expect(textComponent.props.style[0].fontWeight).toBe('400');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle03Medium variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle03Medium",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(14);
    expect(textComponent.props.style[0].fontWeight).toBe('500');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle03Semibold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle03Semibold",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(14);
    expect(textComponent.props.style[0].fontWeight).toBe('600');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle03Bold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle03Bold",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(14);
    expect(textComponent.props.style[0].fontWeight).toBe('700');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });

  // Subtitle3
  test('should render subtitle3Regular variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle3Regular",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(14);
    expect(textComponent.props.style[0].fontWeight).toBe('400');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle3Medium variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle3Medium",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(14);
    expect(textComponent.props.style[0].fontWeight).toBe('500');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle3Semibold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle3Semibold",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(14);
    expect(textComponent.props.style[0].fontWeight).toBe('600');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle3Bold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle3Bold",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(14);
    expect(textComponent.props.style[0].fontWeight).toBe('700');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });

  // Subtitle04
  test('should render subtitle04Regular variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle04Regular",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(12);
    expect(textComponent.props.style[0].fontWeight).toBe('400');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle04Medium variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle04Medium",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(12);
    expect(textComponent.props.style[0].fontWeight).toBe('500');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle04Semibold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle04Semibold",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(12);
    expect(textComponent.props.style[0].fontWeight).toBe('600');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle04Bold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle04Bold",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(12);
    expect(textComponent.props.style[0].fontWeight).toBe('700');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });

  // Subtitle4
  test('should render subtitle4Regular variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle4Regular",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(12);
    expect(textComponent.props.style[0].fontWeight).toBe('400');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle4Medium variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle4Medium",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(12);
    expect(textComponent.props.style[0].fontWeight).toBe('500');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle4Semibold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle4Semibold",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(12);
    expect(textComponent.props.style[0].fontWeight).toBe('600');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle4Bold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "subtitle4Bold",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(12);
    expect(textComponent.props.style[0].fontWeight).toBe('700');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });

  // Body
  test('should render bodyText variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "bodyText",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(14);
    expect(textComponent.props.style[0].fontWeight).toBe('400');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render body1 variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "body1",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(16);
    expect(textComponent.props.style[0].lineHeight).toBe(18);
    expect(textComponent.props.style[0].fontWeight).toBe('400');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render body2 variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "body2",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(14);
    expect(textComponent.props.style[0].lineHeight).toBe(16);
    expect(textComponent.props.style[0].fontWeight).toBe('400');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render body3 variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "body3",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(12);
    expect(textComponent.props.style[0].lineHeight).toBe(14);
    expect(textComponent.props.style[0].fontWeight).toBe('400');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render bodyUnderline variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "bodyUnderline",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(14);
    expect(textComponent.props.style[0].fontWeight).toBe('400');
    expect(textComponent.props.style[0].textDecorationLine).toBe('underline');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render bodyTextLink variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "bodyTextLink",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(14);
    expect(textComponent.props.style[0].fontWeight).toBe('500');
    expect(textComponent.props.style[0].textDecorationLine).toBe('underline');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render bodyLongText variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "bodyLongText",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(14);
    expect(textComponent.props.style[0].fontWeight).toBe('400');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });

  // Caption
  test('should render caption variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "caption",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(12);
    expect(textComponent.props.style[0].lineHeight).toBe(14);
    expect(textComponent.props.style[0].fontWeight).toBe('500');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render captionText variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "captionText",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(12);
    expect(textComponent.props.style[0].lineHeight).toBe(14);
    expect(textComponent.props.style[0].fontWeight).toBe('500');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render captionMedium variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "captionMedium",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(12);
    expect(textComponent.props.style[0].fontWeight).toBe('500');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render captionLongText variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "captionLongText",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(12);
    expect(textComponent.props.style[0].fontWeight).toBe('400');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render captionTextLink variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
      testID: "text",
      variant: "captionTextLink",
      children: "Test Text"
    }));
    const textComponent = getByTestId('text');
    // then
    expect(textComponent.props.style[0].fontSize).toBe(12);
    expect(textComponent.props.style[0].fontWeight).toBe('500');
    expect(textComponent.props.style[0].textDecorationLine).toBe('underline');
    expect(textComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  //
});
//# sourceMappingURL=Text.test.js.map