"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _theme = _interopRequireDefault(require("../../theme"));
var _Box = _interopRequireDefault(require("../Box/Box"));
var _TextAreaLabel = require("./TextAreaLabel");
var _TextAreaHelpText = require("./TextAreaHelpText");
var _TextAreaCounterText = require("./TextAreaCounterText");
var _hooks = require("./hooks");
var _utils = require("./utils");
var _restyle = require("@ergenekonyigit/restyle");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const isRTL = _reactNative.I18nManager.isRTL;
const sizeVariant = (0, _restyle.createVariant)({
  property: 'size',
  themeKey: 'textAreaSizeVariants'
});
const BaseTextArea = (0, _restyle.createRestyleComponent)([_restyle.layout, _restyle.spacing, _restyle.border, _restyle.backgroundColor, _restyle.position, sizeVariant], _reactNative.TextInput);
const TextArea = /*#__PURE__*/(0, _react.forwardRef)(({
  size = 'medium',
  label,
  labelFixed = false,
  placeholder,
  helpText,
  counterText,
  errorText,
  error = false,
  disabled = false,
  editable = true,
  easing = _reactNative.Easing.inOut(_reactNative.Easing.ease),
  testID = 'textArea',
  maxLength = 200,
  maxLengthErrorText = 'You have exceeded the character limit.',
  ...rest
}, ref) => {
  const [focused, setFocused] = _react.default.useState(false);
  const [errorState, setErrorState] = _react.default.useState(false);
  const [length, setLength] = _react.default.useState(0);
  const innerRef = (0, _hooks.useInputRef)();
  const {
    value,
    isControlled,
    setUncontrolledValue
  } = (0, _hooks.useInputValue)({
    value: rest.value,
    defaultValue: rest.defaultValue
  });
  const placeholderText = (0, _utils.getPlaceholderText)({
    label,
    labelFixed,
    placeholder,
    value,
    focused
  });
  const borderColor = (0, _utils.getBorderColor)({
    focused,
    errorState
  });
  const textAreaHeight = {
    small: _theme.default.textAreaSizeVariants.small.height,
    medium: _theme.default.textAreaSizeVariants.medium.height,
    large: _theme.default.textAreaSizeVariants.large.height
  }[size];
  const {
    startAnimation,
    stopAnimation,
    animatedViewProps,
    animatedTextProps
  } = (0, _hooks.useOutlineLabelVisibility)({
    theme: _theme.default,
    easing,
    textAreaHeight,
    focused,
    value,
    disabled,
    helpText,
    counterText,
    errorText,
    errorState
  });
  (0, _react.useEffect)(() => {
    setErrorState(error);
  }, [error]);
  const handleFocus = async e => {
    if (disabled || !editable) {
      return;
    }
    await startAnimation();
    setFocused(true);
    setErrorState(false);
    rest.onFocus?.(e);
  };
  const handleBlur = async e => {
    if (disabled || !editable) {
      return;
    }
    if (!value) {
      await stopAnimation();
    }
    setFocused(false);
    rest.onBlur?.(e);
  };
  const handleChangeText = nextValue => {
    if (disabled || !editable) {
      return;
    }
    if (!isControlled) {
      setUncontrolledValue(nextValue);
    }
    setLength(nextValue.length);
    rest.onChangeText?.(nextValue);
  };
  _react.default.useImperativeHandle(ref, () => ({
    focus: () => innerRef.current?.focus(),
    clear: () => innerRef.current?.clear(),
    setNativeProps: args => innerRef.current?.setNativeProps(args),
    isFocused: () => innerRef.current?.isFocused() || false,
    blur: () => innerRef.current?.blur()
  }));
  const placeHolderSize = () => {
    if (size === 'large') {
      return 'm';
    } else if (size === 'medium') {
      return 'xs';
    } else {
      return '2xs';
    }
  };
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Box.default, {
    py: "2xs",
    px: "m",
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextAreaLabel.TextAreaLabel, {
      label: label,
      labelFixed: labelFixed,
      errorState: errorState,
      animatedViewProps: animatedViewProps,
      animatedTextProps: animatedTextProps,
      textAreaHeight: textAreaHeight
    }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
      flexDirection: "row",
      alignItems: "center",
      borderWidth: 1,
      borderRadius: "m",
      borderColor: length > maxLength ? 'dangerKey' : borderColor,
      backgroundColor: disabled ? 'neutralLightest' : 'neutralFull',
      px: "m",
      justifyContent: "flex-start",
      zIndex: "layer_0",
      accessibilityLabel: `${testID}-box`,
      testID: `${testID}-box`,
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(BaseTextArea, {
        ...rest,
        flex: 1,
        paddingTop: placeHolderSize(),
        ref: innerRef,
        multiline: true,
        height: textAreaHeight,
        bg: "transparent",
        onFocus: handleFocus,
        onBlur: handleBlur,
        placeholder: placeholderText,
        placeholderTextColor: _theme.default.colors.neutralLight,
        onChangeText: handleChangeText,
        value: value,
        disabled: disabled,
        editable: !disabled,
        accessibilityLabel: testID,
        testID: testID,
        textAlign: isRTL ? 'right' : 'left'
      })
    }), /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Box.default, {
      flexDirection: "row",
      justifyContent: "space-between",
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
        justifyContent: "flex-start",
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_TextAreaHelpText.TextAreaHelpText, {
          helpText: helpText,
          errorState: length > maxLength ? true : errorState,
          errorText: length > maxLength ? maxLengthErrorText : errorText
        })
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
        justifyContent: "flex-end",
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_TextAreaCounterText.TextAreaCounterText, {
          counterText: length,
          errorState: length > maxLength ? true : errorState
        })
      })]
    })]
  });
});
var _default = exports.default = TextArea;
//# sourceMappingURL=TextArea.js.map