"use strict";

var _react = _interopRequireDefault(require("react"));
var _reactTestRenderer = require("react-test-renderer");
var _testUtils = require("../../test-utils");
var _theme = _interopRequireDefault(require("../../theme"));
var _TextArea = _interopRequireDefault(require("./TextArea"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
describe('TextArea', () => {
  test('should render TextArea correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextArea.default, {
      label: "label"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render label fixed TextArea correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextArea.default, {
      label: "label",
      labelFixed: true,
      placeholder: "placeholder"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render disabled TextArea correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextArea.default, {
      disabled: true,
      label: "label"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render TextArea with help text correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextArea.default, {
      label: "label",
      helpText: "helpText"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render TextArea with error state correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextArea.default, {
      label: "label",
      error: true
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render TextArea with error state and error text correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextArea.default, {
      label: "label",
      error: true,
      errorText: "errorText"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render TextArea with small size correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextArea.default, {
      label: "label",
      size: "small"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render TextArea with medium size correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextArea.default, {
      label: "label",
      size: "medium"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render TextArea with large size correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextArea.default, {
      label: "label",
      size: "large"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should focus TextArea correctly', async () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextArea.default, {
      label: "label"
    }));

    // then
    expect(getByTestId('textArea-box').props.style[0].borderColor).toBe(_theme.default.colors.neutralLighter);

    // when
    (0, _testUtils.fireEvent)(getByTestId('textArea'), 'onFocus');

    // then
    await (0, _testUtils.waitFor)(() => {
      expect(getByTestId('textArea-box').props.style[0].borderColor).toBe(_theme.default.colors.primaryKey);
    });
  });
  test('should not focus and blur TextArea when TextArea is disabled', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextArea.default, {
      label: "label",
      disabled: true
    }));

    // then
    expect(getByTestId('textArea-box').props.style[0].borderColor).toBe(_theme.default.colors.neutralLighter);

    // when
    (0, _reactTestRenderer.act)(() => {
      const textArea = getByTestId('textArea');
      (0, _testUtils.fireEvent)(textArea, 'onFocus');
      (0, _testUtils.fireEvent)(textArea, 'onBlur');
    });

    // then
    expect(getByTestId('textArea-box').props.style[0].borderColor).toBe(_theme.default.colors.neutralLighter);
  });
  test('should blur TextArea without value correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextArea.default, {
      label: "label"
    }));

    // then
    expect(getByTestId('textArea-box').props.style[0].borderColor).toBe(_theme.default.colors.neutralLighter);

    // when
    (0, _reactTestRenderer.act)(() => {
      const textArea = getByTestId('textArea');
      (0, _testUtils.fireEvent)(textArea, 'onFocus');
      (0, _testUtils.fireEvent)(textArea, 'onBlur');
    });

    // then
    expect(getByTestId('textArea-box').props.style[0].borderColor).toBe(_theme.default.colors.neutralLighter);
  });
  test('should blur TextArea with value correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextArea.default, {
      label: "label",
      value: "value"
    }));

    // then
    expect(getByTestId('textArea-box').props.style[0].borderColor).toBe(_theme.default.colors.neutralLighter);

    // when
    (0, _reactTestRenderer.act)(() => {
      const textArea = getByTestId('textArea');
      (0, _testUtils.fireEvent)(textArea, 'onFocus');
      (0, _testUtils.fireEvent)(textArea, 'onBlur');
    });

    // then
    expect(getByTestId('textArea-box').props.style[0].borderColor).toBe(_theme.default.colors.neutralLighter);
  });
  test('should change text of TextArea without value', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextArea.default, {
      label: "label"
    }));
    const textArea = getByTestId('textArea');
    _testUtils.fireEvent.changeText(textArea, 'e-mail@mail.com');

    // then
    expect(textArea.props.value).toBe('e-mail@mail.com');
  });
  test('should change text of textArea with value', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextArea.default, {
      label: "label",
      value: "value"
    }));
    const textArea = getByTestId('textArea');
    _testUtils.fireEvent.changeText(textArea, 'e-mail@mail.com');

    // then
    expect(textArea.props.value).toBe('value');
  });
  test('should not change text of TextArea when TextArea is disabled', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextArea.default, {
      label: "label",
      disabled: true
    }));
    const textArea = getByTestId('textArea');
    _testUtils.fireEvent.changeText(textArea, 'e-mail@mail.com');

    // then
    expect(textArea.props.value).not.toBe('e-mail@mail.com');
  });
  test('should change text of TextArea when TextArea has defaultValue', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextArea.default, {
      label: "label",
      defaultValue: "defaultValue"
    }));
    const textArea = getByTestId('textArea');
    _testUtils.fireEvent.changeText(textArea, 'e-mail@mail.com');

    // then
    expect(textArea.props.value).toBe('e-mail@mail.com');
  });
  test('should access textAreas handle functions correctly', () => {
    // given
    const ref = /*#__PURE__*/_react.default.createRef();

    // when
    (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextArea.default, {
      label: "label",
      ref: ref
    }));
    (0, _reactTestRenderer.act)(() => {
      ref.current?.focus();
      ref.current?.blur();
      ref.current?.clear();
      ref.current?.isFocused();
      ref.current?.setNativeProps({
        text: ''
      });
    });

    // then
    expect(ref.current?.focus).toBeTruthy();
  });
});
//# sourceMappingURL=TextArea.test.js.map