"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useOutlineLabelVisibility = exports.useInputValue = exports.useInputRef = void 0;
var _react = require("react");
var _reactNative = require("react-native");
var _utils = require("./utils");
const useInputRef = () => (0, _react.useRef)(null);
exports.useInputRef = useInputRef;
const useInputValue = ({
  value,
  defaultValue
}) => {
  const isControlled = value !== undefined;
  const validInputValue = isControlled ? value : defaultValue;
  const [uncontrolledValue, setUncontrolledValue] = (0, _react.useState)(validInputValue);
  return {
    isControlled,
    setUncontrolledValue,
    value: isControlled ? value : uncontrolledValue
  };
};
exports.useInputValue = useInputValue;
const useOutlineLabelVisibility = ({
  theme,
  easing,
  textAreaHeight,
  focused,
  value,
  disabled,
  helpText,
  counterText,
  errorText,
  errorState
}) => {
  const duration = 200;
  const commonAnimatedProps = {
    duration,
    useNativeDriver: false,
    easing
  };
  const labelFontSize = theme.textVariants.defaults.fontSize;
  const labelLineHeightValue = theme.textVariants.subtitle2Regular.fontSize;
  const initialTopValue = 12;
  const labelPositionEmptyValue = 0;
  const labelPositionFillValue = labelLineHeightValue / 2 + initialTopValue - 2;
  const labelPositionRef = (0, _react.useRef)(new _reactNative.Animated.Value(value ? labelPositionFillValue : labelPositionEmptyValue)).current;
  const fontSizeRef = (0, _react.useRef)(new _reactNative.Animated.Value(value ? theme.textVariants.subtitle4Regular.fontSize : theme.textVariants.defaults.fontSize)).current;
  const lineHeightRef = (0, _react.useRef)(new _reactNative.Animated.Value(value ? theme.textVariants.defaults.fontSize : theme.textVariants.subtitle2Regular.fontSize)).current;

  /* istanbul ignore next */
  const startAnimation = async () => {
    return new Promise(res => {
      _reactNative.Animated.parallel([_reactNative.Animated.timing(labelPositionRef, {
        toValue: labelPositionFillValue,
        ...commonAnimatedProps
      }), _reactNative.Animated.timing(fontSizeRef, {
        toValue: labelFontSize - 2,
        ...commonAnimatedProps
      }), _reactNative.Animated.timing(lineHeightRef, {
        toValue: labelLineHeightValue - 2,
        ...commonAnimatedProps
      })]).start(res);
    });
  };

  /* istanbul ignore next */
  const stopAnimation = async () => {
    return new Promise(res => {
      _reactNative.Animated.parallel([_reactNative.Animated.timing(labelPositionRef, {
        toValue: labelPositionEmptyValue,
        ...commonAnimatedProps
      }), _reactNative.Animated.timing(fontSizeRef, {
        toValue: labelFontSize,
        ...commonAnimatedProps
      }), _reactNative.Animated.timing(lineHeightRef, {
        toValue: labelLineHeightValue,
        ...commonAnimatedProps
      })]).start(res);
    });
  };
  let viewHeight = textAreaHeight + 6;
  const helpTextContent = (0, _utils.getHelpText)({
    helpText,
    errorText,
    errorState
  });
  if (helpTextContent) {
    viewHeight = textAreaHeight + 24;
  }
  const counterTextContent = (0, _utils.getCounterText)({
    counterText,
    errorText,
    errorState
  });
  if (counterTextContent) {
    viewHeight = textAreaHeight + 24;
  }
  const animatedViewProps = (0, _react.useMemo)(() => {
    return {
      style: {
        position: 'absolute',
        bottom: labelPositionRef,
        left: theme.spacing.xs,
        zIndex: 2,
        height: viewHeight
      }
    };
  }, [labelPositionRef, theme.spacing, viewHeight]);
  const animatedTextProps = (0, _react.useMemo)(() => {
    return {
      style: {
        fontFamily: theme.fonts.regular,
        color: focused ? theme.colors.neutralDark : theme.colors.neutralLight,
        backgroundColor: disabled ? 'transparent' : theme.colors.neutralFull,
        height: lineHeightRef,
        paddingLeft: theme.spacing['3xs'],
        paddingRight: theme.spacing['3xs'],
        top: initialTopValue - 4,
        fontSize: fontSizeRef,
        lineHeight: lineHeightRef
      }
    };
  }, [disabled, focused, fontSizeRef, initialTopValue, lineHeightRef, theme.colors.neutralDark, theme.colors.neutralFull, theme.colors.neutralLight, theme.fonts, theme.spacing]);
  return {
    startAnimation,
    stopAnimation,
    animatedViewProps,
    animatedTextProps
  };
};
exports.useOutlineLabelVisibility = useOutlineLabelVisibility;
//# sourceMappingURL=hooks.js.map