"use strict";

var _react = _interopRequireDefault(require("react"));
var _theme = _interopRequireDefault(require("../../theme"));
var _testUtils = require("../../test-utils");
var _TextLink = _interopRequireDefault(require("./TextLink"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
describe('TextLink', () => {
  test('should render textLink correctly', () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      accessibilityLabel: "text",
      children: "test"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should not render given textLink correctly', () => {
    // when
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink"
    }));
    const textLinkComponent = queryByTestId('textLink');
    // then
    expect(textLinkComponent).toBe(null);
  });
  test('should render given textLink correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.children).toBe('Test Text');
  });
  test('should render variant correctly when isPressed true', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "heading1",
      isPressed: true,
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(30);
    expect(textLinkComponent.props.style[0].lineHeight).toBe(36);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('400');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.primaryColor);
  });
  test('should clicked when pressed', () => {
    // given
    const onPress = jest.fn();

    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "heading1",
      isPressed: true,
      onPress: onPress,
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    _testUtils.fireEvent.press(textLinkComponent);

    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(30);
    expect(textLinkComponent.props.style[0].lineHeight).toBe(36);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('400');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.primaryColor);
    expect(onPress).toBeCalledTimes(1);
  });

  // Heading
  test('should render heading1 variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "heading1",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(30);
    expect(textLinkComponent.props.style[0].lineHeight).toBe(36);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('400');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render heading2 variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "heading2",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(28);
    expect(textLinkComponent.props.style[0].lineHeight).toBe(32);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('400');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render heading3 variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "heading3",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then

    expect(textLinkComponent.props.style[0].fontSize).toBe(24);
    expect(textLinkComponent.props.style[0].lineHeight).toBe(28);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('400');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });

  // Subtitle01
  test('should render subtitle01Regular variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle01Regular",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(20);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('400');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle01Medium variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle01Medium",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(20);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('500');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle01Semibold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle01Semibold",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(20);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('600');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle01Bold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle01Bold",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(20);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('700');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });

  // Subtitle1
  test('should render subtitle1Regular variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle1Regular",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(20);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('400');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle1Medium variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle1Medium",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(20);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('500');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle1Semibold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle1Semibold",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(20);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('600');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle1Bold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle1Bold",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(20);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('700');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });

  // Subtitle02
  test('should render subtitle02Regular variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle02Regular",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(16);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('400');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle02Medium variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle02Medium",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(16);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('500');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle02Semibold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle02Semibold",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(16);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('600');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle02Bold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle02Bold",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(16);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('700');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });

  // Subtitle2
  test('should render subtitle2Regular variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle2Regular",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(16);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('400');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle2Medium variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle2Medium",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(16);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('500');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle2Semibold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle2Semibold",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(16);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('600');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle2Bold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle2Bold",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(16);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('700');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });

  // Subtitle03
  test('should render subtitle03Regular variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle03Regular",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(14);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('400');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle03Medium variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle03Medium",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(14);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('500');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle03Semibold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle03Semibold",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(14);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('600');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle03Bold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle03Bold",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(14);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('700');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });

  // Subtitle3
  test('should render subtitle3Regular variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle3Regular",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(14);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('400');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle3Medium variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle3Medium",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(14);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('500');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle3Semibold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle3Semibold",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(14);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('600');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle3Bold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle3Bold",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(14);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('700');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });

  // Subtitle04
  test('should render subtitle04Regular variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle04Regular",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(12);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('400');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle04Medium variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle04Medium",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(12);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('500');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle04Semibold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle04Semibold",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(12);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('600');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle04Bold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle04Bold",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(12);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('700');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });

  // Subtitle4
  test('should render subtitle4Regular variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle4Regular",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(12);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('400');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle4Medium variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle4Medium",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(12);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('500');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle4Semibold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle4Semibold",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(12);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('600');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render subtitle4Bold variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "subtitle4Bold",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(12);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('700');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });

  // Body
  test('should render bodyText variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "bodyText",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(14);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('400');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render body1 variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "body1",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(16);
    expect(textLinkComponent.props.style[0].lineHeight).toBe(18);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('400');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render body2 variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "body2",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(14);
    expect(textLinkComponent.props.style[0].lineHeight).toBe(16);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('400');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render body3 variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "body3",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(12);
    expect(textLinkComponent.props.style[0].lineHeight).toBe(14);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('400');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render bodyUnderline variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "bodyUnderline",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(14);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('400');
    expect(textLinkComponent.props.style[0].textDecorationLine).toBe('underline');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render bodyTextLink variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "bodyTextLink",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(14);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('500');
    expect(textLinkComponent.props.style[0].textDecorationLine).toBe('underline');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render bodyLongText variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "bodyLongText",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(14);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('400');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });

  // Caption
  test('should render caption variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "caption",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(12);
    expect(textLinkComponent.props.style[0].lineHeight).toBe(14);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('500');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render captionText variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "captionText",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(12);
    expect(textLinkComponent.props.style[0].lineHeight).toBe(14);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('500');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render captionMedium variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "captionMedium",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(12);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('500');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render captionLongText variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "captionLongText",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(12);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('400');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  test('should render captionTextLink variant correctly', () => {
    // when
    const {
      getByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_TextLink.default, {
      testID: "textLink",
      variant: "captionTextLink",
      children: "Test Text"
    }));
    const textLinkComponent = getByTestId('textLink');
    // then
    expect(textLinkComponent.props.style[0].fontSize).toBe(12);
    expect(textLinkComponent.props.style[0].fontWeight).toBe('500');
    expect(textLinkComponent.props.style[0].textDecorationLine).toBe('underline');
    expect(textLinkComponent.props.style[0].color).toBe(_theme.default.colors.neutralDarker);
  });
  //
});
//# sourceMappingURL=TextLink.test.js.map