"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _Box = _interopRequireDefault(require("../Box/Box"));
var _ToastView = _interopRequireDefault(require("./ToastView"));
var _types = require("./types");
var _uuid = require("../../utils/uuid");
var _reactNativeSafeAreaContext = require("react-native-safe-area-context");
var _hooks = require("./hooks");
var _theme = _interopRequireDefault(require("../../theme"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
// @ts-ignore
const Toast = /*#__PURE__*/_react.default.memo(({
  ignoreKeyboard = false,
  extraPaddingBottom: extraMarginBottom = 0
}) => {
  const [data, setData] = _react.default.useState(null);
  const insets = (0, _reactNativeSafeAreaContext.useSafeAreaInsets)();
  const {
    keyboardHeight,
    isKeyboardVisible
  } = (0, _hooks.useKeyboard)();
  _react.default.useEffect(() => {
    Toast.show = params => {
      if (!params.text) {
        return false;
      }
      setData({
        id: (0, _uuid.uuid)(16),
        variant: params.variant,
        text: params.text,
        duration: params.duration ?? _types.ToastDurations.SHORT,
        action: params.action,
        actionText: params.actionText,
        bottomOffset: params.bottomOffset ?? 0
      });
    };
  }, []);
  const paddingBottom = _react.default.useMemo(() => {
    if (ignoreKeyboard || !isKeyboardVisible) {
      return {
        paddingBottom: insets.bottom * 3 + extraMarginBottom + data?.bottomOffset
      };
    }
    return {
      paddingBottom: _theme.default.spacing['2xs'] + keyboardHeight + extraMarginBottom + data?.bottomOffset
    };
  }, [ignoreKeyboard, extraMarginBottom, insets.bottom, isKeyboardVisible, keyboardHeight, data?.bottomOffset]);
  const toastView = _react.default.useMemo(() => {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_ToastView.default, {
      variant: data?.variant,
      text: data?.text,
      onDisappared: () => setData(null),
      duration: data?.duration,
      action: data?.action,
      actionText: data?.actionText
    }, data?.id);
  }, [data]);
  if (!data) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_jsxRuntime.Fragment, {});
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
    position: "absolute",
    pointerEvents: "box-none",
    testID: "toast-wrapper",
    accessibilityLabel: "toast-wrapper",
    width: "100%",
    px: "xl",
    bottom: 0,
    style: paddingBottom,
    children: toastView
  });
});
Toast.show = () => {
  // eslint-disable-next-line no-console
  console.warn('Please add <Toast/> to your root view');
};
var _default = exports.default = Toast;
//# sourceMappingURL=Toast.js.map