"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _Text = _interopRequireDefault(require("../Text/Text"));
var _types = require("./types");
var _utils = require("./utils");
var _Box = _interopRequireDefault(require("../Box/Box"));
var _restyle = require("@ergenekonyigit/restyle");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const variantVariant = (0, _restyle.createVariant)({
  property: 'variant',
  themeKey: 'toastVariants'
});
const ToastViewContainer = (0, _restyle.createRestyleComponent)([variantVariant], _reactNative.Animated.View);
const ToastView = /*#__PURE__*/_react.default.forwardRef(({
  variant = 'default',
  text,
  duration = _types.ToastDurations.SHORT,
  onDisappared,
  action,
  actionText,
  ...rest
}, ref) => {
  const dims = (0, _reactNative.useWindowDimensions)();
  const anim = _react.default.useRef(new _reactNative.Animated.Value(dims.height / 2)).current;
  const layoutSizesRef = _react.default.useRef();
  const timerRef = _react.default.useRef((0, _utils.pausableTimer)(() => {
    playHideAnim();
  }, duration));
  const panResponderRef = _react.default.useRef(_reactNative.PanResponder.create({
    onStartShouldSetPanResponderCapture: (e, gestureState) => {
      return !action || !(gestureState.dx === 0 && gestureState.dy === 0);
    },
    onMoveShouldSetPanResponder: () => true,
    onPanResponderGrant: () => {
      timerRef.current.pause();
    },
    onPanResponderMove: (e, gestureState) => {
      if (gestureState.dy >= 0) {
        _reactNative.Animated.event([null, {
          dy: anim
        }], {
          useNativeDriver: false
        })(e, gestureState);
      }
    },
    onPanResponderRelease: (e, gestureState) => {
      if (gestureState.dy > (layoutSizesRef.current?.height ?? 0) || gestureState.vy > 0.05) {
        playHideAnim();
      } else {
        playShowAnim();
        timerRef.current.resume(2000);
      }
    }
  }));
  _react.default.useImperativeHandle(ref, () => ({
    show() {
      playShowAnim();
    },
    hide() {
      playHideAnim();
    }
  }));
  const playShowAnim = _react.default.useCallback(() => {
    _reactNative.Animated.timing(anim, {
      toValue: 0,
      duration: 333,
      useNativeDriver: true
    }).start();
  }, [anim]);
  const playHideAnim = _react.default.useCallback(() => {
    _reactNative.Animated.timing(anim, {
      toValue: dims.height / 2,
      duration: 333,
      useNativeDriver: true
    }).start(onDisappared);
  }, [anim, dims.height, onDisappared]);
  _react.default.useEffect(() => {
    playShowAnim();
    return () => {
      timerRef.current.kill();
    };
  }, [playShowAnim, timerRef]);
  const onLayout = _react.default.useCallback(event => {
    layoutSizesRef.current = event.nativeEvent.layout;
  }, []);
  const actionView = _react.default.useMemo(() => {
    if (!action) {
      return null;
    }
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.TouchableOpacity, {
      onPress: () => action(playHideAnim),
      testID: "toast-action",
      accessibilityLabel: "toast-action",
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
        variant: "subtitle03Medium",
        color: "neutralDarker",
        testID: "toast-action-text",
        accessibilityLabel: "toast-action-text",
        p: "2xs",
        children: (0, _utils.capitalizeFirstLetter)(actionText)
      })
    });
  }, [action, actionText, playHideAnim]);
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(ToastViewContainer, {
    ...panResponderRef.current.panHandlers,
    variant: variant,
    onLayout: onLayout,
    testID: "toast-container",
    accessibilityLabel: "toast-container",
    style: {
      transform: [{
        translateY: anim
      }]
    },
    ...rest,
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
      flex: 1,
      shadowRadius: 30,
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
        variant: "bodyText",
        color: "neutralDarker",
        testID: "toast-text",
        accessibilityLabel: "toast-text",
        textAlign: "left",
        children: (0, _utils.getFirstNChar)(text, 250, '...')
      })
    }), actionView]
  });
});
var _default = exports.default = ToastView;
//# sourceMappingURL=ToastView.js.map