"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useKeyboard = useKeyboard;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function useKeyboard() {
  const [keyboardHeight, setKeyboardHeight] = _react.default.useState(0);
  const [isKeyboardVisible, setIsKeyboardVisible] = _react.default.useState(false);
  const onShow = _react.default.useCallback(event => {
    const {
      height
    } = event.endCoordinates;
    setKeyboardHeight(height);
    setIsKeyboardVisible(true);
  }, []);
  const onHide = _react.default.useCallback(() => {
    setKeyboardHeight(0);
    setIsKeyboardVisible(false);
  }, []);
  _react.default.useEffect(() => {
    if (_reactNative.Platform.OS !== 'ios') {
      return () => {};
    }
    const didShowListener = _reactNative.Keyboard.addListener('keyboardDidShow', onShow);
    const didHideListener = _reactNative.Keyboard.addListener('keyboardDidHide', onHide);
    return () => {
      didShowListener.remove();
      didHideListener.remove();
    };
  }, [onHide, onShow]);
  return {
    keyboardHeight,
    isKeyboardVisible
  };
}
//# sourceMappingURL=hooks.js.map