"use strict";

var _reactHooks = require("@testing-library/react-hooks");
var _reactNative = require("react-native");
var _hooks = require("./hooks");
var _RCTDeviceEventEmitter = _interopRequireDefault(require("react-native/Libraries/EventEmitter/RCTDeviceEventEmitter"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/* eslint-env jest */

// @ts-ignore

const setup = (platform = 'ios') => {
  _reactNative.Platform.OS = platform;
  const utils = (0, _reactHooks.renderHook)(_hooks.useKeyboard);
  return {
    ...utils
  };
};
describe('test useKeyboard hook', () => {
  it('returns defaults', () => {
    const {
      result
    } = setup();
    expect(result.current.isKeyboardVisible).toBe(false);
    expect(result.current.keyboardHeight).toBe(0);
  });
  it('updates keyboard height on show', () => {
    const {
      result
    } = setup();
    expect(result.current.isKeyboardVisible).toBe(false);
    expect(result.current.keyboardHeight).toBe(0);
    (0, _reactHooks.act)(() => {
      // @ts-ignore
      _RCTDeviceEventEmitter.default.emit('keyboardDidShow', {
        endCoordinates: {
          height: 425
        }
      });
    });
    expect(result.current.isKeyboardVisible).toBe(true);
    expect(result.current.keyboardHeight).toBe(425);
  });
  it('updates keyboard height on hide', () => {
    const {
      result
    } = setup();
    expect(result.current.isKeyboardVisible).toBe(false);
    expect(result.current.keyboardHeight).toBe(0);
    (0, _reactHooks.act)(() => {
      // @ts-ignore
      _RCTDeviceEventEmitter.default.emit('keyboardDidShow', {
        endCoordinates: {
          height: 425
        }
      });
    });
    expect(result.current.isKeyboardVisible).toBe(true);
    expect(result.current.keyboardHeight).toBe(425);
    (0, _reactHooks.act)(() => {
      // @ts-ignore
      _RCTDeviceEventEmitter.default.emit('keyboardDidHide');
    });
    expect(result.current.isKeyboardVisible).toBe(false);
    expect(result.current.keyboardHeight).toBe(0);
  });
  it('does nothing on Android', () => {
    const {
      result
    } = setup('android');
    expect(result.current.isKeyboardVisible).toBe(false);
    expect(result.current.keyboardHeight).toBe(0);
  });
});
//# sourceMappingURL=hooks.test.js.map