"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Overlay = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _reactNativeSvg = _interopRequireWildcard(require("react-native-svg"));
var _theme = _interopRequireDefault(require("../../theme"));
var _Box = _interopRequireDefault(require("../Box/Box"));
var _TooltipContext = require("./TooltipContext");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const isRTL = _reactNative.I18nManager.isRTL;
const Overlay = () => {
  const overlayRef = _react.default.useRef(null);
  const {
    activeTooltip,
    hide,
    overlayViewport,
    setOverlayViewport
  } = (0, _TooltipContext.useTooltipContext)();
  const onLayout = _react.default.useCallback(() => {
    overlayRef.current?.measure((x, y, w, h, px, py) => {
      setOverlayViewport({
        x,
        y,
        w,
        h,
        px,
        py
      });
    });
  }, [setOverlayViewport]);
  const close = _react.default.useCallback(() => {
    if (activeTooltip) {
      hide(activeTooltip.id);
    }
  }, [activeTooltip, hide]);
  const highlightView = _react.default.useMemo(() => {
    if (!activeTooltip) {
      return null;
    }
    const {
      id,
      overlay,
      hole,
      highlight,
      viewport,
      holePadding
    } = activeTooltip;
    if (!(overlay && hole && highlight)) {
      return null;
    }
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
      testID: `tooltip-highlight-${id}`,
      bg: "white",
      position: "absolute",
      borderRadius: "m",
      justifyContent: "center",
      alignItems: "center",
      top: viewport.py - (overlayViewport?.py ?? 0) - holePadding,
      left: isRTL ? undefined : viewport.px - holePadding,
      right: isRTL ? viewport.px - holePadding : undefined,
      width: viewport.w + holePadding * 2,
      height: viewport.h + holePadding * 2,
      children: activeTooltip.children
    });
  }, [activeTooltip, overlayViewport]);
  if (!activeTooltip) {
    return null;
  }
  const {
    id,
    overlay,
    hole
  } = activeTooltip;
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.TouchableWithoutFeedback, {
    onPress: close,
    accessibilityLabel: `tooltip-overlay-wrapper-${id}`,
    testID: `tooltip-overlay-wrapper-${id}`,
    children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Box.default, {
      position: "absolute",
      flex: 1,
      height: '100%',
      width: '100%',
      onLayout: onLayout,
      ref: overlayRef,
      children: [highlightView, /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSvg.default, {
        height: "100%",
        width: "100%",
        pointerEvents: "none",
        children: overlay ? /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNativeSvg.G, {
          children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSvg.Defs, {
            children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNativeSvg.Mask, {
              id: "clip",
              children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSvg.Rect, {
                fill: "#ffffff",
                width: "100%",
                height: "100%"
              }), overlayViewport && hole ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSvg.Rect, {
                accessibilityLabel: `tooltip-hole-${id}`,
                testID: `tooltip-hole-${id}`,
                fill: "#000",
                ry: 6,
                rx: 6,
                x: activeTooltip.viewport.px - activeTooltip.holePadding,
                y: activeTooltip.viewport.py - activeTooltip.holePadding - (overlayViewport?.py ?? 0),
                width: activeTooltip.viewport.w + activeTooltip.holePadding * 2,
                height: activeTooltip.viewport.h + activeTooltip.holePadding * 2
              }) : undefined]
            })
          }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSvg.Rect, {
            accessibilityLabel: `tooltip-overlay-${id}`,
            testID: `tooltip-overlay-${id}`,
            width: _reactNative.Dimensions.get('screen').width,
            height: _reactNative.Dimensions.get('screen').height,
            clipRule: 'evenodd',
            fillRule: 'nonzero',
            vectorEffect: "inherit",
            fill: _theme.default.colors.neutralDarker,
            fillOpacity: ".7",
            mask: hole ? 'url(#clip)' : undefined
          })]
        }) : undefined
      })]
    })
  });
};
exports.Overlay = Overlay;
//# sourceMappingURL=Overlay.js.map