"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _Box = _interopRequireDefault(require("../Box/Box"));
var _TooltipContext = require("./TooltipContext");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const Tooltip = /*#__PURE__*/_react.default.forwardRef(({
  children,
  id,
  pressable = true,
  content,
  overlay = false,
  hole = false,
  highlight = false,
  position = 'top',
  wrapperStyle,
  holePadding = 4,
  color = 'infoKey',
  onClose = () => null,
  onError = () => null
}, ref) => {
  const {
    show,
    hide
  } = (0, _TooltipContext.useTooltipContext)();
  const triggerRef = _react.default.useRef(null);
  const [tooltipData, setTooltipData] = _react.default.useState();
  const isPending = _react.default.useRef(false);
  _react.default.useImperativeHandle(ref, () => {
    return {
      show: () => {
        if (tooltipData) {
          show(tooltipData);
        } else {
          isPending.current = true;
        }
      },
      hide: () => {
        if (tooltipData) {
          hide(tooltipData?.id);
        }
      }
    };
  }, [tooltipData, show, hide]);
  const onLayout = _react.default.useCallback(() => {
    const data = {
      id,
      position,
      content,
      overlay,
      hole,
      holePadding,
      highlight,
      color,
      onClose,
      onError,
      triggerRef,
      children
    };
    setTooltipData(data);
    if (isPending.current) {
      show(data);
    }
  }, [id, position, content, overlay, hole, holePadding, highlight, color, onClose, onError, show, children]);
  const openTooltip = _react.default.useCallback(() => {
    if (tooltipData) {
      show(tooltipData);
    }
  }, [tooltipData, show]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.TouchableOpacity, {
    testID: `tooltip-trigger-${id}`,
    accessibilityLabel: `tooltip-trigger-${id}`,
    disabled: !pressable,
    onPress: openTooltip,
    style: wrapperStyle,
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
      testID: `tooltip-child-wrapper-${id}`,
      ref: triggerRef,
      onLayout: onLayout,
      children: children
    })
  });
});
var _default = exports.default = Tooltip;
//# sourceMappingURL=Tooltip.js.map