"use strict";

var _react = _interopRequireDefault(require("react"));
var _reactNativeSafeAreaContext = require("react-native-safe-area-context");
var _testUtils = require("../../test-utils");
var _dimentions = require("../../utils/dimentions");
var _Box = _interopRequireDefault(require("../Box/Box"));
var _Button = _interopRequireDefault(require("../Button/Button"));
var _Text = _interopRequireDefault(require("../Text/Text"));
var _Overlay = require("./Overlay");
var _Tooltip = _interopRequireDefault(require("./Tooltip"));
var _TooltipContext = require("./TooltipContext");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
describe('Tooltip', () => {
  const mockOverlayMeasure = jest.fn();
  const mockChildWrapperTopMeasure = jest.fn();
  const mockChildWrapperBottomMeasure = jest.fn();
  const mockChildWrapperOnLayoutParam = {
    nativeEvent: {
      layout: {
        width: 200,
        height: 30
      }
    }
  };
  beforeEach(() => {
    mockChildWrapperTopMeasure.mockImplementation(f => {
      // x,y,w,h,px,py
      f(0, 0, 200, 30, 16, 16);
    });
    mockChildWrapperBottomMeasure.mockImplementation(f => {
      // x,y,w,h,px,py
      f(0, 0, 200, 30, 16, 800);
    });
    mockOverlayMeasure.mockImplementation(f => {
      // x,y,w,h,px,py
      f(0, 0, 400, 800, 0, 62);
    });
  });
  afterEach(() => {
    jest.resetAllMocks();
    jest.clearAllMocks();
    (0, _testUtils.cleanup)();
  });
  test('should render top correctly', async () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSafeAreaContext.SafeAreaProvider, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_TooltipContext.TooltipProvider, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tooltip.default, {
          id: 'test',
          content: 'content Lorem ipsum dolor sit amet',
          position: 'top',
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
            children: "trigger text"
          })
        })
      })
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render bottom correctly', async () => {
    // when
    const {
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSafeAreaContext.SafeAreaProvider, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_TooltipContext.TooltipProvider, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tooltip.default, {
          id: 'test',
          content: 'content Lorem ipsum dolor sit amet',
          position: 'bottom',
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
            children: "trigger text"
          })
        })
      })
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should not render without provider', async () => {
    try {
      (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSafeAreaContext.SafeAreaProvider, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tooltip.default, {
          id: 'test',
          content: 'content Lorem ipsum dolor sit amet',
          position: 'top',
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
            children: "trigger text"
          })
        })
      }));
    } catch (error) {
      expect(error.message).toBe('useTooltipContext must be used within a TooltipProvider');
    }
  });
  test('should show top and hide tooltip via trigger', async () => {
    // when
    const mockOnClose = jest.fn();
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSafeAreaContext.SafeAreaProvider, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_TooltipContext.TooltipProvider, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tooltip.default, {
          id: 'test',
          content: 'content Lorem ipsum dolor sit amet',
          position: 'top',
          onClose: mockOnClose,
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
            children: "trigger text"
          })
        })
      })
    }));

    // then
    const trigger = queryByTestId('tooltip-trigger-test');
    const childWrapper = queryByTestId('tooltip-child-wrapper-test');
    childWrapper.parent.instance.measure = mockChildWrapperTopMeasure;
    (0, _testUtils.fireEvent)(childWrapper, 'layout', mockChildWrapperOnLayoutParam);
    _testUtils.fireEvent.press(trigger);
    const overlayLayout = queryByTestId('tooltip-overlay-wrapper-test');
    overlayLayout.parent.instance.measure = mockOverlayMeasure;
    (0, _testUtils.fireEvent)(overlayLayout, 'layout', {});
    const content = queryByTestId('tooltip-content-test');
    expect(content).not.toBeNull();
    const close = queryByTestId('tooltip-close-test');
    _testUtils.fireEvent.press(close);
    expect(queryByTestId('tooltip-content-test')).toBeNull();
    expect(mockOnClose).toHaveBeenCalledWith('test');
  });
  test('should show bottom and hide tooltip via trigger', async () => {
    // when
    const mockOnClose = jest.fn();
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSafeAreaContext.SafeAreaProvider, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_TooltipContext.TooltipProvider, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tooltip.default, {
          id: 'test',
          overlay: true,
          hole: true,
          content: 'content Lorem ipsum dolor sit amet',
          position: 'bottom',
          onClose: mockOnClose,
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
            children: "trigger text"
          })
        })
      })
    }));

    // then
    const trigger = queryByTestId('tooltip-trigger-test');
    const childWrapper = queryByTestId('tooltip-child-wrapper-test');
    childWrapper.parent.instance.measure = mockChildWrapperTopMeasure;
    (0, _testUtils.fireEvent)(childWrapper, 'layout', mockChildWrapperOnLayoutParam);
    _testUtils.fireEvent.press(trigger);
    const overlayLayout = queryByTestId('tooltip-overlay-wrapper-test');
    overlayLayout.parent.instance.measure = mockOverlayMeasure;
    (0, _testUtils.fireEvent)(overlayLayout, 'layout', {});
    const content = queryByTestId('tooltip-content-test');
    expect(content).not.toBeNull();
    const close = queryByTestId('tooltip-close-test');
    _testUtils.fireEvent.press(close);
    expect(queryByTestId('tooltip-content-test')).toBeNull();
    expect(mockOnClose).toHaveBeenCalledWith('test');
  });
  test('should show bottom when there is no space at top', async () => {
    // when
    const mockOnClose = jest.fn();
    const {
      queryByTestId,
      getByTestId,
      getByA11yHint
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSafeAreaContext.SafeAreaProvider, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_TooltipContext.TooltipProvider, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tooltip.default, {
          id: 'test',
          content: 'content Lorem ipsum dolor sit amet',
          overlay: true,
          hole: true,
          position: 'top',
          onClose: mockOnClose,
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
            children: "trigger text"
          })
        })
      })
    }));

    // then
    const trigger = queryByTestId('tooltip-trigger-test');
    const childWrapper = queryByTestId('tooltip-child-wrapper-test');
    childWrapper.parent.instance.measure = mockChildWrapperTopMeasure;
    (0, _testUtils.fireEvent)(childWrapper, 'layout', mockChildWrapperOnLayoutParam);
    _testUtils.fireEvent.press(trigger);
    const overlayLayout = queryByTestId('tooltip-overlay-wrapper-test');
    overlayLayout.parent.instance.measure = mockOverlayMeasure;
    (0, _testUtils.fireEvent)(overlayLayout, 'layout', {});
    await (0, _testUtils.waitFor)(() => getByTestId('tooltip-content-test'));
    const popup = queryByTestId('tooltip-test');
    popup.parent.instance.measure = jest.fn().mockImplementation(f => {
      // x,y,w,h,px,py
      f(0, 0, 360, 200, 32, 62);
    });
    (0, _testUtils.fireEvent)(popup, 'layout', {});
    expect(getByA11yHint('bottom')).not.toBeNull();
  });
  test('should show top when there is no space at bottom', async () => {
    // when
    const mockOnClose = jest.fn();
    const {
      queryByTestId,
      getByTestId,
      getByA11yHint
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSafeAreaContext.SafeAreaProvider, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_TooltipContext.TooltipProvider, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tooltip.default, {
          id: 'test',
          content: 'content Lorem ipsum dolor sit amet',
          overlay: true,
          hole: true,
          position: 'bottom',
          onClose: mockOnClose,
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
            children: "trigger text"
          })
        })
      })
    }));

    // then
    const trigger = queryByTestId('tooltip-trigger-test');
    const childWrapper = queryByTestId('tooltip-child-wrapper-test');
    childWrapper.parent.instance.measure = mockChildWrapperBottomMeasure;
    (0, _testUtils.fireEvent)(childWrapper, 'layout', mockChildWrapperOnLayoutParam);
    _testUtils.fireEvent.press(trigger);
    const overlayLayout = queryByTestId('tooltip-overlay-wrapper-test');
    overlayLayout.parent.instance.measure = mockOverlayMeasure;
    (0, _testUtils.fireEvent)(overlayLayout, 'layout', {});
    await (0, _testUtils.waitFor)(() => getByTestId('tooltip-content-test'));
    const popup = queryByTestId('tooltip-test');
    popup.parent.instance.measure = jest.fn().mockImplementation(f => {
      // x,y,w,h,px,py
      f(0, 0, 360, 100, 32, _dimentions.deviceHeight - 100 - 21); // component height, inset bottom
    });
    (0, _testUtils.fireEvent)(popup, 'layout', {});
    expect(getByA11yHint('top')).not.toBeNull();
  });
  test('should render overlay and hole', async () => {
    // when
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSafeAreaContext.SafeAreaProvider, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_TooltipContext.TooltipProvider, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tooltip.default, {
          id: 'test',
          overlay: true,
          hole: true,
          position: undefined,
          content: 'content Lorem ipsum dolor sit amet',
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
            children: "trigger text"
          })
        })
      })
    }));

    // then
    const trigger = queryByTestId('tooltip-trigger-test');
    const childWrapper = queryByTestId('tooltip-child-wrapper-test');
    childWrapper.parent.instance.measure = mockChildWrapperTopMeasure;
    (0, _testUtils.fireEvent)(childWrapper, 'layout', mockChildWrapperOnLayoutParam);
    _testUtils.fireEvent.press(trigger);
    const overlayLayout = queryByTestId('tooltip-overlay-wrapper-test');
    overlayLayout.parent.instance.measure = mockOverlayMeasure;
    (0, _testUtils.fireEvent)(overlayLayout, 'layout', {});
    const content = queryByTestId('tooltip-content-test');
    const overlay = queryByTestId('tooltip-overlay-test');
    const hole = queryByTestId('tooltip-hole-test');
    const highlight = queryByTestId('tooltip-highlight-test');
    expect(content).not.toBeNull();
    expect(overlay).not.toBeNull();
    expect(hole).not.toBeNull();
    expect(highlight).toBeNull();
  });
  test('should render overlay and hole and highlight', async () => {
    // when
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSafeAreaContext.SafeAreaProvider, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_TooltipContext.TooltipProvider, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tooltip.default, {
          id: 'test',
          overlay: true,
          hole: true,
          highlight: true,
          position: "bottom",
          content: 'content Lorem ipsum dolor sit amet',
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
            children: "trigger text"
          })
        })
      })
    }));

    // then
    const trigger = queryByTestId('tooltip-trigger-test');
    const childWrapper = queryByTestId('tooltip-child-wrapper-test');
    childWrapper.parent.instance.measure = mockChildWrapperTopMeasure;
    (0, _testUtils.fireEvent)(childWrapper, 'layout', mockChildWrapperOnLayoutParam);
    _testUtils.fireEvent.press(trigger);
    const overlayLayout = queryByTestId('tooltip-overlay-wrapper-test');
    overlayLayout.parent.instance.measure = mockOverlayMeasure;
    (0, _testUtils.fireEvent)(overlayLayout, 'layout', {});
    const content = queryByTestId('tooltip-content-test');
    const overlay = queryByTestId('tooltip-overlay-test');
    const hole = queryByTestId('tooltip-hole-test');
    const highlight = queryByTestId('tooltip-highlight-test');
    expect(content).not.toBeNull();
    expect(overlay).not.toBeNull();
    expect(hole).not.toBeNull();
    expect(highlight).not.toBeNull();
  });
  test('should show and hide via ref', async () => {
    // given
    const ref = /*#__PURE__*/_react.default.createRef();
    const mockOnClose = jest.fn();
    // when
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSafeAreaContext.SafeAreaProvider, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_TooltipContext.TooltipProvider, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tooltip.default, {
          id: 'test',
          ref: ref,
          overlay: true,
          content: 'content Lorem ipsum dolor sit amet',
          position: 'top',
          onClose: mockOnClose,
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
            children: "trigger text"
          })
        })
      })
    }));

    // then
    const childWrapper = queryByTestId('tooltip-child-wrapper-test');
    childWrapper.parent.instance.measure = mockChildWrapperTopMeasure;
    (0, _testUtils.fireEvent)(childWrapper, 'layout', mockChildWrapperOnLayoutParam);
    ref.current?.show();
    const overlayLayout = queryByTestId('tooltip-overlay-wrapper-test');
    overlayLayout.parent.instance.measure = mockOverlayMeasure;
    (0, _testUtils.fireEvent)(overlayLayout, 'layout', {});
    const content = queryByTestId('tooltip-content-test');
    expect(content).not.toBeNull();
    ref.current?.hide();
    expect(queryByTestId('tooltip-content-test')).toBeNull();
    expect(mockOnClose).toHaveBeenCalledWith('test');
  });
  test('should clear all tooltips', async () => {
    const ref1 = /*#__PURE__*/_react.default.createRef();
    const ref2 = /*#__PURE__*/_react.default.createRef();
    const Comp = () => {
      const {
        clearAll
      } = (0, _TooltipContext.useTooltipContext)();
      return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Box.default, {
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_Tooltip.default, {
          id: 'test1',
          ref: ref1,
          overlay: true,
          hole: true,
          content: 'content 1',
          position: 'top',
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
            children: "trigger text 1"
          })
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tooltip.default, {
          id: 'test2',
          ref: ref2,
          overlay: true,
          hole: true,
          content: 'content 2',
          position: 'top',
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
            children: "trigger text 2"
          })
        }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Button.default, {
          testID: "clear_all_btn",
          onPress: clearAll,
          label: "Clear All"
        })]
      });
    };
    // when
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSafeAreaContext.SafeAreaProvider, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_TooltipContext.TooltipProvider, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(Comp, {})
      })
    }));

    // then
    const childWrapper1 = queryByTestId('tooltip-child-wrapper-test1');
    const childWrapper2 = queryByTestId('tooltip-child-wrapper-test2');
    childWrapper1.parent.instance.measure = mockChildWrapperTopMeasure;
    childWrapper2.parent.instance.measure = jest.fn().mockImplementation(f => {
      // x,y,w,h,px,py
      f(0, 0, 200, 30, 16, 64);
    });
    (0, _testUtils.fireEvent)(childWrapper1, 'layout', mockChildWrapperOnLayoutParam);
    (0, _testUtils.fireEvent)(childWrapper2, 'layout', mockChildWrapperOnLayoutParam);
    ref1.current?.show();
    ref2.current?.show();
    const overlayLayout = queryByTestId('tooltip-overlay-wrapper-test1');
    overlayLayout.parent.instance.measure = mockOverlayMeasure;
    (0, _testUtils.fireEvent)(overlayLayout, 'layout', {});
    const content1 = queryByTestId('tooltip-content-test1');
    const content2 = queryByTestId('tooltip-content-test2');
    expect(content1).not.toBeNull();
    expect(content2).toBeNull();

    // clear all
    const btn = queryByTestId('clear_all_btn');
    _testUtils.fireEvent.press(btn);
    expect(queryByTestId('tooltip-content-test1')).toBeNull();
    expect(queryByTestId('tooltip-content-test2')).toBeNull();
  });
  test('should wait for layout ready', async () => {
    const ref = /*#__PURE__*/_react.default.createRef();
    // when
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSafeAreaContext.SafeAreaProvider, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_TooltipContext.TooltipProvider, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tooltip.default, {
          id: 'test',
          ref: ref,
          overlay: true,
          hole: true,
          content: 'content Lorem ipsum dolor sit amet',
          position: 'top',
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
            children: "trigger text"
          })
        })
      })
    }));

    // then
    const childWrapper = queryByTestId('tooltip-child-wrapper-test');
    childWrapper.parent.instance.measure = mockChildWrapperTopMeasure;
    ref.current?.show();
    expect(queryByTestId('tooltip-content-test')).toBeNull();
    (0, _testUtils.fireEvent)(childWrapper, 'layout', mockChildWrapperOnLayoutParam);
    const overlayLayout = queryByTestId('tooltip-overlay-wrapper-test');
    overlayLayout.parent.instance.measure = mockOverlayMeasure;
    (0, _testUtils.fireEvent)(overlayLayout, 'layout', {});
    const content = queryByTestId('tooltip-content-test');
    expect(content).not.toBeNull();
  });
  test('should hide when press overlay', async () => {
    // when
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSafeAreaContext.SafeAreaProvider, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_TooltipContext.TooltipProvider, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tooltip.default, {
          id: 'test',
          overlay: true,
          hole: true,
          content: 'content Lorem ipsum dolor sit amet',
          position: 'top',
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
            children: "trigger text"
          })
        })
      })
    }));

    // then
    const childWrapper = queryByTestId('tooltip-child-wrapper-test');
    childWrapper.parent.instance.measure = mockChildWrapperTopMeasure;
    (0, _testUtils.fireEvent)(childWrapper, 'layout', mockChildWrapperOnLayoutParam);
    const trigger = queryByTestId('tooltip-trigger-test');
    _testUtils.fireEvent.press(trigger);
    const overlayLayout = queryByTestId('tooltip-overlay-wrapper-test');
    overlayLayout.parent.instance.measure = mockOverlayMeasure;
    (0, _testUtils.fireEvent)(overlayLayout, 'layout', {});
    _testUtils.fireEvent.press(overlayLayout);
    expect(queryByTestId('tooltip-content-test')).toBeNull();
  });
  test('should not show when error', async () => {
    // given
    const ref = /*#__PURE__*/_react.default.createRef();
    const mockOnClose = jest.fn();
    const mockOnError = jest.fn();
    // when
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSafeAreaContext.SafeAreaProvider, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_TooltipContext.TooltipProvider, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tooltip.default, {
          id: 'test',
          ref: ref,
          overlay: true,
          content: 'content Lorem ipsum dolor sit amet',
          position: 'top',
          highlight: true,
          onClose: mockOnClose,
          onError: mockOnError,
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
            children: "trigger text"
          })
        })
      })
    }));

    // then
    const childWrapper = queryByTestId('tooltip-child-wrapper-test');
    childWrapper.parent.instance.measure = jest.fn().mockImplementation(f => {
      // x,y,w,h,px,py
      f(undefined, undefined, undefined, undefined, undefined, undefined);
    });
    (0, _testUtils.fireEvent)(childWrapper, 'layout', mockChildWrapperOnLayoutParam);
    ref.current?.show();
    const content = queryByTestId('tooltip-content-test');
    expect(content).toBeNull();
    expect(mockOnClose).not.toBeCalled();
    expect(mockOnError).toHaveBeenCalledWith('test');
  });
  test('should not show when error without onError', async () => {
    // given
    const ref = /*#__PURE__*/_react.default.createRef();
    const mockOnClose = jest.fn();
    // when
    const {
      queryByTestId
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSafeAreaContext.SafeAreaProvider, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_TooltipContext.TooltipProvider, {
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Tooltip.default, {
          id: 'test',
          ref: ref,
          overlay: true,
          content: 'content Lorem ipsum dolor sit amet',
          position: 'top',
          highlight: true,
          onClose: mockOnClose,
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
            children: "trigger text"
          })
        })
      })
    }));

    // then
    const childWrapper = queryByTestId('tooltip-child-wrapper-test');
    childWrapper.parent.instance.measure = jest.fn().mockImplementation(f => {
      // x,y,w,h,px,py
      f(undefined, undefined, undefined, undefined, undefined, undefined);
    });
    (0, _testUtils.fireEvent)(childWrapper, 'layout', mockChildWrapperOnLayoutParam);
    ref.current?.show();
    const content = queryByTestId('tooltip-content-test');
    expect(content).toBeNull();
    expect(mockOnClose).not.toBeCalled();
  });
  test('should not show overlay when no activeTooltip', async () => {
    // given
    const mockShow = jest.fn();
    const mockHide = jest.fn();
    const mockClearAll = jest.fn();
    const mockSetOverlayViewport = jest.fn();
    // when
    const {
      queryByTestId,
      toJSON
    } = (0, _testUtils.render)(/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSafeAreaContext.SafeAreaProvider, {
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_TooltipContext.TooltipContext.Provider, {
        value: {
          activeTooltip: undefined,
          hide: mockHide,
          show: mockShow,
          clearAll: mockClearAll,
          overlayViewport: {
            x: 0,
            y: 0,
            w: 400,
            h: 800,
            px: 0,
            py: 62
          },
          setOverlayViewport: mockSetOverlayViewport
        },
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Overlay.Overlay, {})
      })
    }));

    // then
    const overlayLayout = queryByTestId('tooltip-overlay-wrapper-test');
    expect(overlayLayout).toBeNull();
    expect(toJSON()).toBeNull();
  });
});
//# sourceMappingURL=Tooltip.test.js.map