"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useTooltipContext = exports.TooltipProvider = exports.TooltipContext = void 0;
var _react = _interopRequireWildcard(require("react"));
var _Overlay = require("./Overlay");
var _TooltipView = _interopRequireDefault(require("./TooltipView"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const TooltipContext = exports.TooltipContext = /*#__PURE__*/(0, _react.createContext)(undefined);
const TooltipProvider = ({
  children
}) => {
  const [viewport, setViewport] = _react.default.useState();
  const [stack, setStack] = (0, _react.useState)([]);
  const activeTooltip = _react.default.useMemo(() => {
    return stack[0];
  }, [stack]);
  const addToStack = _react.default.useCallback(tooltipData => {
    if (tooltipData) {
      tooltipData.triggerRef.current?.measure?.((x, y, w, h, px, py) => {
        if (x ?? w ?? px === undefined) {
          tooltipData.onError?.(tooltipData.id);
          return;
        }
        const _viewport = {
          x,
          y,
          w,
          h,
          px,
          py
        };
        setStack(s => [...s, {
          ...tooltipData,
          viewport: _viewport
        }]);
      });
    }
  }, []);
  const removeFromStack = _react.default.useCallback(id => {
    const temp = stack.find(t => t.id === id);
    if (temp) {
      setStack(stack.filter(t => t.id !== temp?.id));
      temp?.onClose?.(id);
    }
  }, [stack]);
  const removeAllStack = _react.default.useCallback(() => {
    setStack([]);
  }, []);
  const value = _react.default.useMemo(() => ({
    activeTooltip,
    overlayViewport: viewport,
    show: addToStack,
    hide: removeFromStack,
    clearAll: removeAllStack,
    setOverlayViewport: setViewport
  }), [activeTooltip, addToStack, removeAllStack, removeFromStack, viewport]);
  const render = _react.default.useMemo(() => {
    if (!activeTooltip) {
      return null;
    }
    return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_Overlay.Overlay, {}), /*#__PURE__*/(0, _jsxRuntime.jsx)(_TooltipView.default, {})]
    });
  }, [activeTooltip]);
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(TooltipContext.Provider, {
    value: value,
    children: [children, render]
  });
};
exports.TooltipProvider = TooltipProvider;
const useTooltipContext = () => {
  const context = (0, _react.useContext)(TooltipContext);
  if (!context) {
    throw new Error('useTooltipContext must be used within a TooltipProvider');
  }
  return context;
};
exports.useTooltipContext = useTooltipContext;
//# sourceMappingURL=TooltipContext.js.map