"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _reactNativeSafeAreaContext = require("react-native-safe-area-context");
var _dimentions = require("../../utils/dimentions");
var _Box = _interopRequireDefault(require("../Box/Box"));
var _Icon = _interopRequireDefault(require("../Icon/Icon"));
var _Text = _interopRequireDefault(require("../Text/Text"));
var _calculatePosition = require("./calculatePosition");
var _TooltipContext = require("./TooltipContext");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const isRTL = _reactNative.I18nManager.isRTL;
const TooltipView = () => {
  const tooltipRef = _react.default.useRef(null);
  const {
    top,
    bottom
  } = (0, _reactNativeSafeAreaContext.useSafeAreaInsets)();
  const {
    hide,
    overlayViewport,
    activeTooltip
  } = (0, _TooltipContext.useTooltipContext)();
  const [position, setPosition] = _react.default.useState(activeTooltip.position);
  const onLayout = _react.default.useCallback(() => {
    tooltipRef.current?.measure?.((x, y, w, h, px, py) => {
      switch (activeTooltip.position) {
        case 'top':
          if (Math.abs(py) - _calculatePosition.PIN_SIZE < top) {
            setPosition('bottom');
          }
          break;
        case 'bottom':
          if (py + h + bottom > _dimentions.deviceHeight - Math.abs(y)) {
            setPosition('top');
          }
          break;
      }
    });
  }, [bottom, activeTooltip, tooltipRef, top]);
  const calc = _react.default.useMemo(() => {
    return (0, _calculatePosition.calculatePosition)({
      ...activeTooltip,
      position
    }, isRTL, overlayViewport);
  }, [activeTooltip, overlayViewport, position]);
  const _hide = _react.default.useCallback(() => {
    if (activeTooltip) {
      hide(activeTooltip.id);
    }
  }, [activeTooltip, hide]);
  const pinPos = _react.default.useMemo(() => {
    return {
      transform: [{
        translateX: calc.pinX
      }, {
        translateY: calc.pinYOverflow
      }, {
        translateX: calc.pinXOverflow
      }, {
        translateY: calc.pinY
      }, {
        rotate: '45deg'
      }]
    };
  }, [calc]);
  if (!overlayViewport || !activeTooltip) {
    return null;
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
    flex: 1,
    height: _dimentions.deviceHeight,
    width: _dimentions.deviceWidth,
    position: "absolute",
    pointerEvents: "box-none",
    children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Box.default, {
      pointerEvents: "box-none",
      top: calc.top,
      height: calc.height,
      justifyContent: position === 'top' ? 'flex-end' : 'flex-start',
      testID: `tooltip-area-${activeTooltip.id}`,
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
        testID: `tooltip-${activeTooltip.id}`,
        bg: activeTooltip.color,
        onLayout: onLayout,
        ref: tooltipRef,
        borderRadius: "m",
        marginHorizontal: "m",
        pointerEvents: "auto",
        accessibilityHint: position,
        children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_Box.default, {
          flexDirection: "row",
          children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
            flex: 1,
            padding: "m",
            children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Text.default, {
              color: "neutralFull",
              variant: "body2",
              testID: `tooltip-content-${activeTooltip.id}`,
              textAlign: 'left',
              children: activeTooltip.content
            })
          }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
            children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.TouchableOpacity, {
              onPress: _hide,
              testID: `tooltip-close-${activeTooltip.id}`,
              accessibilityLabel: `tooltip-close-${activeTooltip.id}`,
              children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
                padding: "m",
                children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Icon.default, {
                  name: "close",
                  size: "xs",
                  color: "neutralFull"
                })
              })
            })
          })]
        })
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_Box.default, {
        testID: `tooltip-pin-${activeTooltip.id}`,
        position: "absolute",
        bg: activeTooltip.color,
        height: _calculatePosition.PIN_SIZE,
        width: _calculatePosition.PIN_SIZE,
        style: pinPos
      })]
    })
  });
};
var _default = exports.default = TooltipView;
//# sourceMappingURL=TooltipView.js.map