"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PIN_SIZE = void 0;
exports.calculatePosition = calculatePosition;
var _reactNative = require("react-native");
var _theme = _interopRequireDefault(require("../../theme"));
var _dimentions = require("../../utils/dimentions");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const PIN_SIZE = exports.PIN_SIZE = 10;
const PIN_HYPOT = Math.hypot(PIN_SIZE, PIN_SIZE);
const PIN_HEIGHT = PIN_HYPOT / 2;
const PIN_MARGIN = 4;
function calculatePosition(tooltipData, isRTL, overlayViewport) {
  switch (tooltipData.position) {
    case 'top':
      return calculateTopPosition(tooltipData, isRTL, overlayViewport);
    case 'bottom':
      return calculateBottomPosition(tooltipData, isRTL, overlayViewport);
  }
}
function calculateTopPosition(data, isRTL, overlayViewport) {
  const hasHole = data.overlay && data.hole;
  return {
    height: Math.round(data.viewport.py - PIN_HEIGHT - PIN_MARGIN - (hasHole ? data.holePadding : 0) - (overlayViewport?.py ?? 0)),
    top: 0,
    pinX: Math.round(pinX(isRTL, data)),
    pinY: Math.round(PIN_HEIGHT),
    pinYOverflow: Math.round(-(PIN_HYPOT - PIN_SIZE) / 2),
    pinXOverflow: Math.round((isRTL ? -1 : 1) * ((PIN_HYPOT - PIN_SIZE) / 2))
  };
}
function calculateBottomPosition(data, isRTL, overlayViewport) {
  const hasHole = data.overlay && data.hole;
  return {
    height: Math.round(_reactNative.Dimensions.get('screen').height - data.viewport.py - data.viewport.h - PIN_HEIGHT - PIN_MARGIN),
    top: Math.round(data.viewport.py + data.viewport.h + PIN_HEIGHT + PIN_MARGIN + (hasHole ? data.holePadding : 0) - (overlayViewport?.py ?? 0)),
    pinX: Math.round(pinX(isRTL, data)),
    pinY: Math.round(-PIN_HEIGHT),
    pinYOverflow: Math.round((PIN_HYPOT - PIN_SIZE) / 2),
    pinXOverflow: Math.round((isRTL ? -1 : 1) * ((PIN_HYPOT - PIN_SIZE) / 2))
  };
}
function pinX(isRTL, data) {
  if (isRTL) {
    const pos = Math.max(Math.min(data.viewport.px + data.viewport.w / 2 + PIN_HEIGHT, _dimentions.deviceWidth + _theme.default.spacing.m * 2 + _theme.default.borderRadii.m / 2), Math.ceil(_theme.default.spacing.m + _theme.default.borderRadii.m / 2));
    return -_dimentions.deviceWidth + pos;
  }
  return Math.max(Math.min(data.viewport.px + data.viewport.w / 2 - PIN_HEIGHT, _dimentions.deviceWidth - _theme.default.spacing.m * 2 - _theme.default.borderRadii.m / 2), Math.ceil(_theme.default.spacing.m + _theme.default.borderRadii.m / 2));
}
//# sourceMappingURL=calculatePosition.js.map