"use strict";

import React from 'react';
import { Pressable, StyleSheet } from 'react-native';
import { createRestyleComponent, createVariant } from '@ergenekonyigit/restyle';
import Box from '../Box/Box';
import Text from '../Text/Text';
import Icon from '../Icon/Icon';
import theme from '../../theme';
import { AlertIcon } from './AlertIcon';
import { deviceWidth } from '../../utils/dimentions';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const variantVariant = createVariant({
  property: 'variant',
  themeKey: 'alertVariants'
});
const AlertContainer = createRestyleComponent([variantVariant], Box);
const Alert = ({
  variant = 'info',
  icon,
  caption,
  description,
  closable,
  closed,
  onClose,
  children,
  ...rest
}) => {
  if (closed) {
    return null;
  }
  return /*#__PURE__*/_jsx(AlertContainer, {
    variant: variant,
    ...rest,
    children: /*#__PURE__*/_jsxs(Box, {
      p: "m",
      flexDirection: "row",
      width: deviceWidth - theme.spacing['2xl'],
      children: [/*#__PURE__*/_jsx(Box, {
        pr: "2xs",
        children: /*#__PURE__*/_jsx(AlertIcon, {
          variant: variant,
          icon: icon
        })
      }), /*#__PURE__*/_jsxs(Box, {
        flex: 1,
        children: [caption ? /*#__PURE__*/_jsx(Text, {
          variant: "subtitle03Medium",
          pb: "2xs",
          testID: "alert-caption",
          textAlign: 'left',
          children: caption
        }) : null, description ? /*#__PURE__*/_jsx(Text, {
          testID: "alert-description",
          textAlign: 'left',
          children: description
        }) : null, children ? /*#__PURE__*/_jsx(Box, {
          flexDirection: "row",
          pt: "2xs",
          children: children
        }) : null]
      }), /*#__PURE__*/_jsx(Box, {
        children: closable ? /*#__PURE__*/_jsx(Pressable, {
          onPress: onClose,
          style: styles.closeButton,
          testID: "alert-close-button",
          children: /*#__PURE__*/_jsx(Icon, {
            size: "xs",
            name: "close"
          })
        }) : null
      })]
    })
  });
};
const styles = StyleSheet.create({
  closeButton: {
    padding: theme.spacing['2xs'],
    marginTop: theme.spacing['-2xs'],
    marginRight: theme.spacing['-2xs']
  }
});
export default Alert;
//# sourceMappingURL=Alert.js.map