"use strict";

import React from 'react';
import { createRestyleComponent, createVariant } from '@ergenekonyigit/restyle';
import theme from '../../theme';
import Box from '../Box/Box';
import Icon from '../Icon/Icon';
import Text from '../Text/Text';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const variantVariant = createVariant({
  property: 'variant',
  themeKey: 'badgeVariants'
});
const BadgeBackground = createRestyleComponent([variantVariant], Box);
const sizeVariant = createVariant({
  property: 'size',
  themeKey: 'badgeSizeVariants'
});
const BadgeText = createRestyleComponent([sizeVariant], Text);
const Badge = ({
  variant = 'default',
  icon,
  color,
  backgroundColor,
  text,
  size,
  transparent,
  testID = 'badge'
}) => {
  const iconView = React.useMemo(() => {
    let iconName;
    switch (variant) {
      case 'neutral':
        iconName = 'alert';
        break;
      case 'success':
        iconName = 'check-fill';
        break;
      case 'warning':
        iconName = 'warning';
        break;
      case 'danger':
        iconName = 'close-fill';
        break;
      default:
        iconName = undefined;
    }
    if (icon) {
      iconName = icon;
    }
    if (!iconName) {
      return null;
    }
    return /*#__PURE__*/_jsx(Box, {
      testID: "badgeIconBox",
      pl: "3xs",
      py: "3xs",
      pr: !text ? '3xs' : 'none',
      children: /*#__PURE__*/_jsx(Icon, {
        testID: "badgeIcon",
        size: "xs",
        name: iconName,
        color: color ?? theme.badgeVariants[variant].color
      })
    });
  }, [icon, color, variant, text]);
  const bgColor = theme.colors[`${backgroundColor}`] ?? backgroundColor;
  let textColor;
  if (theme.colors[color]) {
    textColor = color;
  } else {
    textColor = theme.badgeVariants[variant].color;
  }
  return /*#__PURE__*/_jsxs(Box, {
    testID: testID,
    borderRadius: "xs",
    justifyContent: "center",
    alignSelf: "flex-start",
    flexDirection: "row",
    alignItems: "center",
    style: {
      backgroundColor: bgColor
    },
    children: [!transparent && /*#__PURE__*/_jsx(BadgeBackground, {
      testID: "badgeBackground",
      variant: variant
    }), iconView, text && /*#__PURE__*/_jsx(BadgeText, {
      testID: "badgeText",
      color: textColor,
      size: size,
      fontWeight: "500",
      fontFamily: "medium",
      children: text
    })]
  });
};
export default Badge;
//# sourceMappingURL=Badge.js.map