"use strict";

import React from 'react';
import { TouchableOpacity, StyleSheet } from 'react-native';
import Box from '../Box/Box';
import Text from '../Text/Text';
import BaseModal from '../Modal/BaseModal';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
export const BottomSheetTitle = ({
  closeButtonAction,
  closeButtonLabel,
  selectButtonLabel,
  selectButtonAction,
  testID,
  accessibilityLabel,
  children
}) => {
  const testProps = React.useMemo(() => {
    return {
      accessibilityLabel: accessibilityLabel ?? testID,
      testID: testID ?? accessibilityLabel
    };
  }, [testID, accessibilityLabel]);
  return /*#__PURE__*/_jsxs(Box, {
    flexDirection: "column",
    width: "100%",
    gap: "s",
    mb: "m",
    children: [/*#__PURE__*/_jsxs(Box, {
      justifyContent: "space-between",
      width: "100%",
      alignItems: "center",
      flexDirection: "row",
      children: [/*#__PURE__*/_jsx(TouchableOpacity, {
        onPress: closeButtonAction,
        style: styles.titleSmallButton,
        testID: `${testProps.testID}-header-close`,
        accessibilityLabel: `${testProps.accessibilityLabel}-header-close`,
        children: /*#__PURE__*/_jsx(Text, {
          variant: "subtitle3Medium",
          textAlign: "left",
          children: closeButtonLabel
        })
      }), /*#__PURE__*/_jsx(Text, {
        variant: "subtitle3Medium",
        textAlign: "center",
        style: styles.titleLabel,
        testID: `${testProps.testID}-header-label`,
        accessibilityLabel: `${testProps.accessibilityLabel}-header-label`,
        numberOfLines: 1,
        children: children
      }), /*#__PURE__*/_jsx(TouchableOpacity, {
        onPress: selectButtonAction,
        style: styles.titleSmallButton,
        testID: `${testProps.testID}-header-select`,
        accessibilityLabel: `${testProps.accessibilityLabel}-header-select`,
        children: /*#__PURE__*/_jsx(Text, {
          variant: "subtitle3Medium",
          color: "primaryColor",
          textAlign: "right",
          children: selectButtonLabel
        })
      })]
    }), /*#__PURE__*/_jsx(Box, {
      height: 1,
      backgroundColor: "borderColor",
      mx: "-m"
    })]
  });
};
const BottomSheet = ({
  children,
  closeButtonLabel,
  closeButtonAction,
  selectButtonAction,
  selectButtonLabel,
  accessibilityLabel,
  testID,
  title,
  header,
  ...etc
}) => {
  return /*#__PURE__*/_jsx(BaseModal, {
    ...etc,
    justifyContent: "flex-end",
    p: "none",
    borderBottomStartRadius: "none",
    borderBottomEndRadius: "none",
    closeButtonAction: closeButtonAction,
    accessibilityLabel: accessibilityLabel,
    testID: testID,
    header: header ?? /*#__PURE__*/_jsx(BottomSheetTitle, {
      closeButtonLabel: closeButtonLabel,
      closeButtonAction: closeButtonAction,
      selectButtonAction: selectButtonAction,
      selectButtonLabel: selectButtonLabel,
      accessibilityLabel: accessibilityLabel,
      testID: testID,
      children: title
    }),
    children: children
  });
};
export default BottomSheet;
const styles = StyleSheet.create({
  titleSmallButton: {
    width: '25%'
  },
  titleLabel: {
    width: '50%'
  }
});
//# sourceMappingURL=BottomSheet.js.map