"use strict";

import React from 'react';
import { Pressable } from 'react-native';
import { backgroundColor, border, createRestyleComponent, createVariant, layout, spacing, spacingShorthand } from '@ergenekonyigit/restyle';
import Text from '../Text/Text';
import { useIsPressed } from './hooks';
import Icon from '../Icon/Icon';
import Box from '../Box/Box';
import { variantColorSelector } from './utils';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const sizeVariant = createVariant({
  property: 'size',
  themeKey: 'buttonSizeVariants'
});
const kindVariant = createVariant({
  property: 'kind',
  themeKey: 'buttonKindVariants'
});
const variantVariant = createVariant({
  property: 'variant',
  themeKey: 'buttonVariants'
});
const ButtonContainer = createRestyleComponent([layout, spacing, border, backgroundColor, sizeVariant, kindVariant, variantVariant], Box);
const PressableContainer = createRestyleComponent([layout, spacing, spacingShorthand], Pressable);
const Button = ({
  size = 'm',
  kind = 'default',
  variant = 'primary',
  icon,
  label,
  tintColor,
  disabled = false,
  filled = false,
  ...rest
}) => {
  const {
    pressableProps,
    isPressed
  } = useIsPressed(rest.isPressed);

  /* istanbul ignore next */
  const onPressIn = () => pressableProps.onPressIn();
  /* istanbul ignore next */
  const onPressOut = () => pressableProps.onPressOut();
  const buttonHorizontalPadding = label ? {
    s: 'm',
    m: 'xl',
    l: '2xl'
  }[size] : {
    s: '2xs',
    m: 'xs',
    l: 's'
  }[size];
  const textVariant = {
    s: 'subtitle03Medium',
    m: 'subtitle03Medium',
    l: 'subtitle02Medium'
  }[size];
  const variantColors = variantColorSelector({
    variant,
    kind,
    isPressed,
    disabled
  });
  const typeColor = disabled ? 'neutralLighter' : isPressed && variant !== 'tertiary' ? 'neutralFull' : variantColors.color;
  const iconView = React.useMemo(() => {
    if (!icon) {
      return null;
    }
    if (variant === 'transparent') {
      return /*#__PURE__*/_jsx(Icon, {
        name: icon,
        size: "s",
        color: tintColor,
        testID: "button-icon"
      });
    }
    return /*#__PURE__*/_jsx(Icon, {
      name: icon,
      size: "s",
      color: typeColor,
      testID: "button-icon"
    });
  }, [icon, typeColor, tintColor, variant]);
  const labelView = React.useMemo(() => {
    if (!label) {
      return null;
    }
    return /*#__PURE__*/_jsx(Text, {
      variant: textVariant,
      color: typeColor,
      marginLeft: icon ? '2xs' : 'none',
      testID: "button-text",
      children: label
    });
  }, [icon, label, textVariant, typeColor]);
  return /*#__PURE__*/_jsx(PressableContainer, {
    onPressIn: onPressIn,
    onPressOut: onPressOut,
    disabled: disabled,
    ...rest,
    children: /*#__PURE__*/_jsxs(ButtonContainer, {
      size: size,
      kind: kind
      // @ts-ignore
      ,
      variant: variant,
      paddingHorizontal: buttonHorizontalPadding,
      flexDirection: "row",
      alignItems: "center",
      justifyContent: "center",
      alignSelf: filled ? 'stretch' : 'flex-start',
      ...variantColors,
      children: [iconView, labelView]
    })
  });
};
export default Button;
//# sourceMappingURL=Button.js.map