"use strict";

import React from 'react';
import { createRestyleComponent, createVariant, layout, spacing, spacingShorthand } from '@ergenekonyigit/restyle';
import { TouchableOpacity } from 'react-native';
import Box from '../Box/Box';
import Icon from '../Icon/Icon';
import FlagIcon from '../FlagIcon/FlagIcon';
import Text from '../Text/Text';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const variant = createVariant({
  themeKey: 'checkboxVariants'
});
const Tickbox = createRestyleComponent([variant], Box);
const CheckboxContainer = createRestyleComponent([layout, spacing, spacingShorthand], TouchableOpacity);
const Checkbox = ({
  checked,
  indeterminate,
  label,
  disabled = false,
  flagIcon,
  onPress,
  ...rest
}) => {
  const checkIcon = React.useMemo(() => {
    if (!checked) {
      return null;
    }
    if (indeterminate) {
      return /*#__PURE__*/_jsx(Icon, {
        size: "4xs",
        name: "minus",
        color: disabled ? 'neutralLight' : 'neutralFull',
        testID: "minus-icon"
      });
    }
    return /*#__PURE__*/_jsx(Icon, {
      size: "3xs",
      name: "check",
      color: disabled ? 'neutralLight' : 'neutralFull',
      testID: "check-icon"
    });
  }, [checked, indeterminate, disabled]);
  return /*#__PURE__*/_jsxs(CheckboxContainer, {
    flexDirection: "row",
    alignSelf: "flex-start",
    disabled: disabled,
    onPress: onPress,
    ...rest,
    children: [/*#__PURE__*/_jsx(Tickbox, {
      testID: "tickbox",
      variant: checked ? disabled ? 'disabledChecked' : 'checked' : disabled ? 'disabledUnchecked' : 'unchecked',
      children: checkIcon
    }), flagIcon ? /*#__PURE__*/_jsx(Box, {
      marginLeft: "2xs",
      children: /*#__PURE__*/_jsx(FlagIcon, {
        size: "s",
        name: flagIcon,
        color: disabled ? 'neutralLight' : checked ? 'primaryKey' : 'neutralDarker',
        testID: "flag-icon"
      })
    }) : null, label ? /*#__PURE__*/_jsx(Text, {
      testID: "label",
      marginLeft: "2xs",
      color: disabled ? 'neutralLighter' : checked ? 'primaryKey' : 'neutralDarker',
      children: label
    }) : null]
  });
};
export default Checkbox;
//# sourceMappingURL=Checkbox.js.map