"use strict";

import React, { useCallback } from 'react';
import { StyleSheet, TouchableOpacity } from 'react-native';
import Box from '../Box/Box';
import Text from '../Text/Text';
import Icon from '../Icon/Icon';
import { ShowPickerType } from './constants';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const PickerButton = /*#__PURE__*/React.memo(({
  label,
  isActive,
  onPress,
  testID
}) => /*#__PURE__*/_jsx(TouchableOpacity, {
  onPress: onPress,
  style: styles.touchableOpacity,
  testID: testID,
  accessibilityLabel: testID,
  children: /*#__PURE__*/_jsx(Box, {
    py: "2xs",
    px: "xl",
    alignItems: "center",
    borderRadius: "s",
    backgroundColor: isActive ? 'neutralLightest' : undefined,
    children: /*#__PURE__*/_jsx(Text, {
      variant: "subtitle03Medium",
      color: "neutralDarkest",
      children: label
    })
  })
}));
const NavigationButton = /*#__PURE__*/React.memo(({
  iconName,
  onPress,
  testID
}) => /*#__PURE__*/_jsx(TouchableOpacity, {
  onPress: onPress,
  testID: testID,
  accessibilityLabel: testID,
  children: /*#__PURE__*/_jsx(Box, {
    p: "xs",
    children: /*#__PURE__*/_jsx(Icon, {
      size: "m",
      name: iconName
    })
  })
}));
const CalendarHeader = /*#__PURE__*/React.memo(({
  context
}) => {
  const {
    calendarData,
    showPickerType,
    setShowPickerType,
    onPressNext,
    onPressPrev,
    testID
  } = context;
  const handlePickerPress = useCallback(pickerType => {
    setShowPickerType(showPickerType === pickerType ? ShowPickerType.NONE : pickerType);
  }, [showPickerType, setShowPickerType]);
  return /*#__PURE__*/_jsxs(Box, {
    flexDirection: "row",
    alignItems: "center",
    justifyContent: "space-between",
    py: "2xs",
    mb: "2xs",
    children: [/*#__PURE__*/_jsx(NavigationButton, {
      iconName: "arrow-left",
      onPress: onPressPrev,
      testID: `${testID}-header-prev`
    }), /*#__PURE__*/_jsxs(Box, {
      flex: 1,
      flexDirection: "row",
      gap: "2xs",
      alignItems: "center",
      justifyContent: "space-between",
      children: [/*#__PURE__*/_jsx(PickerButton, {
        label: calendarData.nameOfMonth,
        isActive: showPickerType === ShowPickerType.MONTH,
        onPress: () => handlePickerPress(ShowPickerType.MONTH),
        testID: `${testID}-header-month-select`
      }), /*#__PURE__*/_jsx(PickerButton, {
        label: calendarData.year,
        isActive: showPickerType === ShowPickerType.YEAR,
        onPress: () => handlePickerPress(ShowPickerType.YEAR),
        testID: `${testID}-header-year-select`
      })]
    }), /*#__PURE__*/_jsx(NavigationButton, {
      iconName: "arrow-right",
      onPress: onPressNext,
      testID: `${testID}-header-next`
    })]
  });
});
CalendarHeader.displayName = 'CalendarHeader';
PickerButton.displayName = 'PickerButton';
NavigationButton.displayName = 'NavigationButton';
export default CalendarHeader;
const styles = StyleSheet.create({
  touchableOpacity: {
    flex: 1
  }
});
//# sourceMappingURL=CalendarHeader.js.map