"use strict";

import React from 'react';
import { StyleSheet, TouchableOpacity } from 'react-native';
import CalendarWrapper from './CalendarWrapper';
import Input from '../Input/Input';
import Box from '../Box/Box';
import { DatePickerProvider, useDatePickerContext } from './DatePickerContext';
import { getDateFromString } from './utils';
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
const DatePickerContent = /*#__PURE__*/React.memo(props => {
  const {
    handleOpen,
    testID,
    value
  } = useDatePickerContext();
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsxs(Box, {
      position: "relative",
      children: [/*#__PURE__*/_jsx(Input, {
        placeholder: props.placeholder,
        value: value || '',
        editable: false,
        pointerEvents: "none",
        testID: `${testID}-input`,
        accessibilityLabel: `${testID}-input`,
        size: props.size,
        icon: "calendar",
        labelFixed: true,
        label: props.label
      }), /*#__PURE__*/_jsx(TouchableOpacity, {
        style: styles.touchableOpacity,
        activeOpacity: 1,
        onPress: handleOpen,
        testID: `${testID}-touchable`,
        accessibilityLabel: `${testID}-touchable`
      })]
    }), /*#__PURE__*/_jsx(CalendarWrapper, {
      closeButtonLabel: props.closeButtonLabel,
      selectButtonLabel: props.selectButtonLabel,
      title: props.title
    })]
  });
});
const DatePicker = /*#__PURE__*/React.memo(props => {
  const _disableDates = React.useMemo(() => (props.disableDates || []).map(date => getDateFromString(date, props.format).getTime()), [props.disableDates, props.format]);
  const contextValue = React.useMemo(() => ({
    value: props.value,
    nameOfWeekdays: props.nameOfWeekdays,
    nameOfMonths: props.nameOfMonths,
    minYear: props.minYear,
    maxYear: props.maxYear,
    testID: props.testID,
    firstDayOfWeek: props.firstDayOfWeek,
    placeholder: props.placeholder,
    disableDates: _disableDates,
    onChange: props.onChange,
    multiple: props.multiple || false,
    format: props.format,
    disableMonths: props.disableMonths,
    disableYears: props.disableYears
  }), [props.value, props.nameOfWeekdays, props.nameOfMonths, props.minYear, props.maxYear, props.testID, props.firstDayOfWeek, props.placeholder, props.onChange, props.multiple, props.format, props.disableMonths, props.disableYears, _disableDates]);
  return /*#__PURE__*/_jsx(DatePickerProvider, {
    ...contextValue,
    children: /*#__PURE__*/_jsx(DatePickerContent, {
      closeButtonLabel: props.closeButtonLabel,
      selectButtonLabel: props.selectButtonLabel,
      title: props.title,
      placeholder: props.placeholder,
      size: props.size,
      label: props.label,
      multiple: props.multiple
    })
  });
});
DatePicker.displayName = 'DatePicker';
DatePickerContent.displayName = 'DatePickerContent';
export default DatePicker;
const styles = StyleSheet.create({
  touchableOpacity: {
    position: 'absolute',
    top: 0,
    left: 0,
    right: 0,
    bottom: 0
  }
});
//# sourceMappingURL=DatePicker.js.map