"use strict";

import React from 'react';
import Box from '../Box/Box';
import Text from '../Text/Text';
import DatePicker from './DatePicker';
import { DEFAULT_NAME_OF_MONTHS, DEFAULT_NAME_OF_WEEKDAYS } from './constants';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const DatePickerMeta = {
  title: 'DatePicker',
  component: DatePicker,
  argTypes: {
    onChange: {
      action: 'onChange'
    },
    size: {
      control: {
        type: 'select'
      },
      options: ['small', 'medium', 'large']
    },
    label: {
      control: {
        type: 'text'
      },
      description: 'Input label text'
    },
    maxYear: {
      control: {
        type: 'number'
      },
      description: 'Maximum year'
    },
    minYear: {
      control: {
        type: 'number'
      },
      description: 'Minimum year'
    },
    disableDates: {
      control: {
        type: 'array'
      },
      description: 'Disabled dates'
    },
    disableMonths: {
      control: {
        type: 'array'
      },
      description: 'Disabled months'
    },
    disableYears: {
      control: {
        type: 'array'
      },
      description: 'Disabled years'
    },
    multiple: {
      control: {
        type: 'boolean'
      },
      description: 'Multiple selection'
    },
    format: {
      control: {
        type: 'text'
      },
      description: 'Date format'
    },
    firstDayOfWeek: {
      control: {
        type: 'select'
      },
      options: [0, 1],
      description: 'First day of week'
    },
    placeholder: {
      control: {
        type: 'text'
      },
      description: 'Placeholder text'
    },
    title: {
      control: {
        type: 'text'
      },
      description: 'Title text'
    },
    closeButtonLabel: {
      control: {
        type: 'text'
      },
      description: 'Close button label'
    },
    selectButtonLabel: {
      control: {
        type: 'text'
      },
      description: 'Select button label'
    }
  },
  args: {
    title: 'Select Date',
    closeButtonLabel: 'Close',
    selectButtonLabel: 'Select',
    placeholder: 'Select date',
    firstDayOfWeek: 1,
    multiple: false,
    format: 'dd/MM/yyyy'
  }
};
export default DatePickerMeta;
export const Basic = args => {
  const [value, setValue] = React.useState(null);
  return /*#__PURE__*/_jsxs(Box, {
    p: "2xs",
    children: [/*#__PURE__*/_jsx(Text, {
      p: "2xs",
      variant: "subtitle01Bold",
      children: "DatePicker"
    }), /*#__PURE__*/_jsx(DatePicker, {
      ...args,
      testID: "datepicker",
      value: value,
      onChange: setValue
    })]
  });
};
export const Cases = args => {
  const [value1, setValue1] = React.useState(null);
  const [value2, setValue2] = React.useState(null);
  const [value3, setValue3] = React.useState(null);
  return /*#__PURE__*/_jsxs(Box, {
    gap: "2xs",
    children: [/*#__PURE__*/_jsxs(Box, {
      p: "2xs",
      children: [/*#__PURE__*/_jsx(Text, {
        p: "2xs",
        variant: "subtitle01Bold",
        children: "DatePicker start via Sunday"
      }), /*#__PURE__*/_jsx(DatePicker, {
        ...args,
        title: "Select Date",
        closeButtonLabel: "Close",
        selectButtonLabel: "Select",
        nameOfWeekdays: ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
        testID: "datepicker",
        value: value1,
        onChange: setValue1,
        placeholder: "Select date",
        firstDayOfWeek: 0,
        format: "dd/MM/yyyy"
      })]
    }), /*#__PURE__*/_jsxs(Box, {
      p: "2xs",
      children: [/*#__PURE__*/_jsx(Text, {
        p: "2xs",
        variant: "subtitle01Bold",
        children: "DatePicker start via Monday (Default)"
      }), /*#__PURE__*/_jsx(DatePicker, {
        ...args,
        title: "Select Date",
        closeButtonLabel: "Close",
        selectButtonLabel: "Select",
        testID: "datepicker",
        value: value2,
        onChange: setValue2,
        placeholder: "Select date",
        firstDayOfWeek: 1,
        format: "dd/MM/yyyy"
      })]
    }), /*#__PURE__*/_jsxs(Box, {
      p: "2xs",
      children: [/*#__PURE__*/_jsx(Text, {
        p: "2xs",
        variant: "subtitle01Bold",
        children: "DatePicker with Label"
      }), /*#__PURE__*/_jsx(DatePicker, {
        ...args,
        label: "Birth Date",
        title: "Select Date",
        closeButtonLabel: "Close",
        selectButtonLabel: "Select",
        testID: "datepicker-with-label",
        value: value3,
        onChange: setValue3,
        placeholder: "Select date",
        firstDayOfWeek: 1
      })]
    })]
  });
};
export const SizeComparison = args => {
  const [value1, setValue1] = React.useState(null);
  const [value2, setValue2] = React.useState(null);
  const [value3, setValue3] = React.useState(null);
  return /*#__PURE__*/_jsxs(Box, {
    p: "2xs",
    gap: "2xs",
    children: [/*#__PURE__*/_jsx(Text, {
      p: "2xs",
      variant: "subtitle01Bold",
      children: "DatePicker Size Comparison"
    }), /*#__PURE__*/_jsx(Text, {
      variant: "subtitle03Medium",
      color: "neutralDark",
      children: "Small Size:"
    }), /*#__PURE__*/_jsx(DatePicker, {
      ...args,
      size: "small",
      title: "Select Date",
      closeButtonLabel: "Close",
      selectButtonLabel: "Select",
      testID: "datepicker-small-compare",
      value: value1,
      onChange: setValue1,
      placeholder: "Small size",
      firstDayOfWeek: 1
    }), /*#__PURE__*/_jsx(Text, {
      variant: "subtitle03Medium",
      color: "neutralDark",
      children: "Medium Size:"
    }), /*#__PURE__*/_jsx(DatePicker, {
      ...args,
      size: "medium",
      title: "Select Date",
      closeButtonLabel: "Close",
      selectButtonLabel: "Select",
      testID: "datepicker-medium-compare",
      value: value2,
      onChange: setValue2,
      placeholder: "Medium size",
      firstDayOfWeek: 1
    }), /*#__PURE__*/_jsx(Text, {
      variant: "subtitle03Medium",
      color: "neutralDark",
      children: "Large with Label:"
    }), /*#__PURE__*/_jsx(DatePicker, {
      ...args,
      size: "large",
      title: "Select Date",
      label: "Large Date",
      closeButtonLabel: "Close",
      selectButtonLabel: "Select",
      testID: "datepicker-large-compare",
      value: value3,
      onChange: setValue3,
      placeholder: "Large size",
      firstDayOfWeek: 1
    })]
  });
};
export const MultipleDateSelection = args => {
  const [value, setValue] = React.useState(null);
  const [value1, setValue1] = React.useState(null);
  return /*#__PURE__*/_jsxs(Box, {
    gap: "2xs",
    children: [/*#__PURE__*/_jsxs(Box, {
      p: "2xs",
      children: [/*#__PURE__*/_jsx(Text, {
        p: "2xs",
        variant: "subtitle01Bold",
        children: "Multiple Date Selection"
      }), /*#__PURE__*/_jsx(DatePicker, {
        ...args,
        multiple: true,
        label: "Date Range Selector",
        placeholder: "Select start - end date",
        title: "Select date range",
        closeButtonLabel: "Close",
        selectButtonLabel: "Select",
        testID: "datepicker-multiple",
        value: value,
        onChange: setValue,
        firstDayOfWeek: 1,
        format: "yyyy-MM-dd"
      })]
    }), /*#__PURE__*/_jsxs(Box, {
      p: "2xs",
      children: [/*#__PURE__*/_jsx(Text, {
        p: "2xs",
        variant: "subtitle01Bold",
        children: "Multiple Date Selection with Custom Labels"
      }), /*#__PURE__*/_jsx(DatePicker, {
        ...args,
        multiple: true,
        label: "Reservation Date",
        placeholder: "Select check-in - check-out date",
        title: "Select reservation date",
        closeButtonLabel: "Cancel",
        selectButtonLabel: "Confirm",
        testID: "datepicker-multiple-custom",
        value: value1,
        onChange: setValue1,
        firstDayOfWeek: 1
      })]
    })]
  });
};
export const WithDisabledDates = args => {
  const [value, setValue] = React.useState(null);
  const [value1, setValue1] = React.useState(null);
  const [value2, setValue2] = React.useState(null);
  const disabledMonths = [202501, 202502, 202506, 202507, 202512, 202601, 202606, 202610];
  const disabledYears = [2024, 2026];
  const disabledDates = ['2025-01-04', '2025-01-05', '2025-01-12', '2025-01-25', '2025-01-26', '2025-01-01', '2025-01-15'];
  return /*#__PURE__*/_jsxs(Box, {
    gap: "2xs",
    children: [/*#__PURE__*/_jsxs(Box, {
      p: "2xs",
      children: [/*#__PURE__*/_jsx(Text, {
        p: "2xs",
        variant: "subtitle01Bold",
        children: "DatePicker with Disabled Dates"
      }), /*#__PURE__*/_jsx(Text, {
        p: "2xs",
        variant: "subtitle03Regular",
        color: "neutralDark",
        children: "Weekends and holidays are disabled"
      }), /*#__PURE__*/_jsx(DatePicker, {
        ...args,
        label: "Appointment Date",
        title: "Select Available Date",
        closeButtonLabel: "Close",
        selectButtonLabel: "Select",
        nameOfWeekdays: DEFAULT_NAME_OF_WEEKDAYS,
        nameOfMonths: DEFAULT_NAME_OF_MONTHS,
        testID: "datepicker-disabled-dates",
        value: value,
        onChange: setValue,
        placeholder: "Select available date",
        firstDayOfWeek: 1,
        disableDates: disabledDates,
        format: "yyyy-MM-dd"
      })]
    }), /*#__PURE__*/_jsxs(Box, {
      p: "2xs",
      children: [/*#__PURE__*/_jsx(Text, {
        p: "2xs",
        variant: "subtitle01Bold",
        children: "DatePicker with Disabled Months"
      }), /*#__PURE__*/_jsx(Text, {
        p: "2xs",
        variant: "subtitle03Regular",
        color: "neutralDark",
        children: "Some months are disabled"
      }), /*#__PURE__*/_jsx(DatePicker, {
        ...args,
        label: "Month Selection",
        title: "Select Available Month",
        closeButtonLabel: "Close",
        selectButtonLabel: "Select",
        nameOfWeekdays: DEFAULT_NAME_OF_WEEKDAYS,
        nameOfMonths: DEFAULT_NAME_OF_MONTHS,
        testID: "datepicker-disabled-months",
        value: value1,
        onChange: setValue1,
        placeholder: "Select available month",
        firstDayOfWeek: 1,
        disableMonths: disabledMonths,
        format: "yyyy-MM-dd"
      })]
    }), /*#__PURE__*/_jsxs(Box, {
      p: "2xs",
      children: [/*#__PURE__*/_jsx(Text, {
        p: "2xs",
        variant: "subtitle01Bold",
        children: "DatePicker with Disabled Years"
      }), /*#__PURE__*/_jsx(Text, {
        p: "2xs",
        variant: "subtitle03Regular",
        color: "neutralDark",
        children: "Some years are disabled"
      }), /*#__PURE__*/_jsx(DatePicker, {
        ...args,
        label: "Year Selection",
        title: "Select Available Year",
        closeButtonLabel: "Close",
        selectButtonLabel: "Select",
        nameOfWeekdays: DEFAULT_NAME_OF_WEEKDAYS,
        nameOfMonths: DEFAULT_NAME_OF_MONTHS,
        testID: "datepicker-disabled-years",
        value: value2,
        onChange: setValue2,
        placeholder: "Select available year",
        firstDayOfWeek: 1,
        disableYears: disabledYears,
        format: "yyyy-MM-dd"
      })]
    })]
  });
};
export const WithYearRange = args => {
  const [value, setValue] = React.useState(null);
  const minYear = 2024;
  const maxYear = 2026;
  return /*#__PURE__*/_jsxs(Box, {
    p: "2xs",
    children: [/*#__PURE__*/_jsx(Text, {
      p: "2xs",
      variant: "subtitle01Bold",
      children: "DatePicker with Year Range"
    }), /*#__PURE__*/_jsx(Text, {
      p: "2xs",
      variant: "subtitle03Regular",
      color: "neutralDark",
      children: "Only years 2024-2026 are selectable"
    }), /*#__PURE__*/_jsx(DatePicker, {
      ...args,
      label: "Event Date",
      title: "Select Event Date",
      closeButtonLabel: "Close",
      selectButtonLabel: "Select",
      nameOfWeekdays: DEFAULT_NAME_OF_WEEKDAYS,
      nameOfMonths: DEFAULT_NAME_OF_MONTHS,
      testID: "datepicker-year-range",
      value: value,
      onChange: setValue,
      placeholder: "Select event date (2024-2026)",
      firstDayOfWeek: 1,
      minYear: minYear,
      maxYear: maxYear,
      format: "dd/MM/yyyy"
    })]
  });
};
//# sourceMappingURL=DatePicker.stories.js.map