"use strict";

import React, { useCallback } from 'react';
import { StyleSheet, TouchableOpacity } from 'react-native';
import Box from '../Box/Box';
import Text from '../Text/Text';
import { ShowPickerType } from './constants';
import { createCalendar } from './utils';
import { jsx as _jsx } from "react/jsx-runtime";
const MonthItem = /*#__PURE__*/React.memo(({
  name,
  idx,
  isSelected,
  isCurrentMonth,
  onSelect,
  testID,
  isDisabled
}) => {
  return /*#__PURE__*/_jsx(TouchableOpacity, {
    onPress: () => {
      if (isDisabled) {
        return;
      }
      onSelect(idx);
    },
    style: styles.monthItem,
    testID: `${testID}-month-${idx + 1}`,
    accessibilityLabel: `${testID}-month-${idx + 1}`,
    children: /*#__PURE__*/_jsx(Box, {
      flex: 1,
      mb: "2xs",
      alignItems: "center",
      py: "2xs",
      borderRadius: "s",
      backgroundColor: isSelected ? 'primaryKey' : 'neutralFull',
      opacity: isDisabled ? 0.5 : 1,
      children: /*#__PURE__*/_jsx(Text, {
        variant: "subtitle03Regular",
        color: isSelected ? 'white' : isCurrentMonth ? 'primaryColor' : 'contentPrimary',
        children: name
      })
    })
  }, name);
});
const MonthPicker = /*#__PURE__*/React.memo(({
  context
}) => {
  const {
    calendarData,
    setCalendarData,
    setShowPickerType,
    nameOfMonths,
    firstDayOfWeek,
    testID,
    disableMonths
  } = context;
  const currentDate = new Date();
  const currentMonth = currentDate.getMonth();
  const currentYear = currentDate.getFullYear();
  const onSelect = useCallback(idx => {
    setCalendarData({
      calendar: createCalendar({
        year: calendarData.year,
        month: idx,
        firstDayOfWeek
      }),
      year: calendarData.year,
      month: idx,
      nameOfMonth: nameOfMonths?.[idx]
    });
    setShowPickerType(ShowPickerType.NONE);
  }, [calendarData.year, firstDayOfWeek, nameOfMonths, setCalendarData, setShowPickerType]);
  return /*#__PURE__*/_jsx(Box, {
    children: /*#__PURE__*/_jsx(Box, {
      flexDirection: "row",
      flexWrap: "wrap",
      justifyContent: "space-between",
      children: nameOfMonths?.map((name, idx) => {
        const isSelected = calendarData.month === idx;
        const isCurrentMonth = idx === currentMonth && calendarData.year === currentYear;
        const isDisabled = disableMonths ? disableMonths.includes(Number(`${calendarData.year}${(idx + 1).toString().padStart(2, '0')}`)) : false;
        return /*#__PURE__*/_jsx(MonthItem, {
          name: name,
          idx: idx,
          isSelected: isSelected,
          isCurrentMonth: isCurrentMonth,
          onSelect: onSelect,
          testID: testID || '',
          isDisabled: isDisabled
        }, name);
      })
    })
  });
});
MonthPicker.displayName = 'MonthPicker';
MonthItem.displayName = 'MonthItem';
export default MonthPicker;
const styles = StyleSheet.create({
  monthItem: {
    width: '30%'
  }
});
//# sourceMappingURL=MonthPicker.js.map