"use strict";

import React, { useCallback, useMemo } from 'react';
import { StyleSheet, TouchableOpacity } from 'react-native';
import Box from '../Box/Box';
import Text from '../Text/Text';
import { ShowPickerType } from './constants';
import { createCalendar } from './utils';
import { jsx as _jsx } from "react/jsx-runtime";
const YearItem = /*#__PURE__*/React.memo(({
  year,
  isSelected,
  isCurrentYear,
  onSelect,
  testID,
  isDisabled
}) => /*#__PURE__*/_jsx(TouchableOpacity, {
  onPress: () => {
    if (isDisabled) {
      return;
    }
    onSelect(year);
  },
  style: styles.yearItem,
  testID: `${testID}-year-${year}`,
  accessibilityLabel: `${testID}-year-${year}`,
  children: /*#__PURE__*/_jsx(Box, {
    flex: 1,
    mb: "2xs",
    alignItems: "center",
    py: "2xs",
    borderRadius: "s",
    backgroundColor: isSelected ? 'primaryKey' : 'neutralFull',
    opacity: isDisabled ? 0.5 : 1,
    children: /*#__PURE__*/_jsx(Text, {
      variant: "subtitle03Regular",
      color: isSelected ? 'white' : isCurrentYear ? 'primaryColor' : 'neutralDarker',
      children: year
    })
  })
}, year));
const YearPicker = /*#__PURE__*/React.memo(({
  context
}) => {
  const {
    calendarData,
    setCalendarData,
    setShowPickerType,
    nameOfMonths,
    nameOfWeekdays,
    firstDayOfWeek,
    yearRange,
    testID,
    disableYears
  } = context;
  const onSelect = useCallback(year => {
    const calendar = createCalendar({
      year,
      month: calendarData.month,
      nameOfMonths,
      nameOfWeekdays,
      firstDayOfWeek
    });
    setCalendarData({
      calendar,
      year,
      month: calendarData.month,
      nameOfMonth: nameOfMonths?.[calendarData.month]
    });
    setShowPickerType(ShowPickerType.NONE);
  }, [calendarData.month, nameOfMonths, nameOfWeekdays, firstDayOfWeek, setCalendarData, setShowPickerType]);
  const currentYear = new Date().getFullYear();
  const years = useMemo(() => Array.from({
    length: yearRange.max - yearRange.min + 1
  }, (_, i) => yearRange.min + i), [yearRange.min, yearRange.max]);
  return /*#__PURE__*/_jsx(Box, {
    mb: "2xs",
    children: /*#__PURE__*/_jsx(Box, {
      flexDirection: "row",
      flexWrap: "wrap",
      justifyContent: "space-between",
      children: years.map(year => {
        const isSelected = calendarData.year === year;
        const isCurrentYear = year === currentYear;
        const isDisabled = disableYears ? disableYears.includes(year) : false;
        return /*#__PURE__*/_jsx(YearItem, {
          year: year,
          isSelected: isSelected,
          isCurrentYear: isCurrentYear,
          onSelect: onSelect,
          testID: testID || '',
          isDisabled: isDisabled
        }, year);
      })
    })
  });
});
YearPicker.displayName = 'YearPicker';
YearItem.displayName = 'YearItem';
export default YearPicker;
const styles = StyleSheet.create({
  yearItem: {
    width: '30%'
  }
});
//# sourceMappingURL=YearPicker.js.map