"use strict";

import React from 'react';
import { act } from 'react-test-renderer';
import { fireEvent, render, waitFor } from '../../test-utils';
import theme from '../../theme';
import Input from './Input';
import { jsx as _jsx } from "react/jsx-runtime";
describe('Input', () => {
  test('should render input correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(Input, {
      label: "label"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render label fixed input correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(Input, {
      label: "label",
      labelFixed: true,
      placeholder: "placeholder"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render disabled input correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(Input, {
      disabled: true,
      label: "label"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render input with help text correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(Input, {
      label: "label",
      helpText: "helpText"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render input with icon correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(Input, {
      label: "label",
      icon: "confetti"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render input with leadingText correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(Input, {
      label: "label",
      leadingText: "%"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render input with trailingText correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(Input, {
      label: "label",
      trailingText: "\u20BA"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render input with error state correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(Input, {
      label: "label",
      error: true
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render input with error state and error text correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(Input, {
      label: "label",
      error: true,
      errorText: "errorText"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render input with success state correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(Input, {
      label: "label",
      success: true
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render input with success state and success text correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(Input, {
      label: "label",
      success: true,
      successText: "successText"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render input with small size correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(Input, {
      label: "label",
      size: "small"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render input with medium size correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(Input, {
      label: "label",
      size: "medium"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should focus input correctly', async () => {
    // when
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(Input, {
      label: "label"
    }));

    // then
    expect(getByTestId('input-box').props.style[0].borderColor).toBe(theme.colors.neutralLighter);

    // when
    fireEvent(getByTestId('input'), 'onFocus');

    // then
    await waitFor(() => {
      expect(getByTestId('input-box').props.style[0].borderColor).toBe(theme.colors.primaryKey);
    });
  });
  test('should not focus and blur input when input is disabled', () => {
    // when
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(Input, {
      label: "label",
      disabled: true
    }));

    // then
    expect(getByTestId('input-box').props.style[0].borderColor).toBe(theme.colors.neutralLighter);

    // when
    act(() => {
      const input = getByTestId('input');
      fireEvent(input, 'onFocus');
      fireEvent(input, 'onBlur');
    });

    // then
    expect(getByTestId('input-box').props.style[0].borderColor).toBe(theme.colors.neutralLighter);
  });
  test('should blur input without value correctly', () => {
    // when
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(Input, {
      label: "label"
    }));

    // then
    expect(getByTestId('input-box').props.style[0].borderColor).toBe(theme.colors.neutralLighter);

    // when
    act(() => {
      const input = getByTestId('input');
      fireEvent(input, 'onFocus');
      fireEvent(input, 'onBlur');
    });

    // then
    expect(getByTestId('input-box').props.style[0].borderColor).toBe(theme.colors.neutralLighter);
  });
  test('should blur input with value correctly', () => {
    // when
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(Input, {
      label: "label",
      value: "value"
    }));

    // then
    expect(getByTestId('input-box').props.style[0].borderColor).toBe(theme.colors.neutralLighter);

    // when
    act(() => {
      const input = getByTestId('input');
      fireEvent(input, 'onFocus');
      fireEvent(input, 'onBlur');
    });

    // then
    expect(getByTestId('input-box').props.style[0].borderColor).toBe(theme.colors.neutralLighter);
  });
  test('should change text of input without value', () => {
    // when
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(Input, {
      label: "label"
    }));
    const input = getByTestId('input');
    fireEvent.changeText(input, 'e-mail@mail.com');

    // then
    expect(input.props.value).toBe('e-mail@mail.com');
  });
  test('should change text of input with value', () => {
    // when
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(Input, {
      label: "label",
      value: "value"
    }));
    const input = getByTestId('input');
    fireEvent.changeText(input, 'e-mail@mail.com');

    // then
    expect(input.props.value).toBe('value');
  });
  test('should not change text of input when input is disabled', () => {
    // when
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(Input, {
      label: "label",
      disabled: true
    }));
    const input = getByTestId('input');
    fireEvent.changeText(input, 'e-mail@mail.com');

    // then
    expect(input.props.value).not.toBe('e-mail@mail.com');
  });
  test('should change text of input when input has defaultValue', () => {
    // when
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(Input, {
      label: "label",
      defaultValue: "defaultValue"
    }));
    const input = getByTestId('input');
    fireEvent.changeText(input, 'e-mail@mail.com');

    // then
    expect(input.props.value).toBe('e-mail@mail.com');
  });
  test('should access inputs handle functions correctly', () => {
    // given
    const ref = /*#__PURE__*/React.createRef();

    // when
    render(/*#__PURE__*/_jsx(Input, {
      label: "label",
      ref: ref
    }));
    act(() => {
      ref.current?.focus();
      ref.current?.blur();
      ref.current?.clear();
      ref.current?.isFocused();
      ref.current?.setNativeProps({
        text: ''
      });
    });

    // then
    expect(ref.current?.focus).toBeTruthy();
  });
});
//# sourceMappingURL=Input.test.js.map