"use strict";

import React from 'react';
import { fireEvent, render } from '../../test-utils';
import { InputIcon } from './InputIcon';
import { jsx as _jsx } from "react/jsx-runtime";
describe('Input Icon', () => {
  let errorState;
  let successState;
  let secureTextEntry;
  let icon;
  let variantIconName;
  let focused;
  let passwordVisibilityIcon;
  let handlePasswordVisibility;
  test('should render icon correctly', () => {
    // given
    secureTextEntry = false;
    icon = 'help';
    variantIconName = null;
    focused = false;
    errorState = false;
    successState = false;
    passwordVisibilityIcon = 'eye-on';
    handlePasswordVisibility = jest.fn();

    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(InputIcon, {
      secureTextEntry: secureTextEntry,
      icon: icon,
      variantIconName: variantIconName,
      focused: focused,
      errorState: errorState,
      successState: successState,
      passwordVisibilityIcon: passwordVisibilityIcon,
      handlePasswordVisibility: handlePasswordVisibility
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render null when not have icon and variantIconName', () => {
    // given
    secureTextEntry = false;
    icon = null;
    variantIconName = null;
    focused = false;
    errorState = false;
    successState = false;
    passwordVisibilityIcon = 'eye-on';
    handlePasswordVisibility = jest.fn();

    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(InputIcon, {
      secureTextEntry: secureTextEntry,
      icon: icon,
      variantIconName: variantIconName,
      focused: focused,
      errorState: errorState,
      successState: successState,
      passwordVisibilityIcon: passwordVisibilityIcon,
      handlePasswordVisibility: handlePasswordVisibility
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render eye icon when secureTextEntry true', () => {
    // given
    secureTextEntry = true;
    icon = null;
    variantIconName = null;
    focused = false;
    errorState = false;
    successState = false;
    passwordVisibilityIcon = 'eye-on';
    handlePasswordVisibility = jest.fn();

    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(InputIcon, {
      secureTextEntry: secureTextEntry,
      icon: icon,
      variantIconName: variantIconName,
      focused: focused,
      errorState: errorState,
      successState: successState,
      passwordVisibilityIcon: passwordVisibilityIcon,
      handlePasswordVisibility: handlePasswordVisibility
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should press password visibility button', () => {
    // given
    secureTextEntry = true;
    icon = null;
    variantIconName = null;
    focused = false;
    errorState = false;
    successState = false;
    passwordVisibilityIcon = 'eye-on';
    handlePasswordVisibility = jest.fn();

    // when
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(InputIcon, {
      secureTextEntry: secureTextEntry,
      icon: icon,
      variantIconName: variantIconName,
      focused: focused,
      errorState: errorState,
      successState: successState,
      passwordVisibilityIcon: passwordVisibilityIcon,
      handlePasswordVisibility: handlePasswordVisibility
    }));
    const button = getByTestId('password-visibility-button');
    fireEvent.press(button);

    // then
    expect(handlePasswordVisibility).toBeCalledTimes(1);
  });
});
//# sourceMappingURL=InputIcon.test.js.map