"use strict";

import React from 'react';
import { Animated, I18nManager } from 'react-native';
import Box from '../Box/Box';
import Text from '../Text/Text';
import { getLabelColor } from './utils';
import theme from '../../theme';
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
const isRTL = I18nManager.isRTL;
export const InputLabel = /*#__PURE__*/React.memo(({
  label,
  subLabel,
  labelFixed,
  errorState,
  successState,
  animatedViewProps,
  animatedTextProps,
  inputHeight,
  required
}) => {
  if (!label) {
    return null;
  }
  const contentSecondaryColor = getLabelColor({
    errorState,
    successState
  });
  const RenderFixedLabel = () => {
    return /*#__PURE__*/_jsxs(Box, {
      flexDirection: "row",
      mb: "3xs",
      testID: "fixed-label-box",
      children: [/*#__PURE__*/_jsxs(Text, {
        variant: "subtitle04Medium",
        color: contentSecondaryColor,
        testID: "fixed-label",
        children: [label, required && /*#__PURE__*/_jsx(Text, {
          variant: "subtitle04Medium",
          color: "dangerKey",
          children: "*"
        })]
      }), subLabel ? /*#__PURE__*/_jsx(Text, {
        testID: "subLabel",
        ml: "4xs",
        variant: "subtitle04Regular",
        color: "neutralLight",
        children: subLabel
      }) : null]
    });
  };
  const RenderOutlinedLabel = () => {
    return /*#__PURE__*/_jsx(_Fragment, {
      children: /*#__PURE__*/_jsx(Animated.View, {
        ...animatedViewProps,
        pointerEvents: "none",
        children: /*#__PURE__*/_jsxs(Box, {
          flexDirection: "row",
          height: inputHeight + 6,
          testID: "outlined-label-box",
          children: [/*#__PURE__*/_jsx(Animated.Text, {
            ...animatedTextProps,
            children: isRTL ? `${subLabel ?? ''}${label}` : `${label}${subLabel ?? ''}`
          }), required && /*#__PURE__*/_jsx(Animated.Text, {
            style: [animatedTextProps.style, {
              color: theme.colors.dangerKey
            }],
            children: "*"
          })]
        })
      })
    });
  };
  return labelFixed ? /*#__PURE__*/_jsx(RenderFixedLabel, {}) : /*#__PURE__*/_jsx(RenderOutlinedLabel, {});
});
//# sourceMappingURL=InputLabel.js.map