"use strict";

import Box from '../Box/Box';
import { Animated, ScrollView, StyleSheet } from 'react-native';
import { Portal } from '@gorhom/portal';
import React from 'react';
import theme from '../../theme';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const BaseModal = ({
  modalKey,
  justifyContent,
  p = 'l',
  accessible,
  accessibilityLabel,
  testID,
  children,
  header,
  actions,
  visible,
  duration = 200,
  closable = true,
  wrongPressThresholdMs = 1000,
  // 1 second
  closeButtonAction,
  borderBottomStartRadius,
  borderBottomEndRadius
}) => {
  const anim = React.useRef(new Animated.Value(0)).current;
  const preventWrongPressToClose = React.useRef(Date.now());
  React.useEffect(() => {
    if (visible) {
      preventWrongPressToClose.current = Date.now();
      Animated.timing(anim, {
        toValue: 0.7,
        duration,
        useNativeDriver: true
      }).start();
    } else {
      anim.setValue(0);
    }
  }, [anim, duration, visible]);
  const close = React.useCallback(() => {
    const threshold = preventWrongPressToClose.current + wrongPressThresholdMs;
    if (closable && threshold < Date.now()) {
      closeButtonAction?.();
    }
  }, [closable, closeButtonAction, wrongPressThresholdMs]);
  const testProps = React.useMemo(() => {
    return {
      accessible: accessible,
      accessibilityLabel: accessibilityLabel ?? testID,
      testID: testID ?? accessibilityLabel
    };
  }, [testID, accessibilityLabel, accessible]);
  if (!visible || !children) {
    return null;
  }
  return /*#__PURE__*/_jsx(Portal, {
    name: modalKey ?? 'base-modal',
    children: /*#__PURE__*/_jsxs(Box, {
      position: "absolute",
      justifyContent: justifyContent,
      p: p,
      top: 0,
      bottom: 0,
      left: 0,
      right: 0,
      testID: `${testProps.testID}-wrapper`,
      accessibilityLabel: `${testProps.accessibilityLabel}-wrapper`,
      children: [/*#__PURE__*/_jsx(Animated.View, {
        testID: `${testProps.testID}-overlay`,
        accessibilityLabel: `${testProps.testID}-overlay`,
        style: [styles.overlay, {
          opacity: anim
        }],
        onStartShouldSetResponder: () => true,
        onResponderRelease: close
      }), /*#__PURE__*/_jsxs(Box, {
        ...testProps,
        bg: "white",
        p: "m",
        borderRadius: 'l',
        borderBottomStartRadius: borderBottomStartRadius,
        borderBottomEndRadius: borderBottomEndRadius,
        style: styles.card,
        children: [header, /*#__PURE__*/_jsx(ScrollView, {
          testID: `${testProps.testID}-body`,
          accessibilityLabel: `${testProps.accessibilityLabel}-body`,
          bounces: false,
          showsVerticalScrollIndicator: true,
          children: children
        }), actions]
      })]
    })
  });
};
const styles = StyleSheet.create({
  card: {
    maxHeight: '90%'
  },
  overlay: {
    position: 'absolute',
    backgroundColor: theme.colors.neutralDarker,
    opacity: 0.7,
    top: 0,
    bottom: 0,
    left: 0,
    right: 0
  }
});
export default BaseModal;
//# sourceMappingURL=BaseModal.js.map