"use strict";

import React from 'react';
import { TouchableOpacity } from 'react-native';
import Box from '../Box/Box';
import Button from '../Button/Button';
import Icon from '../Icon/Icon';
import Text from '../Text/Text';
import BaseModal from './BaseModal';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const Modal = ({
  visible,
  title,
  closable = true,
  modalKey,
  closeButtonAction,
  actionButtonProps,
  secondActionButtonProps,
  justifyContent = 'center',
  testID,
  accessibilityLabel,
  accessible = true,
  children,
  ...etc
}) => {
  const testProps = React.useMemo(() => {
    return {
      accessible: accessible,
      accessibilityLabel: accessibilityLabel ?? testID,
      testID: testID ?? accessibilityLabel
    };
  }, [testID, accessibilityLabel, accessible]);
  const header = React.useMemo(() => {
    if (!title && !closable) {
      return null;
    }
    return /*#__PURE__*/_jsxs(Box, {
      flexDirection: "row",
      justifyContent: "space-between",
      alignItems: "flex-start",
      mb: "m",
      testID: `${testProps.testID}-header`,
      accessibilityLabel: `${testProps.accessibilityLabel}-header`,
      children: [/*#__PURE__*/_jsx(Box, {
        flex: 1,
        children: /*#__PURE__*/_jsx(Text, {
          variant: "subtitle2Medium",
          testID: `${testProps.testID}-title`,
          numberOfLines: 2,
          textAlign: "left",
          children: title
        })
      }), closable && /*#__PURE__*/_jsx(TouchableOpacity, {
        testID: `${testProps.testID}-close`,
        accessibilityLabel: `${testProps.accessibilityLabel}-close`,
        hitSlop: {
          left: 0,
          bottom: 0,
          top: 12,
          right: 12
        },
        onPress: closeButtonAction,
        children: /*#__PURE__*/_jsx(Box, {
          p: "4xs",
          pl: "2xs",
          pb: "2xs",
          children: /*#__PURE__*/_jsx(Icon, {
            name: "close",
            color: "neutralDarker",
            size: "xs"
          })
        })
      })]
    });
  }, [closeButtonAction, closable, testProps.accessibilityLabel, testProps.testID, title]);
  const actions = React.useMemo(() => {
    if (!actionButtonProps && !secondActionButtonProps) {
      return null;
    }
    return /*#__PURE__*/_jsxs(Box, {
      testID: `${testProps.testID}-actions-area`,
      accessibilityLabel: `${testProps.accessibilityLabel}-actions-area`,
      children: [actionButtonProps && /*#__PURE__*/_jsx(Button, {
        mt: "m",
        filled: true,
        size: "l",
        variant: "primary",
        testID: `${testProps.testID}-action`,
        accessibilityLabel: `${testProps.accessibilityLabel}-action`,
        ...actionButtonProps
      }), secondActionButtonProps && /*#__PURE__*/_jsx(Button, {
        mt: "m",
        filled: true,
        size: "l",
        variant: "secondary",
        testID: `${testProps.testID}-second-action`,
        accessibilityLabel: `${testProps.accessibilityLabel}-second-action`,
        ...secondActionButtonProps
      })]
    });
  }, [actionButtonProps, secondActionButtonProps, testProps.accessibilityLabel, testProps.testID]);
  return /*#__PURE__*/_jsx(BaseModal, {
    ...etc,
    closeButtonAction: closeButtonAction,
    header: header,
    accessible: accessible,
    accessibilityLabel: accessibilityLabel,
    testID: testID,
    actions: actions,
    modalKey: modalKey,
    justifyContent: justifyContent,
    closable: closable,
    visible: visible,
    children: children
  });
};
export default Modal;
//# sourceMappingURL=Modal.js.map