"use strict";

import React from 'react';
import { createRestyleComponent, createVariant, layout, spacing, spacingShorthand } from '@ergenekonyigit/restyle';
import { TouchableOpacity } from 'react-native';
import Box from '../Box/Box';
import Text from '../Text/Text';
import FlagIcon from '../FlagIcon/FlagIcon';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const variant = createVariant({
  themeKey: 'radioButtonVariants'
});
const Selectbox = createRestyleComponent([variant], Box);
const RadioButtonContainer = createRestyleComponent([layout, spacing, spacingShorthand], TouchableOpacity);
const RadioButton = ({
  selected,
  label,
  disabled = false,
  flagIcon,
  onPress,
  ...rest
}) => {
  const selectedBox = React.useMemo(() => {
    if (!selected) {
      return null;
    }
    return /*#__PURE__*/_jsx(Box, {
      testID: "bullet",
      borderRadius: "full",
      width: 8,
      height: 8,
      backgroundColor: disabled ? 'neutralLighter' : 'neutralFull'
    });
  }, [disabled, selected]);
  const selectVariant = React.useMemo(() => {
    if (selected) {
      return disabled ? 'disabledSelected' : 'selected';
    } else {
      return disabled ? 'disabledUnselected' : 'unselected';
    }
  }, [selected, disabled]);
  const selectLabelColor = React.useMemo(() => {
    if (disabled) {
      return 'neutralLighter';
    } else {
      return selected ? 'primaryKey' : 'neutralDarker';
    }
  }, [selected, disabled]);
  return /*#__PURE__*/_jsxs(RadioButtonContainer, {
    flexDirection: "row",
    alignSelf: "flex-start",
    disabled: disabled,
    onPress: onPress,
    ...rest,
    children: [/*#__PURE__*/_jsx(Selectbox, {
      testID: "selectbox",
      variant: selectVariant,
      children: selectedBox
    }), flagIcon ? /*#__PURE__*/_jsx(Box, {
      marginLeft: "2xs",
      children: /*#__PURE__*/_jsx(FlagIcon, {
        size: "s",
        name: flagIcon,
        color: disabled ? 'neutralLight' : selected ? 'primaryKey' : 'neutralDarker',
        testID: "flag-icon"
      })
    }) : null, label ? /*#__PURE__*/_jsx(Text, {
      testID: "label",
      marginLeft: "2xs",
      color: selectLabelColor,
      children: label
    }) : null]
  });
};
export default RadioButton;
//# sourceMappingURL=RadioButton.js.map