"use strict";

import React, { useState } from 'react';
import Select from './Select';
import Text from '../Text/Text';
import Box from '../Box/Box';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const sizeList = ['small', 'medium', 'large'];
const SelectMeta = {
  title: 'Select',
  component: Select,
  argTypes: {
    size: {
      options: sizeList,
      control: {
        type: 'radio'
      }
    }
  },
  args: {
    size: 'large',
    label: 'Label',
    placeholder: 'Select item',
    helpText: 'Helper text',
    errorText: 'Error text',
    successText: 'Success text',
    labelFixed: true,
    error: false,
    success: false,
    disabled: false,
    options: [{
      id: '1',
      label: 'Option 1 '
    }, {
      id: '2',
      label: 'Option 2'
    }, {
      id: '3',
      label: 'Option 3'
    }, {
      id: '4',
      label: 'Option 4'
    }, {
      id: '5',
      label: 'Option 5'
    }],
    multiple: true,
    bottomSheetTitle: 'Options',
    closeButtonLabel: 'Cancel',
    selectButtonLabel: 'Select'
  }
};
export default SelectMeta;
export const Basic = args => /*#__PURE__*/_jsxs(Box, {
  borderRadius: "l",
  p: "m",
  children: [/*#__PURE__*/_jsx(Text, {
    variant: "subtitle1Bold",
    mb: "l",
    children: "Select"
  }), /*#__PURE__*/_jsx(Select, {
    ...args
  })]
});
export const Cases = () => {
  const options = [{
    id: '1',
    label: 'Option 1'
  }, {
    id: '2',
    label: 'Option 2'
  }, {
    id: '3',
    label: 'Option 3'
  }, {
    id: '4',
    label: 'Option 4'
  }, {
    id: '5',
    label: 'Option 5'
  }];
  return /*#__PURE__*/_jsxs(Box, {
    px: '2xs',
    children: [/*#__PURE__*/_jsx(Text, {
      py: '2xs',
      variant: "subtitle01Bold",
      children: "Select Cases"
    }), /*#__PURE__*/_jsxs(Box, {
      py: 'xs',
      children: [/*#__PURE__*/_jsx(Select, {
        label: "Inline Label",
        placeholder: "Inline Label",
        options: options,
        bottomSheetTitle: "Options",
        closeButtonLabel: "Cancel",
        selectButtonLabel: "Select"
      }), /*#__PURE__*/_jsx(Select, {
        label: "Label Fixed",
        placeholder: "Label Fixed",
        labelFixed: true,
        options: options,
        bottomSheetTitle: "Options",
        closeButtonLabel: "Cancel",
        selectButtonLabel: "Select"
      }), /*#__PURE__*/_jsx(Select, {
        placeholder: "Label False",
        options: options,
        bottomSheetTitle: "Options",
        closeButtonLabel: "Cancel",
        selectButtonLabel: "Select"
      }), /*#__PURE__*/_jsx(Select, {
        placeholder: "Disable",
        labelFixed: true,
        options: options,
        disabled: true
      })]
    }), /*#__PURE__*/_jsxs(Box, {
      py: 'l',
      children: [/*#__PURE__*/_jsx(Select, {
        label: "Label",
        placeholder: "Required",
        labelFixed: true,
        options: options,
        bottomSheetTitle: "Options",
        closeButtonLabel: "Cancel",
        selectButtonLabel: "Select",
        required: true
      }), /*#__PURE__*/_jsx(Select, {
        label: "Label",
        placeholder: "Optional",
        options: options,
        bottomSheetTitle: "Options",
        closeButtonLabel: "Cancel",
        selectButtonLabel: "Select",
        subLabel: ' (Optional)'
      })]
    }), /*#__PURE__*/_jsxs(Box, {
      py: 'l',
      children: [/*#__PURE__*/_jsx(Select, {
        label: "Label",
        placeholder: "Helper text",
        labelFixed: true,
        options: options,
        bottomSheetTitle: "Options",
        closeButtonLabel: "Cancel",
        selectButtonLabel: "Select",
        helpText: "Helper text"
      }), /*#__PURE__*/_jsx(Select, {
        label: "Label",
        placeholder: "Success",
        labelFixed: true,
        options: options,
        bottomSheetTitle: "Options",
        closeButtonLabel: "Cancel",
        selectButtonLabel: "Select",
        success: true,
        successText: "Success text"
      }), /*#__PURE__*/_jsx(Select, {
        label: "Label",
        placeholder: "Error",
        labelFixed: true,
        options: options,
        bottomSheetTitle: "Options",
        closeButtonLabel: "Cancel",
        selectButtonLabel: "Select",
        error: true,
        errorText: "Error text"
      })]
    })]
  });
};
export const DisplaySelected = args => {
  const [selectedMultiple, setSelectedMultiple] = useState([]);
  const handleMultiSelect = selected => {
    setSelectedMultiple(selected);
  };
  return /*#__PURE__*/_jsxs(Box, {
    px: '2xs',
    children: [/*#__PURE__*/_jsx(Select, {
      ...args,
      label: "Label",
      placeholder: "Multi Select",
      selectedOptions: selectedMultiple,
      onSelect: handleMultiSelect
    }), /*#__PURE__*/_jsx(Box, {
      py: 's',
      children: /*#__PURE__*/_jsxs(Text, {
        children: ["Selected values: ", selectedMultiple.join(', ') || 'None']
      })
    })]
  });
};
export const SingleSelect = () => {
  const options = [{
    id: '1',
    label: 'Option 1'
  }, {
    id: '2',
    label: 'Option 2'
  }, {
    id: '3',
    label: 'Option 3'
  }, {
    id: '4',
    label: 'Option 4'
  }, {
    id: '5',
    label: 'Option 5'
  }];
  return /*#__PURE__*/_jsxs(Box, {
    px: '2xs',
    children: [/*#__PURE__*/_jsx(Text, {
      py: '2xs',
      variant: "subtitle01Bold",
      children: "Single Select"
    }), /*#__PURE__*/_jsxs(Box, {
      py: 'xs',
      children: [/*#__PURE__*/_jsx(Select, {
        multiple: false,
        label: "Inline Label",
        placeholder: "Inline Label",
        options: options,
        bottomSheetTitle: "Options",
        closeButtonLabel: "Cancel",
        selectButtonLabel: "Select"
      }), /*#__PURE__*/_jsx(Select, {
        multiple: false,
        label: "Label Fixed",
        placeholder: "Label Fixed",
        labelFixed: true,
        options: options,
        bottomSheetTitle: "Options",
        closeButtonLabel: "Cancel",
        selectButtonLabel: "Select"
      }), /*#__PURE__*/_jsx(Select, {
        multiple: false,
        placeholder: "Label False",
        options: options,
        bottomSheetTitle: "Options",
        closeButtonLabel: "Cancel",
        selectButtonLabel: "Select"
      })]
    })]
  });
};
export const Sizes = () => {
  const options = [{
    id: '1',
    label: 'Option 1'
  }, {
    id: '2',
    label: 'Option 2'
  }, {
    id: '3',
    label: 'Option 3'
  }, {
    id: '4',
    label: 'Option 4'
  }, {
    id: '5',
    label: 'Option 5'
  }];
  return /*#__PURE__*/_jsxs(Box, {
    px: '2xs',
    children: [/*#__PURE__*/_jsx(Text, {
      py: '2xs',
      variant: "subtitle01Bold",
      children: "Select Sizes"
    }), /*#__PURE__*/_jsxs(Box, {
      py: 'xs',
      children: [/*#__PURE__*/_jsx(Select, {
        size: "large",
        label: "Label",
        placeholder: "Large",
        options: options,
        bottomSheetTitle: "Options",
        closeButtonLabel: "Cancel",
        selectButtonLabel: "Select"
      }), /*#__PURE__*/_jsx(Select, {
        size: "large",
        label: "Label",
        placeholder: "Large",
        labelFixed: true,
        options: options,
        bottomSheetTitle: "Options",
        closeButtonLabel: "Cancel",
        selectButtonLabel: "Select"
      }), /*#__PURE__*/_jsx(Select, {
        size: "large",
        placeholder: "Large",
        options: options,
        bottomSheetTitle: "Options",
        closeButtonLabel: "Cancel",
        selectButtonLabel: "Select"
      })]
    }), /*#__PURE__*/_jsxs(Box, {
      py: 'xl',
      children: [/*#__PURE__*/_jsx(Select, {
        size: "medium",
        label: "Label",
        placeholder: "Medium",
        options: options,
        bottomSheetTitle: "Options",
        closeButtonLabel: "Cancel",
        selectButtonLabel: "Select"
      }), /*#__PURE__*/_jsx(Select, {
        size: "medium",
        label: "Label",
        placeholder: "Medium",
        labelFixed: true,
        options: options,
        bottomSheetTitle: "Options",
        closeButtonLabel: "Cancel",
        selectButtonLabel: "Select"
      }), /*#__PURE__*/_jsx(Select, {
        size: "medium",
        placeholder: "Medium",
        options: options,
        bottomSheetTitle: "Options",
        closeButtonLabel: "Cancel",
        selectButtonLabel: "Select"
      })]
    }), /*#__PURE__*/_jsxs(Box, {
      py: 'xl',
      children: [/*#__PURE__*/_jsx(Select, {
        size: "small",
        label: "Label",
        placeholder: "Small",
        options: options,
        bottomSheetTitle: "Options",
        closeButtonLabel: "Cancel",
        selectButtonLabel: "Select"
      }), /*#__PURE__*/_jsx(Select, {
        size: "small",
        label: "Label",
        placeholder: "Small",
        labelFixed: true,
        options: options,
        bottomSheetTitle: "Options",
        closeButtonLabel: "Cancel",
        selectButtonLabel: "Select"
      }), /*#__PURE__*/_jsx(Select, {
        size: "small",
        placeholder: "Small",
        options: options,
        bottomSheetTitle: "Options",
        closeButtonLabel: "Cancel",
        selectButtonLabel: "Select"
      })]
    })]
  });
};
//# sourceMappingURL=Select.stories.js.map