"use strict";

import React from 'react';
import { FlatList, ScrollView, StyleSheet, TouchableOpacity } from 'react-native';
import Box from '../Box/Box';
import BottomSheet from '../BottomSheet/BottomSheet';
import Checkbox from '../Checkbox/Checkbox';
import RadioButton from '../RadioButton/RadioButton';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const SelectBottomSheet = ({
  options,
  type,
  onSelect,
  selectedOption,
  maxVisibleItems = 6,
  pb,
  accessibilityLabel,
  testID,
  ...bottomSheetProps
}) => {
  const [selectedValues, setSelectedValues] = React.useState(selectedOption ?? []);
  const testProps = React.useMemo(() => {
    return {
      accessibilityLabel: accessibilityLabel ?? testID,
      testID: testID ?? accessibilityLabel
    };
  }, [testID, accessibilityLabel]);
  React.useEffect(() => {
    if (Array.isArray(selectedOption)) {
      setSelectedValues(selectedOption);
    }
  }, [selectedOption]);
  const handleSelect = value => {
    if (type === 'checkbox') {
      setSelectedValues(prev => prev.includes(value) ? prev.filter(v => v !== value) : [...prev, value]);
    } else {
      setSelectedValues([value]);
    }
  };
  React.useEffect(() => {
    if (onSelect) {
      onSelect(selectedValues);
    }
  }, [selectedValues, onSelect]);
  const renderItem = ({
    item,
    index
  }) => {
    return /*#__PURE__*/_jsxs(Box, {
      children: [/*#__PURE__*/_jsx(TouchableOpacity, {
        onPress: () => handleSelect(item.id),
        disabled: item.disabled,
        ...testProps,
        testID: `touchable-selectBottomSheet-${item.id}`,
        children: type === 'checkbox' ? /*#__PURE__*/_jsx(Checkbox, {
          testID: `checkbox-selectBottomSheet-${item.id}`,
          label: item.label,
          flagIcon: item.flagIcon,
          checked: selectedValues.includes(item.id),
          onPress: () => handleSelect(item.id),
          disabled: item.disabled
        }) : /*#__PURE__*/_jsx(RadioButton, {
          testID: `radiobutton-selectBottomSheet-${item.id}`,
          label: item.label,
          flagIcon: item.flagIcon,
          selected: selectedValues.includes(item.id),
          onPress: () => handleSelect(item.id),
          disabled: item.disabled
        })
      }), index < options.length - 1 && /*#__PURE__*/_jsx(Box, {
        height: 1,
        backgroundColor: "borderColor",
        marginVertical: "m"
      })]
    }, item.id);
  };
  return /*#__PURE__*/_jsx(BottomSheet, {
    ...bottomSheetProps,
    ...testProps,
    children: /*#__PURE__*/_jsx(Box, {
      pb: pb,
      children: /*#__PURE__*/_jsx(ScrollView, {
        testID: 'selectBottomSheet',
        contentContainerStyle: styles.flatListContainer,
        horizontal: true,
        bounces: false,
        children: /*#__PURE__*/_jsx(FlatList, {
          data: options,
          renderItem: renderItem,
          keyExtractor: item => item.id,
          nestedScrollEnabled: true,
          initialNumToRender: maxVisibleItems,
          maxToRenderPerBatch: maxVisibleItems,
          style: {
            maxHeight: maxVisibleItems * 50 - 15
          }
        })
      })
    })
  });
};
export default SelectBottomSheet;
const styles = StyleSheet.create({
  flatListContainer: {
    flex: 1,
    width: 'auto'
  }
});
//# sourceMappingURL=SelectBottomSheet.js.map