"use strict";

import React from 'react';
import { Alert } from 'react-native';
import SelectBottomSheet from './SelectBottomSheet';
import Text from '../Text/Text';
import Button from '../Button/Button';
import Box from '../Box/Box';
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
const typeList = ['checkbox', 'radio'];
const SelectBottomSheetMeta = {
  title: 'SelectBottomSheet',
  component: SelectBottomSheet,
  argTypes: {
    type: typeList,
    options: {
      id: '1',
      label: 'Option'
    }
  },
  args: {
    visible: true,
    type: 'checkbox',
    selectButtonLabel: 'Select',
    closeButtonLabel: 'Close',
    title: 'Select Options',
    options: [{
      id: '1',
      label: 'Option 1'
    }, {
      id: '2',
      label: 'Option 2'
    }, {
      id: '3',
      label: 'Option 3'
    }]
  }
};
export default SelectBottomSheetMeta;
export const Basic = args => /*#__PURE__*/_jsxs(Box, {
  borderRadius: "l",
  p: "m",
  children: [/*#__PURE__*/_jsx(Text, {
    variant: "subtitle1Bold",
    mb: "l",
    children: "Select Bottom Sheet"
  }), /*#__PURE__*/_jsx(SelectBottomSheet, {
    visible: args.visible,
    type: args.type,
    selectButtonLabel: "Select",
    closeButtonLabel: "Close",
    title: "Select Options",
    options: args.options,
    onSelect: () => {}
  })]
});
export const Checkbox = () => {
  const [modal, showModal] = React.useState(false);
  const [selectedOptions, setSelectedOptions] = React.useState([]);
  const handleMultiSelect = options => {
    if (Array.isArray(options)) {
      setSelectedOptions(options);
    }
  };
  const options = [{
    id: '1',
    label: 'Option 1'
  }, {
    id: '2',
    label: 'Option 2'
  }, {
    id: '3',
    label: 'Option 3'
  }, {
    id: '4',
    label: 'Option 4'
  }, {
    id: '5',
    label: 'Option 5',
    disabled: true
  }, {
    id: '6',
    label: 'Option 6'
  }, {
    id: '7',
    label: 'Option 7'
  }, {
    id: '8',
    label: 'Option 8'
  }, {
    id: '9',
    label: 'Option 9'
  }];
  const showAlert = selected => {
    Alert.alert('Selected Items', selected.join(', '));
  };
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx(Text, {
      p: "2xs",
      variant: "subtitle01Bold",
      children: "Select Bottom Sheet with Checkbox"
    }), /*#__PURE__*/_jsxs(Box, {
      px: "m",
      py: "2xs",
      children: [/*#__PURE__*/_jsx(Button, {
        mb: "m",
        filled: true,
        label: "Checkbox",
        onPress: () => showModal(true)
      }), /*#__PURE__*/_jsx(SelectBottomSheet, {
        visible: modal,
        type: "checkbox",
        selectButtonLabel: "Select",
        closeButtonLabel: "Close",
        title: "Select Options",
        closeButtonAction: () => showModal(false),
        selectButtonAction: () => {
          showAlert(selectedOptions);
          showModal(false);
        },
        options: options,
        selectedOption: selectedOptions,
        onSelect: handleMultiSelect
      })]
    })]
  });
};
export const RadioButton = () => {
  const [modal, showModal] = React.useState(false);
  const [selectedRadioOption, setSelectedRadioOption] = React.useState('');
  const handleRadioSelect = option => {
    if (Array.isArray(option) && option.length > 0) {
      setSelectedRadioOption(option[0]);
    } else if (typeof option === 'string') {
      setSelectedRadioOption(option);
    }
  };
  const [modal2, showModal2] = React.useState(false);
  const [selectedRadioOption2, setSelectedRadioOption2] = React.useState('');
  const handleRadioSelect2 = option => {
    if (Array.isArray(option) && option.length > 0) {
      setSelectedRadioOption2(option[0]);
    } else if (typeof option === 'string') {
      setSelectedRadioOption2(option);
    }
    if (selectedRadioOption2) {
      showAlert([selectedRadioOption2]);
      showModal2(false);
    }
  };
  const options = [{
    id: '1',
    label: 'Option 1'
  }, {
    id: '2',
    label: 'Option 2'
  }, {
    id: '3',
    label: 'Option 3'
  }, {
    id: '4',
    label: 'Option 4'
  }, {
    id: '5',
    label: 'Option 5',
    disabled: true
  }, {
    id: '6',
    label: 'Option 6'
  }, {
    id: '7',
    label: 'Option 7'
  }, {
    id: '8',
    label: 'Option 8'
  }, {
    id: '9',
    label: 'Option 9'
  }];
  const showAlert = selected => {
    Alert.alert('Selected Items', selected.join(', '));
  };
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx(Text, {
      p: "2xs",
      variant: "subtitle01Bold",
      children: "Select Bottom Sheet with RadioButton"
    }), /*#__PURE__*/_jsxs(Box, {
      px: "m",
      py: "2xs",
      children: [/*#__PURE__*/_jsx(Button, {
        mb: "m",
        filled: true,
        label: "RadioButton",
        onPress: () => showModal(true)
      }), /*#__PURE__*/_jsx(SelectBottomSheet, {
        visible: modal,
        type: "radio",
        selectButtonLabel: "Select",
        closeButtonLabel: "Close",
        title: "Select a Single Option",
        closeButtonAction: () => showModal(false),
        selectButtonAction: () => {
          showAlert([selectedRadioOption]);
          showModal(false);
        },
        options: options,
        selectedOption: [selectedRadioOption],
        onSelect: handleRadioSelect
      })]
    }), /*#__PURE__*/_jsxs(Box, {
      px: "m",
      py: "2xs",
      children: [/*#__PURE__*/_jsx(Button, {
        mb: "m",
        filled: true,
        label: "RadioButton without select button",
        onPress: () => showModal2(true)
      }), /*#__PURE__*/_jsx(SelectBottomSheet, {
        visible: modal2,
        type: "radio",
        options: options,
        title: "Select a Single Option",
        closeButtonLabel: "Close",
        closeButtonAction: () => showModal2(false),
        onSelect: handleRadioSelect2
      })]
    })]
  });
};
//# sourceMappingURL=SelectBottomSheet.stories.js.map