"use strict";

import { createRestyleComponent, layout, border, spacing, opacity } from '@ergenekonyigit/restyle';
import React, { useRef, useState } from 'react';
import { Animated, Easing, Pressable, I18nManager } from 'react-native';
import theme from '../../theme';
import Text from '../Text/Text';
import Box from '../Box/Box';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const SwitchContainer = createRestyleComponent([layout], Box);
const AnimatedView = createRestyleComponent([layout, border, spacing], Animated.View);
const RestyledPressable = createRestyleComponent([opacity], Pressable);
const Switch = ({
  label,
  value,
  onValueChange,
  disabled,
  onColor,
  offColor,
  testID,
  accessibilityLabel,
  accessible,
  containerStyle
}) => {
  const [isEnabled, setIsEnabled] = useState(value ? value : false);
  const animatedCirclePosition = useRef(new Animated.Value(isEnabled ? 1 : 0)).current;
  const animatedSwitchWidth = useRef(new Animated.Value(theme.spacing.l)).current;
  const animatedSwitchMarginRight = useRef(new Animated.Value(0)).current;
  const onSwitchPressIn = () => {
    Animated.timing(animatedSwitchMarginRight, {
      toValue: isEnabled ? 1 : -1,
      duration: 200,
      easing: Easing.sin,
      useNativeDriver: false
    }).start();
    Animated.timing(animatedSwitchWidth, {
      toValue: theme.spacing.xl,
      duration: 200,
      easing: Easing.sin,
      useNativeDriver: false
    }).start();
  };
  const onSwitchPressOut = () => {
    Animated.timing(animatedSwitchWidth, {
      toValue: theme.spacing.l,
      duration: 130,
      easing: Easing.out(Easing.exp),
      useNativeDriver: false
    }).start();
  };
  const handleValueChange = React.useCallback(nextState => {
    setIsEnabled(nextState);
    if (onValueChange) {
      onValueChange(nextState);
    }
    Animated.timing(animatedCirclePosition, {
      toValue: nextState ? 1 : 0,
      duration: 130,
      easing: Easing.out(Easing.exp),
      useNativeDriver: false
    }).start();
    Animated.timing(animatedSwitchMarginRight, {
      toValue: 0,
      duration: 90,
      easing: Easing.out(Easing.exp),
      useNativeDriver: false
    }).start();
  }, [animatedCirclePosition, animatedSwitchMarginRight, onValueChange]);
  const testProps = React.useMemo(() => {
    const result = {
      accessible: false,
      accessibilityLabel: undefined,
      testID: undefined
    };
    if (!(testID || accessibilityLabel)) {
      return result;
    }
    result.accessible = accessible ?? true;
    result.accessibilityLabel = accessibilityLabel ?? testID;
    result.testID = testID ?? accessibilityLabel;
    return result;
  }, [testID, accessibilityLabel, accessible]);
  const isRTL = I18nManager.isRTL;
  return /*#__PURE__*/_jsxs(SwitchContainer, {
    flexDirection: "row",
    alignItems: "center",
    style: containerStyle,
    children: [label && /*#__PURE__*/_jsx(Text, {
      variant: "subtitle2Medium",
      p: "2xs",
      testID: "switch-label",
      accessibilityLabel: "switch-label",
      children: label
    }), /*#__PURE__*/_jsx(RestyledPressable, {
      opacity: disabled ? 0.5 : 1,
      disabled: disabled,
      onPressOut: onSwitchPressOut,
      onPressIn: onSwitchPressIn,
      onPress: () => handleValueChange(!isEnabled),
      ...testProps,
      children: /*#__PURE__*/_jsx(AnimatedView, {
        flexDirection: isRTL ? 'row-reverse' : 'row',
        width: theme.spacing['4xl'],
        height: theme.spacing.xl,
        paddingHorizontal: "4xs",
        alignItems: "center",
        borderRadius: "full",
        testID: "switch-outer-view",
        accessibilityLabel: "switch-outer-view"
        // @ts-ignore
        ,
        backgroundColor: animatedCirclePosition.interpolate({
          inputRange: [0, 1],
          outputRange: [offColor ?? theme.colors.neutralLighter, onColor ?? theme.colors.primaryKey]
        }),
        children: /*#__PURE__*/_jsx(AnimatedView, {
          backgroundColor: "white",
          height: theme.spacing.l,
          borderRadius: "full",
          testID: "switch-inner-view",
          accessibilityLabel: "switch-inner-view"
          //@ts-ignore
          ,
          width: animatedSwitchWidth
          //@ts-ignore
          ,
          style: {
            transform: [{
              translateX: animatedCirclePosition.interpolate({
                inputRange: [0, 1],
                outputRange: I18nManager.isRTL ? [theme.spacing.xl, 0] : [0, theme.spacing.xl]
              })
            }, {
              translateX: animatedSwitchMarginRight.interpolate({
                inputRange: [-1, 0, 1],
                outputRange: [2, 0, -6]
              })
            }]
          }
        })
      })
    })]
  });
};
export default Switch;
//# sourceMappingURL=Switch.js.map