"use strict";

import { composeRestyleFunctions, useRestyle, color, createVariant, opacity, spacing, spacingShorthand, textShadow, typography, visible } from '@ergenekonyigit/restyle';
import React from 'react';
import { Text as RNText } from 'react-native';
import { jsx as _jsx } from "react/jsx-runtime";
const restyleFunctions = composeRestyleFunctions([color, opacity, visible, typography, spacing, spacingShorthand, textShadow, createVariant({
  themeKey: 'textVariants'
})]);
const Text = ({
  testID,
  accessibilityLabel,
  accessible,
  ...rest
}) => {
  const props = useRestyle(restyleFunctions, rest);
  const testProps = React.useMemo(() => {
    const result = {
      accessible: false,
      accessibilityLabel: undefined,
      testID: undefined
    };
    if (!(testID || accessibilityLabel)) {
      return result;
    }
    result.accessible = accessible ?? true;
    result.accessibilityLabel = accessibilityLabel ?? testID;
    result.testID = testID ?? accessibilityLabel;
    return result;
  }, [testID, accessibilityLabel, accessible]);
  return /*#__PURE__*/_jsx(RNText, {
    ...props,
    ...testProps
  });
};
export default Text;
//# sourceMappingURL=Text.js.map