"use strict";

import React from 'react';
import { act } from 'react-test-renderer';
import { fireEvent, render, waitFor } from '../../test-utils';
import theme from '../../theme';
import TextArea from './TextArea';
import { jsx as _jsx } from "react/jsx-runtime";
describe('TextArea', () => {
  test('should render TextArea correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(TextArea, {
      label: "label"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render label fixed TextArea correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(TextArea, {
      label: "label",
      labelFixed: true,
      placeholder: "placeholder"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render disabled TextArea correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(TextArea, {
      disabled: true,
      label: "label"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render TextArea with help text correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(TextArea, {
      label: "label",
      helpText: "helpText"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render TextArea with error state correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(TextArea, {
      label: "label",
      error: true
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render TextArea with error state and error text correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(TextArea, {
      label: "label",
      error: true,
      errorText: "errorText"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render TextArea with small size correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(TextArea, {
      label: "label",
      size: "small"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render TextArea with medium size correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(TextArea, {
      label: "label",
      size: "medium"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should render TextArea with large size correctly', () => {
    // when
    const {
      toJSON
    } = render(/*#__PURE__*/_jsx(TextArea, {
      label: "label",
      size: "large"
    }));

    // then
    expect(toJSON()).toMatchSnapshot();
  });
  test('should focus TextArea correctly', async () => {
    // when
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(TextArea, {
      label: "label"
    }));

    // then
    expect(getByTestId('textArea-box').props.style[0].borderColor).toBe(theme.colors.neutralLighter);

    // when
    fireEvent(getByTestId('textArea'), 'onFocus');

    // then
    await waitFor(() => {
      expect(getByTestId('textArea-box').props.style[0].borderColor).toBe(theme.colors.primaryKey);
    });
  });
  test('should not focus and blur TextArea when TextArea is disabled', () => {
    // when
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(TextArea, {
      label: "label",
      disabled: true
    }));

    // then
    expect(getByTestId('textArea-box').props.style[0].borderColor).toBe(theme.colors.neutralLighter);

    // when
    act(() => {
      const textArea = getByTestId('textArea');
      fireEvent(textArea, 'onFocus');
      fireEvent(textArea, 'onBlur');
    });

    // then
    expect(getByTestId('textArea-box').props.style[0].borderColor).toBe(theme.colors.neutralLighter);
  });
  test('should blur TextArea without value correctly', () => {
    // when
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(TextArea, {
      label: "label"
    }));

    // then
    expect(getByTestId('textArea-box').props.style[0].borderColor).toBe(theme.colors.neutralLighter);

    // when
    act(() => {
      const textArea = getByTestId('textArea');
      fireEvent(textArea, 'onFocus');
      fireEvent(textArea, 'onBlur');
    });

    // then
    expect(getByTestId('textArea-box').props.style[0].borderColor).toBe(theme.colors.neutralLighter);
  });
  test('should blur TextArea with value correctly', () => {
    // when
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(TextArea, {
      label: "label",
      value: "value"
    }));

    // then
    expect(getByTestId('textArea-box').props.style[0].borderColor).toBe(theme.colors.neutralLighter);

    // when
    act(() => {
      const textArea = getByTestId('textArea');
      fireEvent(textArea, 'onFocus');
      fireEvent(textArea, 'onBlur');
    });

    // then
    expect(getByTestId('textArea-box').props.style[0].borderColor).toBe(theme.colors.neutralLighter);
  });
  test('should change text of TextArea without value', () => {
    // when
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(TextArea, {
      label: "label"
    }));
    const textArea = getByTestId('textArea');
    fireEvent.changeText(textArea, 'e-mail@mail.com');

    // then
    expect(textArea.props.value).toBe('e-mail@mail.com');
  });
  test('should change text of textArea with value', () => {
    // when
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(TextArea, {
      label: "label",
      value: "value"
    }));
    const textArea = getByTestId('textArea');
    fireEvent.changeText(textArea, 'e-mail@mail.com');

    // then
    expect(textArea.props.value).toBe('value');
  });
  test('should not change text of TextArea when TextArea is disabled', () => {
    // when
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(TextArea, {
      label: "label",
      disabled: true
    }));
    const textArea = getByTestId('textArea');
    fireEvent.changeText(textArea, 'e-mail@mail.com');

    // then
    expect(textArea.props.value).not.toBe('e-mail@mail.com');
  });
  test('should change text of TextArea when TextArea has defaultValue', () => {
    // when
    const {
      getByTestId
    } = render(/*#__PURE__*/_jsx(TextArea, {
      label: "label",
      defaultValue: "defaultValue"
    }));
    const textArea = getByTestId('textArea');
    fireEvent.changeText(textArea, 'e-mail@mail.com');

    // then
    expect(textArea.props.value).toBe('e-mail@mail.com');
  });
  test('should access textAreas handle functions correctly', () => {
    // given
    const ref = /*#__PURE__*/React.createRef();

    // when
    render(/*#__PURE__*/_jsx(TextArea, {
      label: "label",
      ref: ref
    }));
    act(() => {
      ref.current?.focus();
      ref.current?.blur();
      ref.current?.clear();
      ref.current?.isFocused();
      ref.current?.setNativeProps({
        text: ''
      });
    });

    // then
    expect(ref.current?.focus).toBeTruthy();
  });
});
//# sourceMappingURL=TextArea.test.js.map