"use strict";

import React from 'react';
import Box from '../Box/Box';
import ToastView from './ToastView';
import { ToastDurations } from './types';
import { uuid } from '../../utils/uuid';
import { useSafeAreaInsets } from 'react-native-safe-area-context';
import { useKeyboard } from './hooks';
import theme from '../../theme';
import { jsx as _jsx, Fragment as _Fragment } from "react/jsx-runtime";
// @ts-ignore
const Toast = /*#__PURE__*/React.memo(({
  ignoreKeyboard = false,
  extraPaddingBottom: extraMarginBottom = 0
}) => {
  const [data, setData] = React.useState(null);
  const insets = useSafeAreaInsets();
  const {
    keyboardHeight,
    isKeyboardVisible
  } = useKeyboard();
  React.useEffect(() => {
    Toast.show = params => {
      if (!params.text) {
        return false;
      }
      setData({
        id: uuid(16),
        variant: params.variant,
        text: params.text,
        duration: params.duration ?? ToastDurations.SHORT,
        action: params.action,
        actionText: params.actionText,
        bottomOffset: params.bottomOffset ?? 0
      });
    };
  }, []);
  const paddingBottom = React.useMemo(() => {
    if (ignoreKeyboard || !isKeyboardVisible) {
      return {
        paddingBottom: insets.bottom * 3 + extraMarginBottom + data?.bottomOffset
      };
    }
    return {
      paddingBottom: theme.spacing['2xs'] + keyboardHeight + extraMarginBottom + data?.bottomOffset
    };
  }, [ignoreKeyboard, extraMarginBottom, insets.bottom, isKeyboardVisible, keyboardHeight, data?.bottomOffset]);
  const toastView = React.useMemo(() => {
    return /*#__PURE__*/_jsx(ToastView, {
      variant: data?.variant,
      text: data?.text,
      onDisappared: () => setData(null),
      duration: data?.duration,
      action: data?.action,
      actionText: data?.actionText
    }, data?.id);
  }, [data]);
  if (!data) {
    return /*#__PURE__*/_jsx(_Fragment, {});
  }
  return /*#__PURE__*/_jsx(Box, {
    position: "absolute",
    pointerEvents: "box-none",
    testID: "toast-wrapper",
    accessibilityLabel: "toast-wrapper",
    width: "100%",
    px: "xl",
    bottom: 0,
    style: paddingBottom,
    children: toastView
  });
});
Toast.show = () => {
  // eslint-disable-next-line no-console
  console.warn('Please add <Toast/> to your root view');
};
export default Toast;
//# sourceMappingURL=Toast.js.map