"use strict";

export function capitalizeFirstLetter(str) {
  if (!str || typeof str !== 'string') {
    return '';
  }
  return str.charAt(0).toUpperCase() + str.slice(1).toLowerCase();
}
export function getFirstNChar(str, n, suffix) {
  let result = str?.substring(0, n);
  if (str?.length > n) {
    result = result.trim() + (suffix ?? '');
  }
  return result;
}
export const pausableTimer = (callback, delay) => {
  let timerId;
  let start;
  let remaining = delay;
  const pause = () => {
    clearTimeout(timerId);
    timerId = undefined;
    remaining -= Date.now() - start;
  };
  const resume = minRemaining => {
    remaining = Math.max(remaining, minRemaining ?? 0);
    if (timerId) {
      return;
    }
    start = Date.now();
    timerId = setTimeout(callback, remaining);
  };
  const kill = () => {
    clearTimeout(timerId);
    start = 0;
    remaining = 0;
  };
  resume();
  return {
    pause,
    resume,
    kill
  };
};
//# sourceMappingURL=utils.js.map