"use strict";

import React, { createContext, useContext, useState } from 'react';
import { Overlay } from './Overlay';
import TooltipView from './TooltipView';
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
export const TooltipContext = /*#__PURE__*/createContext(undefined);
export const TooltipProvider = ({
  children
}) => {
  const [viewport, setViewport] = React.useState();
  const [stack, setStack] = useState([]);
  const activeTooltip = React.useMemo(() => {
    return stack[0];
  }, [stack]);
  const addToStack = React.useCallback(tooltipData => {
    if (tooltipData) {
      tooltipData.triggerRef.current?.measure?.((x, y, w, h, px, py) => {
        if (x ?? w ?? px === undefined) {
          tooltipData.onError?.(tooltipData.id);
          return;
        }
        const _viewport = {
          x,
          y,
          w,
          h,
          px,
          py
        };
        setStack(s => [...s, {
          ...tooltipData,
          viewport: _viewport
        }]);
      });
    }
  }, []);
  const removeFromStack = React.useCallback(id => {
    const temp = stack.find(t => t.id === id);
    if (temp) {
      setStack(stack.filter(t => t.id !== temp?.id));
      temp?.onClose?.(id);
    }
  }, [stack]);
  const removeAllStack = React.useCallback(() => {
    setStack([]);
  }, []);
  const value = React.useMemo(() => ({
    activeTooltip,
    overlayViewport: viewport,
    show: addToStack,
    hide: removeFromStack,
    clearAll: removeAllStack,
    setOverlayViewport: setViewport
  }), [activeTooltip, addToStack, removeAllStack, removeFromStack, viewport]);
  const render = React.useMemo(() => {
    if (!activeTooltip) {
      return null;
    }
    return /*#__PURE__*/_jsxs(_Fragment, {
      children: [/*#__PURE__*/_jsx(Overlay, {}), /*#__PURE__*/_jsx(TooltipView, {})]
    });
  }, [activeTooltip]);
  return /*#__PURE__*/_jsxs(TooltipContext.Provider, {
    value: value,
    children: [children, render]
  });
};
export const useTooltipContext = () => {
  const context = useContext(TooltipContext);
  if (!context) {
    throw new Error('useTooltipContext must be used within a TooltipProvider');
  }
  return context;
};
//# sourceMappingURL=TooltipContext.js.map