"use strict";

import React from 'react';
import { I18nManager, TouchableOpacity } from 'react-native';
import { useSafeAreaInsets } from 'react-native-safe-area-context';
import { deviceHeight, deviceWidth } from '../../utils/dimentions';
import Box from '../Box/Box';
import Icon from '../Icon/Icon';
import Text from '../Text/Text';
import { calculatePosition, PIN_SIZE } from './calculatePosition';
import { useTooltipContext } from './TooltipContext';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const isRTL = I18nManager.isRTL;
const TooltipView = () => {
  const tooltipRef = React.useRef(null);
  const {
    top,
    bottom
  } = useSafeAreaInsets();
  const {
    hide,
    overlayViewport,
    activeTooltip
  } = useTooltipContext();
  const [position, setPosition] = React.useState(activeTooltip.position);
  const onLayout = React.useCallback(() => {
    tooltipRef.current?.measure?.((x, y, w, h, px, py) => {
      switch (activeTooltip.position) {
        case 'top':
          if (Math.abs(py) - PIN_SIZE < top) {
            setPosition('bottom');
          }
          break;
        case 'bottom':
          if (py + h + bottom > deviceHeight - Math.abs(y)) {
            setPosition('top');
          }
          break;
      }
    });
  }, [bottom, activeTooltip, tooltipRef, top]);
  const calc = React.useMemo(() => {
    return calculatePosition({
      ...activeTooltip,
      position
    }, isRTL, overlayViewport);
  }, [activeTooltip, overlayViewport, position]);
  const _hide = React.useCallback(() => {
    if (activeTooltip) {
      hide(activeTooltip.id);
    }
  }, [activeTooltip, hide]);
  const pinPos = React.useMemo(() => {
    return {
      transform: [{
        translateX: calc.pinX
      }, {
        translateY: calc.pinYOverflow
      }, {
        translateX: calc.pinXOverflow
      }, {
        translateY: calc.pinY
      }, {
        rotate: '45deg'
      }]
    };
  }, [calc]);
  if (!overlayViewport || !activeTooltip) {
    return null;
  }
  return /*#__PURE__*/_jsx(Box, {
    flex: 1,
    height: deviceHeight,
    width: deviceWidth,
    position: "absolute",
    pointerEvents: "box-none",
    children: /*#__PURE__*/_jsxs(Box, {
      pointerEvents: "box-none",
      top: calc.top,
      height: calc.height,
      justifyContent: position === 'top' ? 'flex-end' : 'flex-start',
      testID: `tooltip-area-${activeTooltip.id}`,
      children: [/*#__PURE__*/_jsx(Box, {
        testID: `tooltip-${activeTooltip.id}`,
        bg: activeTooltip.color,
        onLayout: onLayout,
        ref: tooltipRef,
        borderRadius: "m",
        marginHorizontal: "m",
        pointerEvents: "auto",
        accessibilityHint: position,
        children: /*#__PURE__*/_jsxs(Box, {
          flexDirection: "row",
          children: [/*#__PURE__*/_jsx(Box, {
            flex: 1,
            padding: "m",
            children: /*#__PURE__*/_jsx(Text, {
              color: "neutralFull",
              variant: "body2",
              testID: `tooltip-content-${activeTooltip.id}`,
              textAlign: 'left',
              children: activeTooltip.content
            })
          }), /*#__PURE__*/_jsx(Box, {
            children: /*#__PURE__*/_jsx(TouchableOpacity, {
              onPress: _hide,
              testID: `tooltip-close-${activeTooltip.id}`,
              accessibilityLabel: `tooltip-close-${activeTooltip.id}`,
              children: /*#__PURE__*/_jsx(Box, {
                padding: "m",
                children: /*#__PURE__*/_jsx(Icon, {
                  name: "close",
                  size: "xs",
                  color: "neutralFull"
                })
              })
            })
          })]
        })
      }), /*#__PURE__*/_jsx(Box, {
        testID: `tooltip-pin-${activeTooltip.id}`,
        position: "absolute",
        bg: activeTooltip.color,
        height: PIN_SIZE,
        width: PIN_SIZE,
        style: pinPos
      })]
    })
  });
};
export default TooltipView;
//# sourceMappingURL=TooltipView.js.map