import { VariantProps } from '@ergenekonyigit/restyle';
import { Theme } from '../../theme';
export interface BaseToastData {
    /**
     * variant
     * what color will appear on the screen
     * @type {ToastVariant}
     * @default  ToastVariant.DEFAULT
     * @success ToastVariant.SUCCESS
     * @error - ToastVariant.ERROR
     */
    variant?: VariantProps<Theme, 'toastVariants'>['variant'];
    /**
     * message to appear in toast
     *
     * max length is 250
     */
    text?: string;
    /**
     * how long(ms) will it be visible on the screen
     * @default 7000
     */
    duration?: number;
    /**
     * offset from the bottom of the screen (in px)
     *
     */
    bottomOffset?: number;
}
export interface ToastDataWithoutAction extends BaseToastData {
    action?: never;
    actionText?: never;
}
export interface ToastDataWithAction extends BaseToastData {
    action: (close: () => void) => void;
    actionText: string;
}
export type ToastData = ToastDataWithoutAction | ToastDataWithAction;
export type ToastDataWithId = (ToastDataWithoutAction | ToastDataWithAction) & {
    id: string;
};
export type ShowMethodParams = ToastDataWithoutAction | ToastDataWithAction;
export declare const ToastDurations: {
    readonly SHORT: 7000;
    readonly LONG: 10000;
};
export type DurationTypes = typeof ToastDurations;
export type Duration = DurationTypes[keyof DurationTypes];
export declare const ToastVariants: {
    readonly DEFAULT: "default";
    readonly SUCCESS: "success";
    readonly ERROR: "error";
    readonly WARNING: "warning";
};
export type ToastVariantsTypes = typeof ToastVariants;
export type ToastVariant = ToastVariantsTypes[keyof ToastVariantsTypes];
//# sourceMappingURL=types.d.ts.map